
 /*
facebook wedge100 
Model:  heart attack module
Revision: V0.1, 
History : 
2015/06/25 - initial draft by zhiping Yao

 
1: check heartbeat signal from fan module
2: if no fan heartbeat activity for 30 seconds, then disable main power
  


*/

module heart_attack
 #
(
    //10hz clock, 1hz heartbeat
    parameter [15:00]   PULSE_WIDTH_HEART_BEAT    = 300   // 30 second 
)
(
    input         clk                  // 50mhz clock
,   input         clk_10hz             // 10hz clock
,   input         fancard_heart        // fancard heart beat
                             
,	output	      fan_fatal            // fan fatal status                          
                   
) ;

  

wire  clk_10hz_pul  ;

pos_edge	clk_10hz_pos_edge        
(
.clk	 		(clk),
.rst_n	 		(1'b1),
.sig_in     	(clk_10hz),
.pos_edge_en	(clk_10hz_pul) 
);

// --------------------------------------
wire  fancard_heart_pul  ;

pos_edge	heart_pos_edge        
(
.clk	 		(clk),
.rst_n	 		(1'b1),
.sig_in     	(fancard_heart),
.pos_edge_en	(fancard_heart_pul) 
);
 
  
reg  [15:0]    heart_counter; 
reg            heart_attacking;
 
always @ (posedge clk  )
    begin
       //  hear beat counter
       if      (  fancard_heart_pul == 1'b1 )                                             heart_counter <=  16'd0 ;        
       else if (( clk_10hz_pul  == 1'b1 ) && ( heart_counter < PULSE_WIDTH_HEART_BEAT ))  heart_counter <=  heart_counter + 16'd1 ;
       else if (  heart_counter     == PULSE_WIDTH_HEART_BEAT )                           heart_counter <=  PULSE_WIDTH_HEART_BEAT ; 
       else                                                                               heart_counter <=  heart_counter  ;
    end
    
       
always @ (posedge clk  )     
    begin
        //
       if      (  heart_counter     == PULSE_WIDTH_HEART_BEAT ) heart_attacking  <= 1'b1 ;
       else                                                     heart_attacking  <= 1'b0 ;
    end


// assign heartbeat signal
assign   fan_fatal = heart_attacking ;

endmodule
