//-----------------------------------------------------------------------------
// Title       : Interrupt control module
// Design      : Wedge100 CPLD Design
// File        : irq_ctrl.v
//-----------------------------------------------------------------------------
// Version     : Ver 2.0
// Changes     : 1. Added Xpliant MISC interrupt status registers using registers
//               rw_0x41 and ro_0x40
//-----------------------------------------------------------------------------
// Description:- Interrupt controller implementation
//-----------------------------------------------------------------------------
module irq_ctrl 
(
	input		  clk			  // clock
,   input         clk_tick 
,   input         rst_n 
                  
,   input  [7:0]  rw_0x20          // interrupt control
,   input  [7:0]  rw_0x21          // interrupt control
,   input  [7:0]  rw_0x22          // interrupt control
,   input  [7:0]  rw_0x23
,   input  [7:0]  rw_0x24
,   input  [7:0]  rw_0x25
,   input  [7:0]  rw_0x41
// output registers
,   output [7:0]  ro_0x10    
,   output [7:0]  ro_0x11
,   output [7:0]  ro_0x12
,   output [7:0]  ro_0x13
,   output [7:0]  ro_0x14
,   output [7:0]  ro_0x15
,   output [7:0]  ro_0x16
,   output [7:0]  ro_0x17
,   output [7:0]  ro_0x40
 

// psu signals      0x10
,   input         PSU1_PRSNT_N            // psu-1 present, active low
,   input         PSU1_PWR_OK             // psu-1 power ok
,   input         PSU1_INPUT_OK           // psu-1 input power ok
,   input         PSU1_SMB_ALERT_N        // psu-1 sm bus alert, active low
                  
,   input         PSU2_PRSNT_N            // psu-2 present, active low
,   input         PSU2_PWR_OK             // psu-2 power ok
,   input         PSU2_INPUT_OK           // psu-2 input power ok
,   input         PSU2_SMB_ALERT_N        // psu-2 sm bus alert, active low
    
    
//   power status input    0x11      
//,   input	      P5V_STBY_OK             // 5V standby power OK
//,   input	      P1V2_STBY_OK            // 1.2V standby power OK                 
,   input	      PWR_STBY_OK             //  
            
//   IR power status, 0x12 
,   input         VCORE_VRDY1             // Vcore voltage ready status
,   input         VCORE_HOT               // over temperature or over current alarm
,   input         VANLG_VRDY1             // 
,   input         VANLG_HOT               // over temperature or over current alarm
,   input         V3V3_VRDY1              // 
,   input         V3V3_HOT                // over temperature or over current alarm
    
//   interrupt signals, 0x13
,   input	      I2C_IO_0_INT_N          // I2C IO device PCA9535 Interrupt
,   input	      I2C_IO_1_INT_N          // I2C IO device PCA9535 Interrupt
,   input	      I2C_IO_2_INT_N          // I2C IO device PCA9535 Interrupt
,   input	      I2C_IO_3_INT_N          // I2C IO device PCA9535 Interrupt
,   input	      I2C_IO_4_INT_N          // I2C IO device PCA9535 Interrupt
,   input	      I2C_IO_5_INT_N          // I2C IO device PCA9535 Interrupt

,   input	      PM_SM_ALERT_N           // power sequencer alaert 
,   input	      VCORE_SMB_ALERT         // 
,   input	      V3_3V_SMB_ALERT         // 
,   input	      VANLG_SMB_ALERT         // 
,   input	      TEMP_SENSOR_ALERT       // temp sensor alert
,   input         TPM_SPI_PIRQ_N          // TPM interrupt

,   input         ISO_XP_REI_INIT_DONE    // ISO_XP_REI_INIT_DONE XPLIANT INTERRUPT SIGNAL
,   input         ISO_XP_INT_N	          // ISO_XP_INT_N XPLIANT INTERRUPT SIGNAL
,   input         ISO_XP_OVERT_N	      // ISO_XP_OVERT_N XLIPANT TEMP SENSOR OUTPUT
,   input         ISO_XP_TEMP_ALRT_N      // ISO_XP_TEMP_ALRT_N XLIPANT TEMP SENSOR OUTPUT	

,   output	      SMB_ALERT               // interrupt from CPLD to BMC for SM bus alarm
,   output        BMC_CPLD_POWER_INT      // interrupt from cpld to BMC for power status change
,   output	      BMC_CPLD_QSFP_INT       // interupt from cpld to BMC for qsfp LLI status change 
                                                                                     
// // interrupt output
// ,   output        irq_psu_n               // psu interrupt active low
// ,   output        irq_power_n               // main board power interrupt active low   
// ,   output        irq_ir_pwr_n               // IR power interrupt active low
// ,   output        irq_pca9535_n               // psu interrupt active low
 
) ;

wire   irq_psu_n    ;           // psu interrupt active low                  
wire   irq_power_n  ;             // main board power interrupt active low  
wire   irq_ir_pwr_n ;              // IR power interrupt active low         
wire   irq_pca9535_n;               // psu interrupt active low    
wire   misc_int_n   ;               // misc interrupt active low    
wire  tpm_spi_int_n ;

//Reg0x10 PSU status register
assign  ro_0x10[0] = PSU1_PRSNT_N      ;      // psu-1 present, active low      
assign  ro_0x10[1] = PSU1_PWR_OK       ;      // psu-1 power ok                 
assign  ro_0x10[2] = PSU1_INPUT_OK     ;      // psu-1 input power ok           
assign  ro_0x10[3] = PSU1_SMB_ALERT_N  ;      // psu-1 sm bus alert, active low                                                       
assign  ro_0x10[4] = PSU2_PRSNT_N      ;      // psu-2 present, active low     
assign  ro_0x10[5] = PSU2_PWR_OK       ;      // psu-2 power ok                
assign  ro_0x10[6] = PSU2_INPUT_OK     ;      // psu-2 input power ok           
assign  ro_0x10[7] = PSU2_SMB_ALERT_N  ;      // psu-2 sm bus alert, active low 

// reg_0x11 power status
assign  ro_0x11[0] = PWR_STBY_OK       ;      //  standby power OK
assign  ro_0x11[1] = 1'b0              ;      //       
assign  ro_0x11[2] = 1'b0              ;      // 
assign  ro_0x11[3] = 1'b0              ; 
assign  ro_0x11[4] = 1'b0              ;      //   
assign  ro_0x11[5] = 1'b0              ;      //       
assign  ro_0x11[6] = 1'b0              ;      // 
assign  ro_0x11[7] = 1'b0              ; 

// reg_0x12 power status                   
assign  ro_0x12[0] = VCORE_VRDY1       ;      // Vcore voltage ready status              
assign  ro_0x12[1] = VCORE_HOT         ;      // over temperature or over current alarm  
assign  ro_0x12[2] = VANLG_VRDY1       ;      //                                         
assign  ro_0x12[3] = VANLG_HOT         ;      // over temperature or over current alarm  
assign  ro_0x12[4] = V3V3_VRDY1        ;      //                                       
assign  ro_0x12[5] = V3V3_HOT          ;      // over temperature or over current alarm
assign  ro_0x12[6] = 1'b0              ;
assign  ro_0x12[7] = 1'b0              ; 
                      

// ro_0x13 for gpio status, debug only
assign  ro_0x13[0] = I2C_IO_0_INT_N     ;     // I2C IO device PCA9535 Interrupt
assign  ro_0x13[1] = I2C_IO_1_INT_N     ;     // I2C IO device PCA9535 Interrupt
assign  ro_0x13[2] = I2C_IO_2_INT_N     ;     // I2C IO device PCA9535 Interrupt
assign  ro_0x13[3] = I2C_IO_3_INT_N     ;     // I2C IO device PCA9535 Interrupt
assign  ro_0x13[4] = I2C_IO_4_INT_N     ;     // I2C IO device PCA9535 Interrupt
assign  ro_0x13[5] = I2C_IO_5_INT_N     ;     // I2C IO device PCA9535 Interrupt
assign  ro_0x13[6] = 1'b1               ;                   
assign  ro_0x13[7] = 1'b1               ;

 


// ========================== Interrupt Outputs ==========================================

// GPIO0: psu_int_n
// rw_0x20 psu interrupt block
wire   [7:0] psu_int_blk = rw_0x20[7:0];
wire   [7:0] psu_int_n_tmp;
assign       psu_int_n_tmp[0] = psu_int_blk[0] | PSU1_PRSNT_N      ;      // psu-1 present, active low       
assign       psu_int_n_tmp[1] = psu_int_blk[1] | PSU1_PWR_OK       ;      // psu-1 power ok                  
assign       psu_int_n_tmp[2] = psu_int_blk[2] | PSU1_INPUT_OK     ;      // psu-1 input power ok             
assign       psu_int_n_tmp[3] = psu_int_blk[3] | PSU1_SMB_ALERT_N  ;      // psu-1 sm bus alert, active low  
assign       psu_int_n_tmp[4] = psu_int_blk[4] | PSU2_PRSNT_N      ;      // psu-2 present, active low       
assign       psu_int_n_tmp[5] = psu_int_blk[5] | PSU2_PWR_OK       ;      // psu-2 power ok                   
assign       psu_int_n_tmp[6] = psu_int_blk[6] | PSU2_INPUT_OK     ;      // psu-2 input power ok            
assign       psu_int_n_tmp[7] = psu_int_blk[7] | PSU2_SMB_ALERT_N  ;      // psu-2 sm bus alert, active low                            
                                                                                                                                     
//wire       nmi_int_n_tmp  = HWM_INT_L & HWM_TCRIT_L & RT1_INT_L & RT2_INT_L & FAN_INTC_L & FAN_INTB_L & FAN_INTA_L ;              
assign       irq_psu_n     = rw_0x25[0]? (1'b1): ( &psu_int_n_tmp) ;   //   Reg0x24_bit0                                                 

// GPIO0: pwr_mb_int_n
// rw_0x21 pwr_mb interrupt block
wire   [7:0] pwr_mb_int_blk = rw_0x21[7:0];
wire   [7:0] pwr_mb_int_n_tmp;
assign       pwr_mb_int_n_tmp[0] = pwr_mb_int_blk[0] | PWR_STBY_OK       ;      // standby power OK             
assign       pwr_mb_int_n_tmp[1] = 1'b1  ;      // 1.2V standby power OK           
assign       pwr_mb_int_n_tmp[2] = 1'b1  ;      //                                 
assign       pwr_mb_int_n_tmp[3] = 1'b1  ;
assign       pwr_mb_int_n_tmp[4] = 1'b1  ;       
assign       pwr_mb_int_n_tmp[5] = 1'b1  ;       
assign       pwr_mb_int_n_tmp[6] = 1'b1  ;       
assign       pwr_mb_int_n_tmp[7] = 1'b1  ;       

assign       irq_power_n     = rw_0x25[1]? (1'b1): ( &pwr_mb_int_n_tmp) ;   //   Reg0x24_bit1    

// GPIO0: pwr_ir_int_n
// rw_0x22 pwr_ir interrupt block
wire   [7:0] pwr_ir_int_blk = rw_0x22[7:0];
wire   [7:0] pwr_ir_int_n_tmp;
assign       pwr_ir_int_n_tmp[0] = pwr_ir_int_blk[0] | VCORE_VRDY1       ;      // Vcore voltage ready status               
assign       pwr_ir_int_n_tmp[1] = pwr_ir_int_blk[1] | VCORE_HOT         ;      // over temperature or over current alarm   
assign       pwr_ir_int_n_tmp[2] = pwr_ir_int_blk[2] | VANLG_VRDY1       ;      //                                           
assign       pwr_ir_int_n_tmp[3] = pwr_ir_int_blk[3] | VANLG_HOT         ;      // over temperature or over current alarm   
assign       pwr_ir_int_n_tmp[4] = pwr_ir_int_blk[4] | V3V3_VRDY1        ;      //                                          
assign       pwr_ir_int_n_tmp[5] = pwr_ir_int_blk[5] | V3V3_HOT          ;      // over temperature or over current alarm    
assign       pwr_ir_int_n_tmp[6] = pwr_ir_int_blk[6] | 1'b1              ;                                                  
assign       pwr_ir_int_n_tmp[7] = pwr_ir_int_blk[7] | 1'b1              ;                                                  

assign       irq_ir_pwr_n     = rw_0x25[2]? (1'b1): ( &pwr_ir_int_n_tmp) ;   //   Reg0x44_bit1  


// GPIO0: pca9535_int_n
// rw_0x23 pca9535 interrupt block
wire   [7:0] pca9535_int_blk = rw_0x23[7:0];
wire   [7:0] pca9535_int_n_tmp;
assign       pca9535_int_n_tmp[0] = pca9535_int_blk[0] | I2C_IO_0_INT_N   ;     // I2C IO device PCA9535 Interrupt
assign       pca9535_int_n_tmp[1] = pca9535_int_blk[1] | I2C_IO_1_INT_N   ;     // I2C IO device PCA9535 Interrupt
assign       pca9535_int_n_tmp[2] = pca9535_int_blk[2] | I2C_IO_2_INT_N   ;     // I2C IO device PCA9535 Interrupt
assign       pca9535_int_n_tmp[3] = pca9535_int_blk[3] | I2C_IO_3_INT_N   ;     // I2C IO device PCA9535 Interrupt
assign       pca9535_int_n_tmp[4] = pca9535_int_blk[4] | I2C_IO_4_INT_N   ;     // I2C IO device PCA9535 Interrupt
assign       pca9535_int_n_tmp[5] = pca9535_int_blk[5] | I2C_IO_5_INT_N   ;     // I2C IO device PCA9535 Interrupt
assign       pca9535_int_n_tmp[6] = pca9535_int_blk[6] | 1'b1             ;                                   
assign       pca9535_int_n_tmp[7] = pca9535_int_blk[7] | 1'b1             ;                                        

assign       irq_pca9535_n     = rw_0x25[3]? (1'b1): ( &pca9535_int_n_tmp) ;   //   Reg0x44_bit1  

// Xpliant misc interface interrupt signals
assign  ro_0x40[3] = ISO_XP_REI_INIT_DONE ;  // REI INIT DONE OUTPUT
assign  ro_0x40[2] = ISO_XP_INT_N	      ;  // XPLIANT INTERRUPT SIGNAL
assign  ro_0x40[1] = ISO_XP_OVERT_N	      ;  // XLIPANT TEMP SENSOR OUTPUT
assign  ro_0x40[0] = ISO_XP_TEMP_ALRT_N   ;  // XLIPANT TEMP SENSOR OUTPUT

wire [2:0] misc_int_blk = rw_0x41[2:0];
wire [2:0] misc_int_n_tmp ;
assign  misc_int_n_tmp[0] = misc_int_blk[0] | ISO_XP_INT_N	     ;     // I2C IO device PCA9535 Interrupt
assign  misc_int_n_tmp[1] = misc_int_blk[1] | ISO_XP_OVERT_N	 ;     // I2C IO device PCA9535 Interrupt
assign  misc_int_n_tmp[2] = misc_int_blk[2] | ISO_XP_TEMP_ALRT_N ;     // I2C IO device PCA9535 Interrupt

assign misc_int_n = rw_0x41[3]? (1'b1): ( &misc_int_n_tmp) ;

// pwr aleart interrupt
wire   [7:0] smb_int_blk = rw_0x24[7:0];
wire   [4:0] smb_alert_tmp;

assign       smb_alert_tmp[0]  =  smb_int_blk[0] | PM_SM_ALERT_N ;
assign       smb_alert_tmp[1]  =  smb_int_blk[1] | VCORE_SMB_ALERT ;
assign       smb_alert_tmp[2]  =  smb_int_blk[2] | V3_3V_SMB_ALERT ;
assign       smb_alert_tmp[3]  =  smb_int_blk[3] | VANLG_SMB_ALERT ;
assign       smb_alert_tmp[4]  =  smb_int_blk[4] | TEMP_SENSOR_ALERT ;
	            

assign       ro_0x14[0]  = irq_psu_n    ;           // psu interrupt active low                  
assign       ro_0x14[1]  = irq_power_n  ;           // main board power interrupt active low   
assign       ro_0x14[2]  = irq_ir_pwr_n ;           // IR power interrupt active low          
assign       ro_0x14[3]  = irq_pca9535_n;           // psu interrupt active low     
assign       ro_0x14[4]  = tpm_spi_int_n ;      //   
assign       ro_0x14[5]  = misc_int_n  ;      //       
assign       ro_0x14[6]  = 1'b0  ;      // 
assign       ro_0x14[7]  = 1'b0  ; 

assign       SMB_ALERT          =  rw_0x25[4]? (1'b1): ( &smb_alert_tmp) ;   //   Reg0x44_bit1 

assign       tpm_spi_int_n      =  rw_0x25[5]? (1'b1): ( TPM_SPI_PIRQ_N) ;   //   tpm interrupt block
         
assign       BMC_CPLD_POWER_INT =  rw_0x25[6]? (1'b1): ( irq_ir_pwr_n & irq_power_n & irq_psu_n & misc_int_n) ; 
assign       BMC_CPLD_QSFP_INT  =  rw_0x25[7]? (1'b1): ( irq_pca9535_n ) ;  
 
/*
//===============================================================

// reg_0x4d: write clear register
 
wire        wr_clear_fru_prsnt;
wire  [2:0] wr_clear_mb_pg ;
wire  [2:0] wr_clear_eps_pg;
wire  [1:0] wr_clear_psu_pg;

assign  wr_clear_fru_prsnt = wr_0x4c_en & rw_0x4c[0];

assign  wr_clear_mb_pg[2]  = wr_0x4d_en & rw_0x4d[7];
assign  wr_clear_mb_pg[1]  = wr_0x4d_en & rw_0x4d[6];
assign  wr_clear_mb_pg[0]  = wr_0x4d_en & rw_0x4d[5];
assign  wr_clear_eps_pg[2] = wr_0x4d_en & rw_0x4d[4];
assign  wr_clear_eps_pg[1] = wr_0x4d_en & rw_0x4d[3];
assign  wr_clear_eps_pg[0] = wr_0x4d_en & rw_0x4d[2];
assign  wr_clear_psu_pg[1] = wr_0x4d_en & rw_0x4d[1];
assign  wr_clear_psu_pg[0] = wr_0x4d_en & rw_0x4d[0];

 

fru_prsnt_int_gen fru_prsnt_int_gen_inst

(
	.clk 				   (clk	                  ),
	.clk_ls                (clk_tick              ),  //low speed clock
	.reset_n               (rst_n                 ),
	.fru_int_test          (fru_int_test          ),
	.test_select           (test_select[2:0]      ),                                                  
	.psu_present           ({1'b1,EPS_PST_L }     ),                               
	.fan_prsnt             (2'b11                 ), // 0: fan is alive  1: not active
	.module_present	       (3'b111                ), 
	.wr_clear_fru_prsnt    (wr_clear_fru_prsnt    ), // write clear pulse to clear interrupt
	.ro_0x04		       (ro_0x04               ),
	.fru_prsnt_int		   (fru_prsnt_int         ) 
) ;

wire  [1:0] psu_pwr_good_n;
assign      psu_pwr_good_n[0] = PSU_12V_PG_L ;         // Internal PSU Power good
assign      psu_pwr_good_n[1] = PSU_54V_PG_L ;         // RPS PSU 12V Ready 

wire  [2:0] eps_pwr_good_n;
assign      eps_pwr_good_n[0] = EPS_12V_PG_L;     // EPS 12V power good
assign      eps_pwr_good_n[1] = EPS1_PG_L;     // EPS channel 1 power good
assign      eps_pwr_good_n[2] = EPS2_PG_L;     // EPS channel 2 power good

wire  [2:0] mb_pwr_good_n;
assign      mb_pwr_good_n[0] = !SYS_PG    ;   // PGOOD output from 0.75V, last power of volt chain
assign      mb_pwr_good_n[1] = !P1V525_PG;   // On board 1.5V Power good status input
assign      mb_pwr_good_n[2] = !VP1P0_PG ;   // PGOOD of tps53319 P1V0

//wire        MB_PG_INT,EPS_PG_INT,PSU_PG_INT;

wire  [2:0] mb_pg_int_n ;
wire  [2:0] eps_pg_int_n;
wire  [1:0] psu_pg_int_n;

pwrgood_int_gen pwrgood_int_gen_inst

(
	.clk 				    (clk	    		  ),           
	.clk_ls                 (clk_tick             ),
	.reset                  (rst_n                ),
	.pwrgood_int_test       (pwrgood_int_test     ),
	.test_select            (test_select[2:0]     ),
	.mb_pwr_good_n          (mb_pwr_good_n        ),  // main board dcdc power good
	.eps_pwr_good_n         (eps_pwr_good_n       ),  // power status
	.psu_pwr_good_n         (psu_pwr_good_n       ),  // power status
	.wr_clear_mb_pg         (wr_clear_mb_pg       ), // write clear pulse to clear interrupt
	.wr_clear_eps_pg        (wr_clear_eps_pg      ),                                   
	.wr_clear_psu_pg        (wr_clear_psu_pg      ),                                  
	.ro_0x02	            (ro_0x02	          ),                                  
	.ro_0x16	            (ro_0x16	          ),  
	.mb_pg_int_n            (mb_pg_int_n          ),
	.eps_pg_int_n           (eps_pg_int_n         ),
	.psu_pg_int_n           (psu_pg_int_n         ) 
) ;

*/ 
                                                                       
endmodule


