 /*
facebook wedge100
Model: wedge100 led test module
Revision: V0.1, 
History : 
2015/06/26 - initial draft by zhiping Yao
 
*/
//-----------------------------------------------------------------------------
// Title       : led test module
// Design      : Wedge100 CPLD Design
// File        : led_test.v
//-----------------------------------------------------------------------------
// Version     : Ver 2.0
// Changes     : 1. Removed the unused signals and rearranged the code
//-----------------------------------------------------------------------------
// Description:- LED test implementation
//-----------------------------------------------------------------------------
module led_test
(
          
  input	         hot_reset_n 	             // cold reset output, reset all devices on board, both standby and main power domain
, input	         warm_reset_n                // warm reset output, reset standby power domain                          	       
, input	         cold_reset_n                // hot reset output, reset BMC only, will not affect datapath                     
, input          pd_stby_reset_n             // async standby power on reset, active low, from power1014a, already delayed
, input	         pd_main_reset_n             // power domain main  

, input	         clk                         // 50mhz clock input
, input          clk_10hz                    // button selection clock
, input	         clk_blink                   // blinking clock input, 500ms??
, input	         pd_main_ok                  // power domain main is OK
, input	         CPLD_QSFP_LED_POSITION                 
                                             
, input  [7:0]   rw_0x3c                     // Tomahawk LED control 1
, input  [7:0]   rw_0x3d                     // Tomahawk LED control 2
, input  [7:0]   rw_0x3e                     // stream LED control 1
, input  [7:0]   rw_0x3f                     // stream LED control 2
                                             
// led stream signals                        
// , input          TH_LED_CLK0                 // tomahawk led stream 0 clk input
// , input          TH_LED_DATA0                // tomahawk led stream 0 data input
// , input          TH_LED_CLK1                 // tomahawk led stream 1 clk input
// , input          TH_LED_DATA1                // tomahawk led stream 1 data input
// , input          TH_LED_CLK2                 // tomahawk led stream 2 clk input
// , input          TH_LED_DATA2                // tomahawk led stream 2 data input
                                             
, output         LED_CLK0_BUF_EN             // led stream 0 ISO buffer enable, active low
, output         LED_CLEAR0                  // led stream 0 clear
, output         LED_CLK0                    // led stream 0 clock output
, output         LED_DATA0                   // led stream 0 data output
                                             
// , output         LED_CLK1_BUF_EN             // led stream 1 ISO buffer enable, active low
// , output         LED_CLEAR1                  // led stream 1 clear
// , output         LED_CLK1                    // led stream 1 clock output
// , output         LED_DATA1                   // led stream 1 data output
                                             
//	system LED signals                       
, output         SYS_LED1_GREEN              // system led 1, green
, output         SYS_LED1_BLUE               // system led 1, blue
, output         SYS_LED1_RED                // system led 1, red
                                             
, output         SYS_LED2_GREEN              // system led 1, green
, output         SYS_LED2_BLUE               // system led 1, blue
, output         SYS_LED2_RED                // system led 1, red

, output         top_led_active_n            //bottom qsfp selection status                                   (* chip_pin = "B4"  *)
, output         bot_led_active_n            //top qsfp selection status                                      (* chip_pin = "D6"  *) 

, output  [7:0]  ro_0x1b                     // led read only status, secreate cmd  

) ;

// {RED, Blue, Green }
parameter [2:0]   COLOR_RED    = 3'b100 ;
parameter [2:0]   COLOR_BLUE   = 3'b010 ;
parameter [2:0]   COLOR_GREEN  = 3'b001 ;
parameter [2:0]   COLOR_YELLOW = 3'b101 ; //Red, Green
parameter [2:0]   COLOR_PINK   = 3'b110 ; //Red, blue
parameter [2:0]   COLOR_AQUA   = 3'b011 ; //green, blue
parameter [2:0]   COLOR_WHITE  = 3'b111 ;

// led stream pulse generation
reg        test_led_clk;
reg [7:0]  led_test_cnt;
reg [1:0]  test_led_data_act;
reg        test_led_green, test_led_blue,test_led_red ; 
reg   [5:0]led_test_numb_cnt;
reg        blink_active;

wire       led_blink_pul;
wire [1:0] test_led_out;
wire   rst_n = cold_reset_n & warm_reset_n ;
// test control reg 0x3d
wire  walk_stream_select = led_test_numb_cnt[5];
wire  led_test_green  = rw_0x3d[5];   // indicate color of the led for testing purpose
wire  led_test_blue   = rw_0x3d[6];   // indicate color of the led for testing purpose
wire  led_test_red    = rw_0x3d[7];   // indicate color of the led for testing purpose
wire [2:0]  led_test_mode;  
wire        walk_test_en; 
wire  [2:0] led_color = rw_0x3d[7:5];
wire  led_start_pul;
wire  [4:0] led_test_num ;

assign  led_test_num    = walk_test_en? led_test_numb_cnt[4:0] : rw_0x3d[4:0]; // indicate one of the led of 16 qsfp port/32 tri-color led
assign led_test_mode      = rw_0x3c[6:4];  
assign walk_test_en       = rw_0x3c[3];  

// counter to move led slot number
always @ (posedge clk )
    begin
       // free run counter for led test timing base 
       if      (led_blink_pul == 1'b1 )  led_test_numb_cnt <= led_test_numb_cnt + 6'd1;
       else                              led_test_numb_cnt <= led_test_numb_cnt ;  
    end   


 

// led shift test logic
// shifting sequence: green, blue, red 

//======================================================================================= 

// led test trigger pulse, 0 -> 1 rising edge

pos_edge	led_0_start_pos_edge        //  
(
.clk	 		(clk),
.rst_n	 		(rst_n),
.sig_in     	(clk_10hz),      // every 100ms generate one pulse
.pos_edge_en	(led_start_pul) 
) ;


pos_edge	led_blink_pos_edge        //  
(
.clk	 		(clk),
.rst_n	 		(rst_n),
.sig_in     	(clk_blink),      // every 1s generate one pulse
.pos_edge_en	(led_blink_pul) 
) ;

// generate blinking control signal
always @ (posedge clk or negedge rst_n)
    begin
       if      (!rst_n)                   blink_active <=  1'b0 ;
       else if (led_blink_pul == 1'b1 )   blink_active <=  !blink_active ;
    end   

// green/blue/red shift position timing base 
always @ (posedge clk )
    begin
       // free run counter for led test timing base 
       if      (led_start_pul == 1'b1 )  led_test_cnt <=  8'd0;
       else if (led_test_cnt  == 8'hFF)  led_test_cnt <= led_test_cnt ;
       else                              led_test_cnt <= led_test_cnt + 8'd1;
          
     // led test pulse generation, each stream has 16 ports, 32 tri-color led, 32x3=96bit. 
     // use 256bit counter, every two bits is a single color led. last two bits not used in 8bit cycle
     // low 8bits for 3 led: bit0,1 for green, bit2,3 for blue, bit4,5 for red, bit6,7 unused
     // led_clk is when cnt[0] = 1
       // if   ( led_test_cnt == 8'd0 )                          test_led_act  <= 1'b1;
	   // else ( led_test_cnt == {led_test_num[4:0], 3'b111 } )  test_led_act  <= 1'b0;
	 
	   // led clock generation, two bits is one led_clk cycle  
	   if       ( led_test_cnt[2:0] == 3'b001 ) test_led_clk <= 1'b1; // red led clock                             
	   else if  ( led_test_cnt[2:0] == 3'b011 ) test_led_clk <= 1'b1; // blue  led clock                             
	   else if  ( led_test_cnt[2:0] == 3'b101 ) test_led_clk <= 1'b1; // green   led clock                             
	   else                                     test_led_clk <= 1'b0;                                                
	                                                                                                                 
	   // Green, Blue, Red                                                                                           
	   if   ( led_test_cnt[2:1] == 2'b10 )  test_led_green  <= led_test_green;                                       
	   else                                 test_led_green  <= 1'b0;                                                 
                                                                                                                     
	   if   ( led_test_cnt[2:1] == 2'b01 )  test_led_blue   <= led_test_blue;
	   else                                 test_led_blue   <= 1'b0;
	   
	   if   ( led_test_cnt[2:1] == 2'b00 )  test_led_red    <= led_test_red;
	   else                                 test_led_red    <= 1'b0;
	 end

	 
// generate test pattern	 
always @ (posedge clk )
	 begin  
	   // led position match. 
	   // led test mode  rw_0x3c[6:4]                                                                
       // 000: stream-0 single led check, led number and color is decided by register 0x3d, constant 
       // 001: stream-1 single led check, led number and color is decided by register 0x3d, constant 
       // 010: stream-0 all    led check, led color is decided by register 0x3d, constant            
       // 011: stream-1 all    led check, led color is decided by register 0x3d, constant            
       // 100: stream-0 single led check, led number and color is decided by register 0x3d, blinking 
       // 101: stream-1 single led check, led number and color is decided by register 0x3d, blinking 
       // 110: stream-0 all    led check, led color is decided by register 0x3d, blinking            
       // 111: stream-1 all    led check, led color is decided by register 0x3d, blinking            

	   if       ( walk_test_en == 1'b0 && led_test_mode == 3'b000  && led_test_cnt[7:3] == led_test_num[4:0] )                   test_led_data_act <= 2'b01 ;
	   else if  ( walk_test_en == 1'b0 && led_test_mode == 3'b001  && led_test_cnt[7:3] == led_test_num[4:0] )                   test_led_data_act <= 2'b10 ;
	   else if  ( walk_test_en == 1'b0 && led_test_mode == 3'b010 )                                                              test_led_data_act <= 2'b11 ;
	   else if  ( walk_test_en == 1'b0 && led_test_mode == 3'b011 )                                                              test_led_data_act <= 2'b11 ;
	   else if  ( walk_test_en == 1'b0 && led_test_mode == 3'b100  && led_test_cnt[7:3] == led_test_num[4:0] && blink_active )   test_led_data_act <= 2'b01 ;
	   else if  ( walk_test_en == 1'b0 && led_test_mode == 3'b101  && led_test_cnt[7:3] == led_test_num[4:0] && blink_active )   test_led_data_act <= 2'b10 ;
	   else if  ( walk_test_en == 1'b0 && led_test_mode == 3'b110  && blink_active )                                             test_led_data_act <= 2'b11 ;
	   else if  ( walk_test_en == 1'b0 && led_test_mode == 3'b111  && blink_active )                                             test_led_data_act <= 2'b11 ;
	   else if  ( walk_test_en == 1'b1 && walk_stream_select == 1'b1 && led_test_cnt[7:3] == led_test_num[4:0] )                 test_led_data_act <= 2'b01 ;
	   else if  ( walk_test_en == 1'b1 && walk_stream_select == 1'b0 && led_test_cnt[7:3] == led_test_num[4:0] )                 test_led_data_act <= 2'b10 ;
	                                                                                                                                                         
	   else                                                                                                                      test_led_data_act <= 2'b00 ;
	   
	   //
	   
    end
 
assign  test_led_out[0] = ( test_led_green || test_led_blue || test_led_red ) && test_led_data_act[0] ; 
assign  test_led_out[1] = ( test_led_green || test_led_blue || test_led_red ) && test_led_data_act[1] ;


always @ (posedge clk )
	 begin  
	   // led position match. 
	   // led test mode  rw_0x3c[6:4]                                                                
       // 000: stream-0 single led check, led number and color is decided by register 0x3d, constant 
       // 001: stream-1 single led check, led number and color is decided by register 0x3d, constant 
       // 010: stream-0 all    led check, led color is decided by register 0x3d, constant            
       // 011: stream-1 all    led check, led color is decided by register 0x3d, constant            
       // 100: stream-0 single led check, led number and color is decided by register 0x3d, blinking 
       // 101: stream-1 single led check, led number and color is decided by register 0x3d, blinking 
       // 110: stream-0 all    led check, led color is decided by register 0x3d, blinking            
       // 111: stream-1 all    led check, led color is decided by register 0x3d, blinking            

	   if       ( walk_test_en == 1'b0 && led_test_mode == 3'b000  && led_test_cnt[7:3] == led_test_num[4:0] )                   test_led_data_act <= 2'b01 ;
	   else if  ( walk_test_en == 1'b0 && led_test_mode == 3'b001  && led_test_cnt[7:3] == led_test_num[4:0] )                   test_led_data_act <= 2'b10 ;
	   else if  ( walk_test_en == 1'b0 && led_test_mode == 3'b010 )                                                              test_led_data_act <= 2'b11 ;
	   else if  ( walk_test_en == 1'b0 && led_test_mode == 3'b011 )                                                              test_led_data_act <= 2'b11 ;
	   else if  ( walk_test_en == 1'b0 && led_test_mode == 3'b100  && led_test_cnt[7:3] == led_test_num[4:0] && blink_active )   test_led_data_act <= 2'b01 ;
	   else if  ( walk_test_en == 1'b0 && led_test_mode == 3'b101  && led_test_cnt[7:3] == led_test_num[4:0] && blink_active )   test_led_data_act <= 2'b10 ;
	   else if  ( walk_test_en == 1'b0 && led_test_mode == 3'b110  && blink_active )                                             test_led_data_act <= 2'b11 ;
	   else if  ( walk_test_en == 1'b0 && led_test_mode == 3'b111  && blink_active )                                             test_led_data_act <= 2'b11 ;
	   else if  ( walk_test_en == 1'b1 && walk_stream_select == 1'b1 && led_test_cnt[7:3] == led_test_num[4:0] )                 test_led_data_act <= 2'b01 ;
	   else if  ( walk_test_en == 1'b1 && walk_stream_select == 1'b0 && led_test_cnt[7:3] == led_test_num[4:0] )                 test_led_data_act <= 2'b10 ;
	                                                                                                                                                         
	   else                                                                                                                      test_led_data_act <= 2'b00 ;
	   
	   //
	   
    end
    
    
endmodule		     