 
// reset control
// reg 0x31 reset control register bit definition
// bit7 reset all, cold   : this bit will reset both standby power domain IC and main pwer domain ICs
// bit6 reset_all,_warm : write 0 to this bit will cause warm boot for all devices including cpu itself
// bit5 
// bit4 
// bit3 
// bit2 
// bit1 reserved
// bit0 reserved


module reset_ctrl 
(
	input			clk				            // clock 
,	input			pd_stby_reset_n 	        // async standby power on reset, active low, from power1014a, already delayed    
,   input           pd_main_reset_n             // async main power on reset, active low, from power1014a, already delayed 
,   input           rst_pwr_n                   // self poweron reset, only used for reset generation        
  
// reset pulse
,   input           pb_reset_neg_pul            // push button reset pulse            
,   input           pb_dbg_reset_neg_pul        // on board pus button for debug                         falling edge pulse, watchdog timeout, reset BMC only and reboot to secondary image                                              
,   input           facebook_dbg_reset_neg_pul  // facebook debug reset input                            falling edge pulse, not used 
,   input 			  cb_reset							// Change                                                                                                
,   input           bmc_req_reset_neg_pul       // bmc request reset input           , reset BMC only                                                                                                                                                                                                                                                           falling edge pulse, reset BMC only                                                                                              
,   input           bmc_reset_th_neg_pul        // bmc reset request to cpld, input #1, reset Tomahawk                                                                                              
,   input           bmc_reset_usrv_neg_pul      // bmc reset request to cpld, input #2, reset uServer                                                                                               
,   input           bmc_reset_main_neg_pul      // bmc reset request to cpld, input #3, reset tomahawk, microserver and everything in main power domain                                             
,   input           bmc_reset_all_neg_pul       // bmc reset request to cpld, input #4, reset everything including BMC and standby power components, and tomahawk and main power domain components  
,   input           wdt_reset_1_neg_pul         // wdt_reset_1_neg_pul                                   
,   input           wdt_reset_2_neg_pul         // wdt_reset_2_neg_pul                                   
                                                                                                         
,   input           reg_hot_req_pul             // reg 0x30 bit 4 negative edge                          
,   input           reg_warm_req_pul            // reg 0x30 bit 5 negative edge       
,   input           reg_cold_req_pul            // reg 0x30 bit 6 negative edge       
,   input           reg_pwr_req_pul             // reg 0x30 bit 7 negative edge       

,   output			hot_reset_n 	            // hot reset output, reset BMC only, will not affect datapath 
,   output          warm_reset_n                // warm reset output, reset main power domain only, not sffect standby power domain
,   output          cold_reset_n                // cold reset output, reset all devices on board, both standby and main power domain
,   output          reset_usrv_n                // micro server reset request 
,   output          reset_th_n                  // tomahawk reset request 
,	 output			  xplaint_reset
) ;

 
//========================================================
//3303330 --> 100ms, 330033 -> 10ms,33003300 --> 1se
//parameter [27:00]	PULSE_WIDTH_PANIC = 4954995 ;  //4954995 --> 150ms, for panic interrupt
//parameter [27:00]	PULSE_WIDTH_RESET = 8258325 ;  //8258325 --> 250ms, assert /hreset 100ms after panic interrupt


 
//spatha/sic use the following parameter, helix4 need minimal
parameter [27:00]	PULSE_WIDTH_HOT  = 5000000 ;  //10000000 --> 20*10   = 200ms,  
parameter [27:00]	PULSE_WIDTH_WARM = 10000000 ;  //10000000 --> 40*10   = 400ms,  
parameter [27:00]	PULSE_WIDTH_COLD = 19000000 ;  //19000000 --> 40ns*19 = 760ms,  
parameter [27:00]	PULSE_WIDTH_END   = 10000 ;
 

parameter st_idle = 0, st_hot_reset = 1, st_warm_reset = 2,st_cold_reset = 3, st_reset_stop = 4,st_usrv_reset = 5,st_th_reset = 6  ;

reg [2:0]  reset_state; 
reg [27:0] cnt_reset_state;  

reg reset_hot_n_int   ;
reg reset_cold_n_int   ;
reg reset_warm_n_int   ; 
reg reset_usrv_n_int  ;
reg reset_th_n_int    ;
reg other_reset_n_int  ;
reg spl_reset,spl_reset_1;
// reset output
//wire   main_stby_reset_n  = pd_main_reset_n & pd_stby_reset_n;

assign hot_reset_n        = reset_hot_n_int   ; 
assign warm_reset_n       = reset_warm_n_int & pd_main_reset_n ; 
assign cold_reset_n       = reset_cold_n_int & pd_stby_reset_n ;
assign reset_usrv_n       = reset_usrv_n_int & pd_main_reset_n ;
assign reset_th_n         = reset_th_n_int   & pd_main_reset_n ;

                                                            
// different type of reset request    
/* reset pulse
,   input           pb_reset_neg_pul            // push button reset pulse , cold reset           
,   input           pb_dbg_reset_neg_pul        // on board pus button for debug, warm, tbd, might be reset usrv only       
,   input           facebook_dbg_reset_neg_pul  // facebook debug reset input, warm reset          
,   input           bmc_req_reset_neg_pul       // bmc request reset input, hot reset           
                                                                             
,   input           bmc_cpld_reset_1_neg_pul    // bmc reset request to cpld, input #1, warm request
,   input           bmc_cpld_reset_2_neg_pul    // bmc reset request to cpld, input #2, cold request
,   input           bmc_cpld_reset_3_neg_pul    // bmc reset request to cpld, input #3
,   input           bmc_cpld_reset_4_neg_pul    // bmc reset request to cpld, input #4
,   input           wdt_reset_1_neg_pul         // wdt_reset_1_neg_pul                
,   input           wdt_reset_2_neg_pul         // wdt_reset_2_neg_pul                
                                                                            
,   input           reg_hot_req_pul             // reg 0x30 bit 4 negative edge                                                            
,   input           reg_warm_req_pul            // reg 0x30 bit 5 negative edge                         
,   input           reg_cold_req_pul            // reg 0x30 bit 6 negative edge                         
,   input           reg_pwr_req_pul             // reg 0x30 bit 7 negative edge                          
*/
                                                                                                 
wire hot_start  =  reg_hot_req_pul       |   // SW write cpld reg 0x31[4]
                   bmc_req_reset_neg_pul |   // BMC request reset BMC only
                   wdt_reset_1_neg_pul   |   // WDT1 timeout reset
                   wdt_reset_2_neg_pul   |    // WDT2 timeout reset
                   pb_reset_neg_pul  ;       // front panel push button reset
                   
wire warm_start =  reg_warm_req_pul           | // SW write cpld reg 0x31[5]
                   facebook_dbg_reset_neg_pul ; // facebook debug header reset input
                          //
                   
wire cold_start =  bmc_reset_all_neg_pul |   //
                   reg_cold_req_pul      |   //
                   reg_pwr_req_pul       |   //
                   pb_dbg_reset_neg_pul  |   // on-board push button
                   bmc_reset_main_neg_pul;   //

wire usrv_start =  bmc_reset_usrv_neg_pul ;
wire th_start   =  bmc_reset_th_neg_pul ;

// reset state machine
// standby power reset is cold reset, it will reset both standby circuit(BMC) and main power IC(micro-server and tomahawk)
// main power reset is warm reset, it will reset main power IC(micro-server and tomahawk)
// only be reset by pd_stby_reset_n

always@(posedge cb_reset or negedge rst_pwr_n)
begin
if(!rst_pwr_n)
spl_reset    				<=1'b0;
else if (reset_cold_n_int)
spl_reset               <=1'b1;
xplaint_reset<=spl_reset;
end



always @ (posedge clk or negedge rst_pwr_n)
if (!rst_pwr_n)
  begin
    reset_state 			<= st_idle ;
    reset_hot_n_int     <= 1'b0 ;     
    reset_cold_n_int    <= 1'b0 ;       		    
    reset_warm_n_int    <= 1'b0 ;
    reset_usrv_n_int    <= 1'b0 ;
    reset_th_n_int      <= 1'b0 ;
    cnt_reset_state 		<= 28'd0 ;
	 
  end
else
  begin
    case (reset_state)
            st_idle : begin
            		    if (hot_start)
                           begin
                             reset_state 		<= st_hot_reset  ;
                             reset_hot_n_int    <= 1'b0 ;
                           end 
                        else if (warm_start)
            		       begin
            		         reset_state 		<= st_warm_reset  ;
            		         reset_warm_n_int   <= 1'b0 ;
            		       end
            		    else if (cold_start)
            		       begin
            		         reset_state 		<= st_cold_reset  ;
            		         reset_cold_n_int   <= 1'b0 ;
            		       end
            		    else if (usrv_start)                  
            		       begin                                 
            		         reset_state 		<= st_usrv_reset  ;   
            		         reset_usrv_n_int   <= 1'b0 ;        
            		       end                                   
            		    else if (th_start)                  
            		       begin                                     
            		         reset_state 		<= st_th_reset  ;   
            		         reset_th_n_int     <= 1'b0 ;        
            		       end                                   
            		    else    //
            		       begin  
            		         reset_hot_n_int         <= 1'b1 ;
            		         reset_warm_n_int        <= 1'b1 ;            		    
            		         reset_cold_n_int        <= 1'b1 ; 	
            		         reset_usrv_n_int        <= 1'b1 ;
            		         reset_th_n_int          <= 1'b1 ;	    
            		         cnt_reset_state 	     <= 28'd0 ;
            		         reset_state 		     <= st_idle ; 
								 end
            		  end
 
            st_hot_reset : 
                      begin
            		    reset_hot_n_int         <= 1'b0 ;
            			if (cnt_reset_state < PULSE_WIDTH_HOT)
            			  begin
            			     cnt_reset_state <= cnt_reset_state + 28'd1 ;
            			     reset_state     <= st_hot_reset ;
            			  end
            			else if (cnt_reset_state == PULSE_WIDTH_HOT)	
            			  begin
            			     cnt_reset_state <= cnt_reset_state ;
            			     reset_state     <= st_reset_stop ;
            			  end
            		  end
            		  
            st_warm_reset : 
                      begin
            		    reset_warm_n_int         <= 1'b0 ;
            			if (cnt_reset_state < PULSE_WIDTH_WARM)
            			  begin
            			     cnt_reset_state <= cnt_reset_state + 28'd1 ;
            			     reset_state     <= st_warm_reset ;
            			  end
            			else if (cnt_reset_state == PULSE_WIDTH_WARM)	
            			  begin
            			     cnt_reset_state <= cnt_reset_state ;
            			     reset_state     <= st_reset_stop ;
            			  end
            		  end
            	
            st_cold_reset : 
                      begin
            		    reset_cold_n_int       <= 1'b0 ; 
            			if (cnt_reset_state < PULSE_WIDTH_COLD)
            			  begin
            			     cnt_reset_state <= cnt_reset_state + 28'd1 ;
            			     reset_state     <= st_cold_reset ;
            			  end
            			else if (cnt_reset_state == PULSE_WIDTH_COLD)	
            			  begin
            			     cnt_reset_state <= cnt_reset_state ;
            			     reset_state     <= st_reset_stop ;
            			  end
            		  end	
            		  
            st_usrv_reset : 
                      begin
            		    reset_usrv_n_int         <= 1'b0 ;
            			if (cnt_reset_state < PULSE_WIDTH_WARM)
            			  begin
            			     cnt_reset_state <= cnt_reset_state + 28'd1 ;
            			     reset_state     <= st_usrv_reset ;
            			  end
            			else if (cnt_reset_state == PULSE_WIDTH_WARM)	
            			  begin
            			     cnt_reset_state <= cnt_reset_state ;
            			     reset_state     <= st_reset_stop ;
            			  end
            		  end           		  

            		  
           st_th_reset : 
                      begin
            		    reset_th_n_int         <= 1'b0 ;
            			if (cnt_reset_state < PULSE_WIDTH_WARM)
            			  begin
            			     cnt_reset_state <= cnt_reset_state + 28'd1 ;
            			     reset_state     <= st_th_reset ;
            			  end
            			else if (cnt_reset_state == PULSE_WIDTH_WARM)	
            			  begin
            			     cnt_reset_state <= cnt_reset_state ;
            			     reset_state     <= st_reset_stop ;
            			  end
            		  end            		  
            		              		  	  
            st_reset_stop : begin
            		    cnt_reset_state      <= 28'd0 ;
            		    reset_hot_n_int      <= 1'b1 ;
            		    reset_warm_n_int     <= 1'b1 ;
            		    reset_cold_n_int     <= 1'b1 ; 
            		    reset_usrv_n_int     <= 1'b1 ;
            		    reset_th_n_int       <= 1'b1 ;
            		    reset_state          <= st_idle ;
            		end
            		
            default :   reset_state          <= st_idle ;
            
           
    endcase
end

endmodule
