
 /*
facebook wedge100 
Model:  reset output module
Revision: V0.1, 
History : 
2015/02/19 - initial draft by zhiping Yao

reset reason
1: Power on reset, both standby and main power domain
2: poweron reset, only tomahawk and microserver power cycling, BMC keep working
3: cold reset: reset both BMC and tomahawk/microserver
4: warm reset: only reset micro-server and tomahawk


*/
//-----------------------------------------------------------------------------
// Title       : reset out module
// Design      : Wedge100 CPLD Design
// File        : reset_out.v
//-----------------------------------------------------------------------------
// Version     : Ver 2.0
// Changes     : 1. Renamed the signals mentioned in excel sheet
//-----------------------------------------------------------------------------
// Description:- Reset out implementation
//-----------------------------------------------------------------------------

module reset_out
(
    input         clk     
,   input         hot_reset_n           // warm reset, from reset_ctrl module 
,   input         warm_reset_n          // warm reset, from reset_ctrl module 
,   input         cold_reset_n          // cold reset, from reset_ctrl module
,   input         reset_usrv_n          // micro server reset request 
,   input         reset_th_n            // tomahawk reset request     
,	 input 			xplaint_reset_n
// BMC control input signals
,   input         xp_powerup            // tomahawk power up, main power up except userver
,   input         userver_powerup       // microserver power up  
,   input         microsrv_pcie_rst_n   // microserver pcie reset input

,   input [7:0]   rw_0x30               // reg 0x30
//,   input [7:0]   rw_0x31               // reg 0x31
,   input [7:0]   rw_0x32               // reg 0x32
,   input [7:0]   rw_0x33               // reg 0x33
,   input [7:0]   rw_0x34               // reg 0x34
,   input [7:0]   rw_0x35               // reg 0x35
,   input [7:0]   rw_0x36               // reg 0x36
,   input [7:0]   rw_0x37               // reg 0x37
,   input [7:0]   rw_0x38               // reg 0x38
,   input [7:0]   rw_0x39               // reg 0x39
 
       
// power control register 0x30             
,	output	pwr_cyc_all_n         // power cycle output to pwr1014a, power cycle all power
,   output  pwr_main_en           // enable main power, active high, to pwr1014a
,   output  pwr_usrv_en           // enable micro-server power, active high, to pwr1014a
,   output  pwr_usrv_btn_n        // micro-server power button input

,   output  pwr_main_force        // force main power, debug only, should not change by SW
,   output  pwr_mserver_force     // force micro-server power, debug only, should not change by SW
                                     
// reset control reset register 0x32   	 
,   output  microsrv_rst_n        // micro-server reset output 
,   output  iso_xpliant_rst_n     // tomahawk reset output 
// ,   output  tomahawk_pcie_rst_n   // tomahawk pcie reset output 

// misc control 
// ,   output  dpll_clk_sel          // dpll clock select
,   output  comexp_test_en_n      // comexp test card enable
,   output  usrv_uart_iso_en      // micro-server uart isolation buffer 0: disable, 1: enable, under BMC control
// BMC reset
,   output  bmc_rst_n            // bmc reset output 
   
// qsfp reset output , reg 0x34 to 0x37                                                                                                      
,   output [31:0] qsfp_reset_n         
                                  
// reset control register 0x32 for small ICs, such as oob switch, phy, and fan-ctrl card    
,   output  fancard_rst_n         // fan_ctrl card reset output                               
,	output	usb_brdg_rst_n        // usb bridge reset output 
,   output  usb_hub_rst_n         // usb hub reset output 
,   output  bcm5387_rst_n         // OOB switch BCM5387 reset output  
,   output  fp_phy_rst_n          // front port PHY reset output 
,   output  bcm54616_phy_rst_n    // on-board PHY BCM54616 reset output 
,   output  usb_spi_brg_rst_n     // reserved usb to spi bridge reset output
,   output  dpll_rst_n            // reserved for dpll module reset

// reset control register 0x33  for i2c mux reset                                
,	output	i2c_mux_rst0_n        // i2c mux 0 reset output
,   output  i2c_mux_rst1_n        // i2c mux 1 reset output
,   output  i2c_mux_rst2_n        // i2c mux 2 reset output
,   output  i2c_mux_rst3_n        // i2c mux 3 reset output
,   output  i2c_mux_psu_rst_n     // i2c mux for psu reset output 
,   output  i2c_mux_exp_rst_n     // i2c mux for qsfp LLI signals reset output  	                              
                   
) ;

// reg_0x30 power cntrol register
// rw_0x30[0]: pwr_cyc_all_n, write 0 to this bit will trigger power cycle of both standby and main power
// rw_0x30[1]: 
assign	pwr_cyc_all_n        =  rw_0x30[0] ; // power cycle output to pwr1014a, power cycle all power
assign  pwr_main_en          =  rw_0x30[1] ; // enable main power, active high
assign  pwr_usrv_en          =  rw_0x30[2] ;
assign  pwr_usrv_btn_n       =  rw_0x30[3] ; // usrv power button control bit

assign  pwr_mserver_force    =  rw_0x30[6] & userver_powerup; // force micro-server power, debug only, should not change by SW
assign  pwr_main_force       =  rw_0x30[7] & xp_powerup;      // force main power, debug only, should not change by SW
           
                        
   
 
// reset control reset register 0x32   	
  
assign  microsrv_rst_n       = cold_reset_n & reset_usrv_n & rw_0x32[0] ; // micro-server reset output 
assign  iso_xpliant_rst_n    = cold_reset_n & reset_th_n   & rw_0x32[1] & xplaint_reset_n; // tomahawk reset output 
// assign  tomahawk_pcie_rst_n  = cold_reset_n & reset_th_n   & rw_0x32[2] & microsrv_pcie_rst_n; // tomahawk pcie reset output 

//bmc reset
assign  bmc_rst_n            = cold_reset_n & hot_reset_n;                 
                                                              
// misc control 0x33
// assign  dpll_clk_sel      = cold_reset_n & rw_0x33[0] ;
assign  comexp_test_en_n  =                rw_0x33[1] ;  // 1: disabl ecomexp test card. 0: enable comexp test card
assign  usrv_uart_iso_en  =                rw_0x33[2] ;  // 1: uart isolation buffer is enabled

//qsfp reset control register 0x34 to 0x37
assign  qsfp_reset_n[0]    = cold_reset_n & warm_reset_n & rw_0x34[0] ;
assign  qsfp_reset_n[1]    = cold_reset_n & warm_reset_n & rw_0x34[1] ;
assign  qsfp_reset_n[2]    = cold_reset_n & warm_reset_n & rw_0x34[2] ;
assign  qsfp_reset_n[3]    = cold_reset_n & warm_reset_n & rw_0x34[3] ;
assign  qsfp_reset_n[4]    = cold_reset_n & warm_reset_n & rw_0x34[4] ;
assign  qsfp_reset_n[5]    = cold_reset_n & warm_reset_n & rw_0x34[5] ;
assign  qsfp_reset_n[6]    = cold_reset_n & warm_reset_n & rw_0x34[6] ;
assign  qsfp_reset_n[7]    = cold_reset_n & warm_reset_n & rw_0x34[7] ;

assign  qsfp_reset_n[8]    = cold_reset_n & warm_reset_n & rw_0x35[0] ;
assign  qsfp_reset_n[9]    = cold_reset_n & warm_reset_n & rw_0x35[1] ;
assign  qsfp_reset_n[10]   = cold_reset_n & warm_reset_n & rw_0x35[2] ;
assign  qsfp_reset_n[11]   = cold_reset_n & warm_reset_n & rw_0x35[3] ;
assign  qsfp_reset_n[12]   = cold_reset_n & warm_reset_n & rw_0x35[4] ;
assign  qsfp_reset_n[13]   = cold_reset_n & warm_reset_n & rw_0x35[5] ;
assign  qsfp_reset_n[14]   = cold_reset_n & warm_reset_n & rw_0x35[6] ;
assign  qsfp_reset_n[15]   = cold_reset_n & warm_reset_n & rw_0x35[7] ;
                          
assign  qsfp_reset_n[16]   = cold_reset_n & warm_reset_n & rw_0x36[0] ;
assign  qsfp_reset_n[17]   = cold_reset_n & warm_reset_n & rw_0x36[1] ;
assign  qsfp_reset_n[18]   = cold_reset_n & warm_reset_n & rw_0x36[2] ;
assign  qsfp_reset_n[19]   = cold_reset_n & warm_reset_n & rw_0x36[3] ;
assign  qsfp_reset_n[20]   = cold_reset_n & warm_reset_n & rw_0x36[4] ;
assign  qsfp_reset_n[21]   = cold_reset_n & warm_reset_n & rw_0x36[5] ;
assign  qsfp_reset_n[22]   = cold_reset_n & warm_reset_n & rw_0x36[6] ;
assign  qsfp_reset_n[23]   = cold_reset_n & warm_reset_n & rw_0x36[7] ;
                          
assign  qsfp_reset_n[24]   = cold_reset_n & warm_reset_n & rw_0x37[0] ;
assign  qsfp_reset_n[25]   = cold_reset_n & warm_reset_n & rw_0x37[1] ;
assign  qsfp_reset_n[26]   = cold_reset_n & warm_reset_n & rw_0x37[2] ;
assign  qsfp_reset_n[27]   = cold_reset_n & warm_reset_n & rw_0x37[3] ;
assign  qsfp_reset_n[28]   = cold_reset_n & warm_reset_n & rw_0x37[4] ;
assign  qsfp_reset_n[29]   = cold_reset_n & warm_reset_n & rw_0x37[5] ;
assign  qsfp_reset_n[30]   = cold_reset_n & warm_reset_n & rw_0x37[6] ;
assign  qsfp_reset_n[31]   = cold_reset_n & warm_reset_n & rw_0x37[7] ;

  

// reset control register 0x38  for i2c mux reset                                
assign	i2c_mux_rst0_n       = cold_reset_n & warm_reset_n & rw_0x38[0] ;  // i2c mux 0 reset output
assign  i2c_mux_rst1_n       = cold_reset_n & warm_reset_n & rw_0x38[1] ;  // i2c mux 1 reset output
assign  i2c_mux_rst2_n       = cold_reset_n & warm_reset_n & rw_0x38[2] ;  // i2c mux 2 reset output
assign  i2c_mux_rst3_n       = cold_reset_n & warm_reset_n & rw_0x38[3] ;  // i2c mux 3 reset output
assign  i2c_mux_psu_rst_n    = cold_reset_n & warm_reset_n & rw_0x38[4] ;  // i2c mux for psu reset output 
assign  i2c_mux_exp_rst_n    = cold_reset_n & warm_reset_n & rw_0x38[5] ;  // i2c mux for qsfp LLI signals reset output  

                                
// reset control register 0x39 for small ICs, such as oob switch, phy, and fan-ctrl card    
assign  fancard_rst_n        = rw_0x39[0] & cold_reset_n  ;  // fan_ctrl card reset output                               
assign	usb_brdg_rst_n       = rw_0x39[1] & cold_reset_n & warm_reset_n ;  // usb bridge reset output 
assign  usb_hub_rst_n        = rw_0x39[2] & cold_reset_n & warm_reset_n ;  // usb hub reset output 
assign  bcm5387_rst_n        = rw_0x39[3] & cold_reset_n  ;  // OOB switch BCM5387 reset output  
assign  fp_phy_rst_n         = rw_0x39[4] & cold_reset_n  ;  // front port PHY reset output 
assign  bcm54616_phy_rst_n   = rw_0x39[5] & cold_reset_n  ;  // on-board PHY BCM54616 reset output 
assign  usb_spi_brg_rst_n    = rw_0x39[6] & cold_reset_n & warm_reset_n ;  // reserved bridge
assign  dpll_rst_n           = rw_0x39[7] & cold_reset_n ;  // reserved for dpll module reset


endmodule
