
module reset_reason

( 	
    input 		clk            		          //  clock
,   input       reset_hot_n                 // hot reset output
,   input       reset_warm_n                // warm reset output
,   input       reset_cold_n                // cold reset output

,   input       pd_stby_reset_n             // async standby power on reset, active low, from power1014a, already delayed
,   input       pd_main_reset_n             // async main power on reset, active low, from power1014a, already delayed

//
,   input       pb_reset_neg_pul            // push button reset pulse
,   input       pb_dbg_reset_neg_pul        // on board pus button for debug
,   input       facebook_dbg_reset_neg_pul  // facebook debug reset input
       
,   input       bmc_req_reset_neg_pul       // bmc request reset input                                 
,   input       bmc_reset_th_neg_pul        // bmc reset request to cpld, input #1
,   input       bmc_reset_usrv_neg_pul      // bmc reset request to cpld, input #2
,   input       bmc_reset_main_neg_pul      // bmc reset request to cpld, input #3
,   input       bmc_reset_all_neg_pul       // bmc reset request to cpld, input #4
       
,   input       wdt_reset_1_neg_pul         // wdt_reset_1_neg_pul
,   input       wdt_reset_2_neg_pul         // wdt_reset_2_neg_pul
                                   
,   input       reg_hot_req_pul             // reg 0x30 bit 4 negative edge
,   input       reg_warm_req_pul            // reg 0x30 bit 5 negative edge
,   input       reg_cold_req_pul            // reg 0x30 bit 6 negative edge
,   input       reg_pwr_req_pul             // reg 0x30 bit 7 negative edge 
 
,	output [07:00]	ro_0x0d                 // reset reason register 
,	output [07:00]	ro_0x0e                 //  
,   output [07:00]  ro_0x0f                 // reset reason status bit register
 
) ;

wire reset_cold_n_edge;
pos_edge  reset_cold_n_positive_edge         
(
.clk          (clk),
.rst_n        (1'b1),
.sig_in       (reset_cold_n),
.pos_edge_en  (reset_cold_n_edge) 
) ;    

wire reset_warm_n_edge;
pos_edge  reset_warm_n_positive_edge         
(
.clk          (clk),
.rst_n        (1'b1),
.sig_in       (reset_warm_n),
.pos_edge_en  (reset_warm_n_edge) 
) ;    

wire reset_hot_n_edge;
pos_edge  reset_hot_n_positive_edge         
(
.clk          (clk),
.rst_n        (1'b1),
.sig_in       (reset_hot_n),
.pos_edge_en  (reset_hot_n_edge) 
) ;    

wire  system_reset_n_edge = reset_warm_n_edge | reset_cold_n_edge | reset_hot_n_edge;

//wire  system_reset_n  = reset_cold_n & reset_warm_n & reset_hot_n ;
 
wire pd_stby_reset_n_edge;
pos_edge 	pd_stby_positive_edge         
(
.clk	 		(clk),
.rst_n	 		(1'b1),
.sig_in     	(pd_stby_reset_n),
.pos_edge_en	(pd_stby_reset_n_edge) 
) ;    

wire pd_main_reset_n_edge;
pos_edge  pd_main_positive_edge         
(
.clk      (clk),
.rst_n      (1'b1),
.sig_in       (pd_main_reset_n),
.pos_edge_en  (pd_main_reset_n_edge) 
) ;    

reg	[7:0]	  reset_cause_reg ;
reg         system_reset_n_edge_seq;

    
reg         pd_stby_reset_n_edge_active ; 
reg         pd_main_reset_n_edge_active ;   
 

 
reg         pb_reset_neg_pul_active           ;  // push button reset pulse               
reg         pb_dbg_reset_neg_pul_active       ;  // on board pus button for debug         
reg         facebook_dbg_reset_neg_pul_active ;  // facebook debug reset input            
                                                                              
reg         bmc_req_reset_neg_pul_active      ; // bmc request reset input               
reg         bmc_reset_th_neg_pul_active       ; // bmc reset request to cpld, input #1   
reg         bmc_reset_usrv_neg_pul_active     ; // bmc reset request to cpld, input #2   
reg         bmc_reset_main_neg_pul_active     ; // bmc reset request to cpld, input #3   
reg         bmc_reset_all_neg_pul_active      ; // bmc reset request to cpld, input #4   
                                                                              
reg         wdt_reset_1_neg_pul_active        ; // wdt_reset_1_neg_pul                   
reg         wdt_reset_2_neg_pul_active        ; // wdt_reset_2_neg_pul                   
                                                                               
reg         reg_hot_req_pul_active            ; // reg 0x30 bit 4 negative edge          
reg         reg_warm_req_pul_active           ; // reg 0x30 bit 5 negative edge          
reg         reg_cold_req_pul_active           ; // reg 0x30 bit 6 negative edge          
reg         reg_pwr_req_pul_active            ; // reg 0x30 bit 7 negative edge          
         
          
          




// reset cause register
always @ (posedge clk )
 begin
   system_reset_n_edge_seq <= system_reset_n_edge;
                                                                                                          
                                                                                                                                                                                                                                    
                                                                                                                                           
   if (pd_stby_reset_n_edge)    // standby power on reset, cold reset                                                                      
       pd_stby_reset_n_edge_active <= 1'b1;                                                                                                
   else if (system_reset_n_edge_seq)                                                                                                       
       pd_stby_reset_n_edge_active <= 1'b0;                                                                                                
                                                                                                                               
  if (pd_main_reset_n_edge)    // main power on reset, cold reset                                                                          
       pd_main_reset_n_edge_active <= 1'b1;                                                                                                
   else if (system_reset_n_edge_seq)                                                                                                       
       pd_main_reset_n_edge_active <= 1'b0;   
       
       
       

// reset reason pulse latch, falling edge generate pulse, system reset rising edge latch the status                   
  if (pb_reset_neg_pul && reset_cold_n && reset_warm_n )    //  // push button reset pulse                                        
       pb_reset_neg_pul_active <= 1'b1;                                                                               
   else if (system_reset_n_edge_seq)                                                                                  
       pb_reset_neg_pul_active <= 1'b0;                                                                               
                                                                                                                      
  if (pb_dbg_reset_neg_pul && reset_cold_n && reset_warm_n )     // on board pus button for debug                     
       pb_dbg_reset_neg_pul_active <= 1'b1;                                                                           
   else if (system_reset_n_edge_seq)                                                                                  
       pb_dbg_reset_neg_pul_active <= 1'b0;                                                                           
                                                                                                                      
  if (facebook_dbg_reset_neg_pul && reset_cold_n && reset_warm_n )    // facebook debug reset input                   
       facebook_dbg_reset_neg_pul_active <= 1'b1;                                                                     
   else if (system_reset_n_edge_seq)                                                                                  
       facebook_dbg_reset_neg_pul_active <= 1'b0;     
                                                                       
 // SW cpld write to reset control                                                                                                                     
  if (reg_hot_req_pul && reset_cold_n && reset_warm_n )    //  reg 0x30 bit 4 negative edge  , reset hot                    
       reg_hot_req_pul_active <= 1'b1;                                                                                  
   else if (system_reset_n_edge_seq)
       reg_hot_req_pul_active <= 1'b0;

  if (reg_warm_req_pul && reset_cold_n && reset_warm_n )    //  reg 0x30 bit 5 negative edge  , reset hot                    
       reg_warm_req_pul_active <= 1'b1;                                                                                  
   else if (system_reset_n_edge_seq)
       reg_warm_req_pul_active <= 1'b0;
       
  if (reg_cold_req_pul && reset_cold_n && reset_warm_n )    //  reg 0x30 bit 6 negative edge  , reset hot                    
       reg_cold_req_pul_active <= 1'b1;                                                                                  
   else if (system_reset_n_edge_seq)
       reg_cold_req_pul_active <= 1'b0;
       
  if (reg_pwr_req_pul && reset_cold_n && reset_warm_n )    //  reg 0x30 bit 7 negative edge  , reset hot                    
       reg_pwr_req_pul_active <= 1'b1;                                                                                  
   else if (system_reset_n_edge_seq)
       reg_pwr_req_pul_active <= 1'b0;
       
// BMC reset and WDT reset source              
  if (bmc_req_reset_neg_pul && reset_cold_n && reset_warm_n )    //   bmc request reset input 
       bmc_req_reset_neg_pul_active <= 1'b1;
   else if (system_reset_n_edge_seq)
       bmc_req_reset_neg_pul_active <= 1'b0;
       
   if (bmc_reset_th_neg_pul  && reset_cold_n && reset_warm_n )    //   bmc request reset input 
       bmc_reset_th_neg_pul_active <= 1'b1;
   else if (system_reset_n_edge_seq)
       bmc_reset_th_neg_pul_active <= 1'b0;
       
  if (bmc_reset_usrv_neg_pul  && reset_cold_n && reset_warm_n )    //   bmc request reset input 
       bmc_reset_usrv_neg_pul_active <= 1'b1;
   else if (system_reset_n_edge_seq)
       bmc_reset_usrv_neg_pul_active <= 1'b0;
       
  if (bmc_reset_main_neg_pul && reset_cold_n && reset_warm_n )    //   bmc request reset input 
       bmc_reset_main_neg_pul_active <= 1'b1;
   else if (system_reset_n_edge_seq)
       bmc_reset_main_neg_pul_active <= 1'b0;
       
  if (bmc_reset_all_neg_pul  && reset_cold_n && reset_warm_n )    //   bmc request reset input 
       bmc_reset_all_neg_pul_active <= 1'b1;
   else if (system_reset_n_edge_seq)
       bmc_reset_all_neg_pul_active <= 1'b0;
       
  if (wdt_reset_1_neg_pul  && reset_cold_n && reset_warm_n )    //   bmc wdt1 reset
       wdt_reset_1_neg_pul_active <= 1'b1;
   else if (system_reset_n_edge_seq)
       wdt_reset_1_neg_pul_active <= 1'b0;
       
  if (wdt_reset_2_neg_pul  && reset_cold_n && reset_warm_n )    //   bmc wdt2 reset
       wdt_reset_2_neg_pul_active <= 1'b1;
   else if (system_reset_n_edge_seq)
       wdt_reset_2_neg_pul_active <= 1'b0;      
       
       
end


always @ (posedge clk )    
 begin                 
 
          
  // reset cause status
    
  if       ( system_reset_n_edge &&  pd_stby_reset_n_edge_active )  // power on reset
		 reset_cause_reg 	<= 8'h01 ;
  else if  ( system_reset_n_edge &&  pd_main_reset_n_edge_active && !pd_stby_reset_n_edge_active ) 	
  	     reset_cause_reg 	<= 8'h02 ;   // 
  else if  ( system_reset_n_edge &&  pb_reset_neg_pul_active ) 	
  	     reset_cause_reg 	<= 8'h03 ;	 // push button reset pulse  
  else if  ( system_reset_n_edge &&  pb_dbg_reset_neg_pul_active ) 	
		     reset_cause_reg 	<= 8'h04 ;  //on board pus button for debug 
  else if  ( system_reset_n_edge &&  facebook_dbg_reset_neg_pul_active )  
         reset_cause_reg  <= 8'h05 ;  //facebook debug reset input
  else if  ( system_reset_n_edge &&  reg_hot_req_pul_active  )  
         reset_cause_reg  <= 8'h10 ;  // reg 0x31 bit 4 negative edge   
  else if  ( system_reset_n_edge &&  reg_warm_req_pul_active  )  
         reset_cause_reg  <= 8'h11 ;  // reg 0x31 bit 5 negative edge   
  else if  ( system_reset_n_edge &&  reg_cold_req_pul_active  )  
         reset_cause_reg  <= 8'h12 ;  // reg 0x31 bit 6 negative edge   
  else if  ( system_reset_n_edge &&  reg_pwr_req_pul_active  )  
         reset_cause_reg  <= 8'h13 ;  // reg 0x31 bit 7 negative edge   
  else if  ( system_reset_n_edge &&  bmc_req_reset_neg_pul_active )  
         reset_cause_reg  <= 8'h20 ;  // bmc request reset input   
  else if  ( system_reset_n_edge &&  bmc_reset_th_neg_pul_active )  
         reset_cause_reg  <= 8'h21 ;  // bmc reset request to cpld, input #1
  else if  ( system_reset_n_edge &&  bmc_reset_usrv_neg_pul_active )  
         reset_cause_reg  <= 8'h22 ;  // bmc reset request to cpld, input #2
  else if  ( system_reset_n_edge &&  bmc_reset_main_neg_pul_active )  
         reset_cause_reg  <= 8'h23 ;  // bmc reset request to cpld, input #3
  else if  ( system_reset_n_edge &&  bmc_reset_all_neg_pul_active )  
         reset_cause_reg  <= 8'h24 ;  // bmc reset request to cpld, input #4
  else if  ( system_reset_n_edge &&  wdt_reset_1_neg_pul_active )  
         reset_cause_reg  <= 8'h25 ;  // wdt_reset_1_neg_pul
  else if  ( system_reset_n_edge &&  wdt_reset_2_neg_pul_active )  
         reset_cause_reg  <= 8'h26 ;  // wdt_reset_2_neg_pul        
 
 end		     	

  
 
  
reg  [7:0] ro_0x0e_seq,ro_0x0f_seq;
always @ (posedge clk )
 begin
    if  ( system_reset_n_edge )                                                                                                                
        begin                                                      
           ro_0x0e_seq[0] =  pb_reset_neg_pul_active          ;   // push button reset pulse                    
           ro_0x0e_seq[1] =  pb_dbg_reset_neg_pul_active      ;   // on board push button for debug           
           ro_0x0e_seq[2] =  facebook_dbg_reset_neg_pul_active;   // facebook debug reset input            
           ro_0x0e_seq[3] =  1'b0                             ;               
           ro_0x0e_seq[4] =  reg_hot_req_pul_active    ;          // reg 0x31 bit 4 negative edge                                                                           
           ro_0x0e_seq[5] =  reg_warm_req_pul_active   ;          // reg 0x31 bit 5 negative edge             
           ro_0x0e_seq[6] =  reg_cold_req_pul_active   ;          // reg 0x31 bit 6 negative edge                          
           ro_0x0e_seq[7] =  reg_pwr_req_pul_active    ;          // reg 0x31 bit 7 negative edge
           
           ro_0x0f_seq[0] =  bmc_req_reset_neg_pul_active  ;    // bmc request reset input             
           ro_0x0f_seq[1] =  bmc_reset_th_neg_pul_active   ;    // bmc reset request to cpld, input #1 
           ro_0x0f_seq[2] =  bmc_reset_usrv_neg_pul_active ;    // bmc reset request to cpld, input #2 
           ro_0x0f_seq[3] =  bmc_reset_main_neg_pul_active ;    // bmc reset request to cpld, input #3 
           ro_0x0f_seq[4] =  bmc_reset_all_neg_pul_active  ;    // bmc reset request to cpld, input #4 
           ro_0x0f_seq[5] =  wdt_reset_1_neg_pul_active    ;    // wdt_reset_1_neg_pul                 
           ro_0x0f_seq[6] =  wdt_reset_2_neg_pul_active    ;    // wdt_reset_2_neg_pul                 
           ro_0x0f_seq[7] =  1'b0                          ;
                    
        end      
 
 end

assign	  ro_0x0d	= reset_cause_reg ;
assign    ro_0x0e   = ro_0x0e_seq ; 
assign    ro_0x0f   = ro_0x0f_seq ;  

endmodule


  
                                                                                                                                                                     