//-----------------------------------------------------------------------------
// Title       : UART mux module
// Design      : Wedge100 CPLD Design
// File        : uart_mux.v
//-----------------------------------------------------------------------------
// Version     : Ver 2.0
// Changes     : 1. Removed the unused signals and logic
//-----------------------------------------------------------------------------
// Description:- Uart Mux implementation
//-----------------------------------------------------------------------------

module uart_mux
(
  input  [7:0]   uart_ctrl             // uart mux control, rw_0x26
, input          uart_select_bmc       // DEBUG UART 0 Select line from BMC GPIOE0
, input          uart_select_dbg       // DEBUG UART 0 Select line from fcebook debug header
                 
, input          BMC_UART_1_TX         // bmc uart_1, BMC TX to cpld
, output         BMC_UART_1_RX         // bmc uart_1, cpld to BMC RX
, input          BMC_UART_1_RTS        // bmc uart_1, BMC RTS to cpld
                 
, input          BMC_UART_4_TX         // bmc uart_4, BMC TX to cpld
, output         BMC_UART_4_RX         // bmc uart_4, cpld to BMC RX
, input          BMC_UART_4_RTS        // bmc uart_1, BMC RTS to cpld
                 
, input          BMC_UART_5_TX         // bmc uart_5, BMC TX to cpld
, output         BMC_UART_5_RX         // bmc uart_5, cpld to BMC RX
                                
, input          PANTHER_COM_TX        // panther uart TX to cpld
, output         PANTHER_COM_RX        // panther uart RX, cpld to panther RX
                                     
, input          FB_HDR_UART_RX        // facebook debug header
, output         FB_HDR_UART_TX        // facebook debug header
                                     
, input          REAR_DBG_UART_RX      // facebook debug header
, output         REAR_DBG_UART_TX      // facebook debug header
                                     
, input          RMON_RS485_RX         //  
, output         RMON_RS485_TX         //  
, output         RMON_RS485_RTS        //  

) ;


// BMC UART3 connect to front panel console


/*
always @ (uart_ctrl,BMC_UART_5_TX,BMC_UART_1_TX,PANTHER_COM_TX,FB_HDR_UART_RX ) begin
    if ( (uart_ctrl[0] == 1'b0) )           
        begin
       // panther uart connect to BMC uart 5 in official configuration, but can be routed to FB debug port 
          PANTHER_COM_RX = BMC_UART_5_TX;          // Panther+ to BMC UART5
          BMC_UART_5_RX  = PANTHER_COM_TX;
 
          FB_HDR_UART_TX = BMC_UART_1_TX;          // FB header to BMC UART1
          BMC_UART_1_RX  = FB_HDR_UART_RX;    
       end 
       
    else 
       begin 
       // panther uart connect to BMC uart 5 in official configuration, but can be routed to FB debug port 
          BMC_UART_1_RX = BMC_UART_5_TX  ;        // BMC UART1 to BMC UART5                                                           
          BMC_UART_5_RX = BMC_UART_1_TX  ;                                 
                                                                           
          PANTHER_COM_RX = FB_HDR_UART_RX;        // FB header to PANTHER+                                  
          FB_HDR_UART_TX = PANTHER_COM_TX;                                                                 
       end                                                   
       
    
end

*/

wire   uart_dbg_sel;
assign uart_dbg_sel   = (uart_ctrl[1:0] == 2'b00) ? uart_select_bmc:           // use uart_select_bmc 
                        (uart_ctrl[1:0] == 2'b01) ? uart_select_dbg:           // use uart_select_dbg 
                        (uart_ctrl[1:0] == 2'b10) ? 1'b0 :                     // force to use bit0 to select                                     
                        (uart_ctrl[1:0] == 2'b11) ? 1'b1 : 1'b0 ;              // force to use bit0 to select 


// DEBUG_UART_SEL_0 = 0: PANTHER <=> FB_HDR_UART ; 
// DEBUG_UART_SEL_0 = 1: PANTHER <=> BMC_UART_1;  BMC_UART_5 <=> FB_HDR_UART

assign PANTHER_COM_RX = uart_dbg_sel  ? BMC_UART_1_TX  : FB_HDR_UART_RX ;
assign BMC_UART_5_RX  = uart_dbg_sel  ? FB_HDR_UART_RX : 1'b1  ;        

assign FB_HDR_UART_TX = uart_dbg_sel  ? BMC_UART_5_TX  : PANTHER_COM_TX;
assign BMC_UART_1_RX  = uart_dbg_sel  ? PANTHER_COM_TX : 1'b1          ;




// RMON uart connect to RS485 port, BMC uart 4
assign  BMC_UART_4_RX  = RMON_RS485_RX ; 
assign  RMON_RS485_TX  = BMC_UART_4_TX ;  
assign  RMON_RS485_RTS = BMC_UART_4_RTS;

 
endmodule		     