//-----------------------------------------------------------------------------
// Title       : Wedge100 CPLD Design top module
// Design      : Wedge100 CPLD Design
// File        : wedge100_syscpld_top.v
//-----------------------------------------------------------------------------
// Version     : Ver 1.0
// Changes     : 1. First version
//-----------------------------------------------------------------------------
// Version     : Ver 1.1
// Generated   : 26/05/2015
// Changes     : 1. Parameters Added to Top Module
//-----------------------------------------------------------------------------
// Version     : Ver 1.2
// Generated   : 29/05/2015
// Changes     : 1. ro_0x02 - subrevision -03
//             : 2. ro_0x08 - was updated as Card Present Signal status - earlier this was done to 0x06
//                  Here some signals are already mapped to ro_0x10 - PSU1,2 PRSNT
//             : 3. rw_0x2c and rw_0x2d were used for GPIO Direction and Data Register
//             : 5. CPLD_SPI_SEC_BOOT_WP_N = BMC_SPI_WP_N was added with a write protect logic.
//             : 6. MSERVE_ISOBUF_EN       = BMC_MSERVE_ISOBUF_EN was added with a write protect logic.
//             : 7. ISO_BUF_EN             = BMC_ISO_BUF_EN was added with a write protect logic.
//             : 8. rw_0x32[0] was removed from DUAL BOOT EN control - 0x2f[0] is used
//             : 9. rst_pwr_n was assigned from different logic than cold_reset_n
//             :10. rw_0x26 - is UART control register insteadof rw_0x25
//             :11. rw_0x25 is given for irq controller
//             :12. rw_0x3b bit[3:5] for debug enable/disable
//-----------------------------------------------------------------------------
// Version     : Ver 2.0
// Generated   : 03/12/2015
// Changes     : 1. Added the 22 additional signals
//             : 2. Removed the unused signals mentioned in excel sheet
//             : 3. Changed the name of signals that are level shifted and those mentioned in excel sheet
//             : 4. Added read only register ro_0x40 MISC Interrupt status register 
//             : 5. Added read only register ro_0x42 PLL_CLOCK_LOCK[2:0] to read the Xpliant PLL Lock status 
//             : 6. Added read only register ro_0x43 to read the GPIO read data 
//             : 7. Added write register rw_0x41[2:0] to enable the MISC interrupts
//             : 8. Added write register rw_0x44[2:0] to reset the Xpliant Clock PLL(CLK_PLL_RESET[2:0] register)
//             : 9. Added write register rw_0x45[2:0] to write to the GPIO register
//-----------------------------------------------------------------------------
// Version     : Ver 2.1
// Generated   : 02/02/2016
// Changes     : 1. Added the LED shift register implementation signals
//             : 2. Added a write register rw_0x46[1:0] to select the LED implementation speed
//-----------------------------------------------------------------------------
// Description:- Wedge100 CPLD Design top module which instantiates all other
//               interface top modules
//-----------------------------------------------------------------------------

// `include "wedge100_syscpld_def.v"



/*
    facebook wedge100
    Model: 
    Revision: V0.1, 
    History :
    2015/02/26 - Draft
    
     
    

*/

// `include "wedge100_syscpld_def.v"

module wedge100_syscpld_top   #
(
    parameter [27:00]   PULSE_WIDTH_HOT    = 5000000 , // 100ms - clock= 50MHz
    parameter [27:00]   PULSE_WIDTH_WARM   = 10000000, // 200ms - clock= 50MHz
    parameter [27:00]   PULSE_WIDTH_COLD   = 19000000, // 380ms - clock= 50MHz
    parameter [27:00]   PULSE_WID_BMC_MAIN = 1000000 , // 20ms  - clock= 50MHz
    parameter [27:00]   PULSE_WID_PUSH_BTN = 1000000 , // 20ms  - clock= 50MHz
    parameter           SW_DEB_LEN         = 32      , // Switch Debounce time - 32:=> 640ns if clk = 50Hz
    parameter  [6:0]    MAIN_I2C_DevADDR   = 7'h32   , // Main I2C Slave Address
    parameter  [6:0]    BMC_I2C_DevADDR    = 7'h31   , // BMC I2C Slave Address
    parameter  [7:0]    MAIN_End_Of_ADDR   = 8'hFF   , // Main I2C Slave End Address
    parameter  [7:0]    BMC_End_Of_ADDR    = 8'hFF   , // BMC I2C Slave End Address

    //parameter           CPLD_REVISION      = 8'd3      // zyao: wedge100 initial revision
	 parameter           CPLD_REVISION      = 8'd4
)

(
 
  input	    clk                     // 50mhz clock input

// Xpliant GPIO Interface
, inout     ISO_XP_GPIO_0          // Xpliant GPIO signal
, inout     ISO_XP_GPIO_1          // Xpliant GPIO signal
, inout     ISO_XP_GPIO_2          // Xpliant GPIO signal
, inout     ISO_XP_GPIO_3          // Xpliant GPIO signal
        
, output    ISO_XP_CORE_CLK_PLL_RST_N // Core Clock PLL reset.When low core clock pll is reset
, output    ISO_XP_MAC_CLK_PLL_RST_N  // Mac Clock PLL reset.When low mac clock pll is reset
, output    ISO_XP_PEX_CLK_PLL_RST_N  // PEX Clock PLL reset.When low pex clock pll is reset

, input     ISO_XP_CORE_PLL_LOCK    // Core clock PLL lock indication 0-not locked,1- locked
, input     ISO_XP_MAC_PLL_LOCK     // Mac clock PLL lock indication 0-not locked,1- locked
, input     ISO_XP_PEX_PLL_LOCK     // PEX clock PLL lock indication 0-not locked,1- locked  

, input 	ISO_XP_REI_INIT_DONE	// REI INIT DONE OUTPUT
, input 	ISO_XP_INT_N	        // XPLIANT INTERRUPT SIGNAL
, input 	ISO_XP_OVERT_N	        // XLIPANT TEMP SENSOR OUTPUT
, input 	ISO_XP_TEMP_ALRT_N	    // XLIPANT TEMP SENSOR OUTPUT

// led stream signals
, input     ISO_XP_LED_CLK          // LED Stream Interface Clock input
, input     ISO_XP_LED_DAT          // LED Data, synchronized to LED_CLK input 
, input     ISO_XP_LED_STB          // LED Strobe, synchronized to LED_CLK input
, input     CPLD_QSFP_LED_POSITION  // push button led position selection
 		
, output    LED_CLK0_BUF_EN         // led stream 0 ISO buffer enable      (* chip_pin = "M10"  *)
, output    LED_CLEAR0              // led stream 0 clear                  (* chip_pin = "P10"  *)
, output    LED_CLK0                // led stream 0 clock output           (* chip_pin = "N10"  *)
, output    LED_DATA0               // led stream 0 data output            (* chip_pin = "T11"  *)
                                                                                                                                                                                                    
// main i2c bus                                 
, inout	    MAIN_I2C_SDA            // I2C Bus controlled by micro-server  (* chip_pin = "T9"  *) 
, inout	    MAIN_I2C_SCL            // I2C Bus controlled by micro-server  (* chip_pin = "T8"  *) 
// BMC cpld i2c bus                                
, inout     BMC_CPLD_SDA            // I2C Bus to BMC                     (* chip_pin = "R8"  *)
, inout     BMC_CPLD_SCL            // I2C Bus to BMC                     (* chip_pin = "N8"  *)                                
                                  
// gpio to USB-I2C bridge CP2112  rw_0x1f, rw_0x2c, rw_0x2d
, inout     LS_CP2112_CPLD_GPIO1    // GPIO1   (* chip_pin = "M3"  *)
, inout     LS_CP2112_CPLD_GPIO0    // GPIO0   (* chip_pin = "N2"  *)

// --------------------------------------------------------
// psu signals
, input     PSU1_PRSNT_N            // psu-1 present, active low        (* chip_pin = "D10" *) 
, input     PSU1_PWR_OK             // psu-1 power ok                   (* chip_pin = "B10" *) 
, input     PSU1_INPUT_OK           // psu-1 input power ok             (* chip_pin = "E8"  *) 
, input     PSU1_SMB_ALERT_N        // psu-1 sm bus alert, active low   (* chip_pin = "A6"  *) 
                                                                                               
, input     PSU2_PRSNT_N            // psu-2 present, active low        (* chip_pin = "C6"  *) 
, input     PSU2_PWR_OK             // psu-2 power ok                   (* chip_pin = "B3"  *) 
, input     PSU2_INPUT_OK           // psu-2 input power ok             (* chip_pin = "D5"  *) 
, input     PSU2_SMB_ALERT_N        // psu-2 sm bus alert, active low   (* chip_pin = "A2"  *) 


// power status input    0x21      

, input	    P1V2_STBY_OK            // 1.2V standby power OK (* chip_pin = "N6"  *)     
                                                                                         
, output    PWR_STBY_OK             //  standby power OK(* chip_pin = "R5"  *)       to PWR1014A PWR_STBY_OK input

// IR power status, 0x22 
, input     VCORE_VRDY1             // Vcore voltage ready status               (* chip_pin = "M6"  *)
, input     VCORE_HOT               // over temperature or over current alarm   (* chip_pin = "T5"  *)
, input     VANLG_VRDY1             //                                          (* chip_pin = "R6"  *)
, input     VANLG_HOT               // over temperature or over current alarm   (* chip_pin = "N7"  *)
, input     V3V3_VRDY1              //                                          (* chip_pin = "R7"  *)
, input     V3V3_HOT                // over temperature or over current alarm   (* chip_pin = "P8"  *)

// interrupt signals, 0x22
, input	    I2C_IO_0_INT_N          // I2C IO device PCA9535 Interrupt  (* chip_pin = "R13"  *) 
, input	    I2C_IO_1_INT_N          // I2C IO device PCA9535 Interrupt  (* chip_pin = "N12"  *) 
, input	    I2C_IO_2_INT_N          // I2C IO device PCA9535 Interrupt  (* chip_pin = "R14"  *) 
, input	    I2C_IO_3_INT_N          // I2C IO device PCA9535 Interrupt  (* chip_pin = "P12"  *) 
, input	    I2C_IO_4_INT_N          // I2C IO device PCA9535 Interrupt  (* chip_pin = "T15"  *) 
, input	    I2C_IO_5_INT_N          // I2C IO device PCA9535 Interrupt  (* chip_pin = "R16"  *) 
 
//------------------------------------------------------------------------                                 
 
                                  
// misc control signals  rw_0x2f     
, output    DUAL_BOOT_EN          //  enable dual boot      (* chip_pin = "T7"  *)
 
// micro-server signals
, input     MICROSRV_PRSNT_N      // micro-server present_n       (* chip_pin = "C8"  *)    => ro_0x08
, input     MICROSRV_PCIE_RST_N   // micro-server reset output    (* chip_pin = "E7"  *)    => micro-server PCIe reset request, input of cpld
, output    MICROSRV_PWR_BTN_N    // micro-server reset output    (* chip_pin = "B6"  *)     => cpld output to micro-server BTN_IN pin
, input     MSERV_POWERUP         // micro-server power up enable (* chip_pin = "D7"  *) => this is BMC driven signal,  

                                                                   
//  Reset control                                                   
, input     PD_STBY_RESET_N       // standby reset input from pwr1014a    (* chip_pin = "L12"  *)
, input     PD_MAIN_RESET_N       // main power reset input from pwr1014a (* chip_pin = "E2"  *) 

, input     BMC_MAIN_RESET_N      // BMC request to reset the system (* chip_pin = "F5"  *) 
                                  
, output    P0_QRESET_N           // Reset output to QSFP port 0    (* chip_pin = "B8"  *) 
, output    P1_QRESET_N           // Reset output to QSFP port 1    (* chip_pin = "A8"  *) 
, output    P2_QRESET_N           // Reset output to QSFP port 2    (* chip_pin = "D8"  *) 
, output    P3_QRESET_N           // Reset output to QSFP port 3    (* chip_pin = "A7"  *) 
, output    P4_QRESET_N           // Reset output to QSFP port 4    (* chip_pin = "F13"  *)
, output    P5_QRESET_N           // Reset output to QSFP port 5    (* chip_pin = "E15"  *)
, output    P6_QRESET_N           // Reset output to QSFP port 6    (* chip_pin = "F14"  *)
, output    P7_QRESET_N           // Reset output to QSFP port 7    (* chip_pin = "D16"  *)
, output    P8_QRESET_N           // Reset output to QSFP port 8    (* chip_pin = "E12"  *)
, output    P9_QRESET_N           // Reset output to QSFP port 9    (* chip_pin = "D15"  *)
, output    P10_QRESET_N          // Reset output to QSFP port 10   (* chip_pin = "C15"  *)
, output    P11_QRESET_N          // Reset output to QSFP port 11   (* chip_pin = "E13"  *)
, output    P12_QRESET_N          // Reset output to QSFP port 12   (* chip_pin = "E14"  *)
, output    P13_QRESET_N          // Reset output to QSFP port 13   (* chip_pin = "C14"  *)
, output    P14_QRESET_N          // Reset output to QSFP port 14   (* chip_pin = "C13"  *)
, output    P15_QRESET_N          // Reset output to QSFP port 15   (* chip_pin = "B16"  *)
, output    P16_QRESET_N          // Reset output to QSFP port 16   (* chip_pin = "D12"  *)
, output    P17_QRESET_N          // Reset output to QSFP port 17   (* chip_pin = "B14"  *)
, output    P18_QRESET_N          // Reset output to QSFP port 18   (* chip_pin = "C11"  *)
, output    P19_QRESET_N          // Reset output to QSFP port 19   (* chip_pin = "B13"  *)
, output    P20_QRESET_N          // Reset output to QSFP port 20   (* chip_pin = "E11"  *)
, output    P21_QRESET_N          // Reset output to QSFP port 21   (* chip_pin = "B12"  *)
, output    P22_QRESET_N          // Reset output to QSFP port 22   (* chip_pin = "B11"  *)
, output    P23_QRESET_N          // Reset output to QSFP port 23   (* chip_pin = "A12"  *)
, output    P24_QRESET_N          // Reset output to QSFP port 24   (* chip_pin = "E10"  *)
, output    P25_QRESET_N          // Reset output to QSFP port 25   (* chip_pin = "A11"  *)
, output    P26_QRESET_N          // Reset output to QSFP port 26   (* chip_pin = "A10"  *)
, output    P27_QRESET_N          // Reset output to QSFP port 27   (* chip_pin = "C9"  *) 
, output    P28_QRESET_N          // Reset output to QSFP port 28   (* chip_pin = "B9"  *) 
, output    P29_QRESET_N          // Reset output to QSFP port 29   (* chip_pin = "D9"  *) 
, output    P30_QRESET_N          // Reset output to QSFP port 30   (* chip_pin = "A9"  *) 
, output    P31_QRESET_N          // Reset output to QSFP port 31   (* chip_pin = "E9"  *) 
                                                                                           
, output    USB_BRDG_RST_N        // usb bridge reset output        (* chip_pin = "M14"  *)
, output    USB_HUB_RST_N         // usb hub reset output           (* chip_pin = "K12"  *)
, output    FANCARD_RST_N         // fan_ctrl card reset output     (* chip_pin = "M11"  *)
 	

, output    MICROSRV_RST_N        // micro-server reset output          (* chip_pin = "K4"  *) 
, output    ISO_XPLIANT_RST_N     // tomahawk reset output              (* chip_pin = "L4"  *) 
, output    BCM5387_RST_N         // OOB switch BCM5387 reset output    (* chip_pin = "N9"  *) 
, output    FP_PHY_RST_N          // front port PHY reset output        (* chip_pin = "F11" *)
, output    BCM54616_PHY_RST_N    // on-board PHY BCM54616 reset output (* chip_pin = "T10" *)
, output    LS_USB_SPI_BRIDGE_RST_N  // usb to spi bridge reset signal  (* chip_pin = "D11" *) 
                                                                                                       
, output    I2C_MUX_RST0_N        // i2c mux 0 reset output                     (* chip_pin = "D4"  *) 
, output    I2C_MUX_RST1_N        // i2c mux 1 reset output                     (* chip_pin = "B1"  *) 
, output    I2C_MUX_RST2_N        // i2c mux 2 reset output                     (* chip_pin = "C5"  *) 
, output    I2C_MUX_RST3_N        // i2c mux 3 reset output                     (* chip_pin = "C4"  *) 
, output    I2C_MUX_PSU_RST_N     // i2c mux for psu reset output               (* chip_pin = "D13" *)
, output    I2C_MUX_EXP_RST_N     // i2c mux for qsfp LLI signals reset output  (* chip_pin = "M12" *)
                                  
// power control signals              
, output    PWR_CYC_ALL_N         // power cycle output to pwr1014a, power cycle all power, pulse signal (* chip_pin = "H1"  *)  
, output    PWR_MAIN_EN           // enable main power, active high, 1: enable. 0: disable               (* chip_pin = "D14" *) 
, output    PWR_MAIN_FORCE        // force main power, debug only, should not change by SW               (* chip_pin = "L5"  *)  
, output    PWR_MSERVER_FORCE     // force micro-server power, debug only, should not change by SW       (* chip_pin = "F12" *)   rw_0x30[2] can enable or disable this, active high to enable 12V to microserver
, input     XP_POWERUP            // tomahawk power up     from BMC GPIOM3                               (* chip_pin = "A5"  *)  
 	                                                                                                                                      
, input     BMC_UART_1_TX         // bmc uart_1, BMC TX to cpld           (* chip_pin = "K5"  *)  
, output    BMC_UART_1_RX         // bmc uart_1, cpld to BMC RX           (* chip_pin = "L1"  *)  
, input     BMC_UART_1_RTS        // bmc uart_1, BMC RTS to cpld          (* chip_pin = "J1"  *)  
                                                                                                  
, input     BMC_UART_4_TX         // bmc uart_4, BMC TX to cpld           (* chip_pin = "L2"  *)  
, output    BMC_UART_4_RX         // bmc uart_4, cpld to BMC RX           (* chip_pin = "K3"  *)  
, input     BMC_UART_4_RTS        // bmc uart_1, BMC RTS to cpld          (* chip_pin = "H4"  *)  
                                                                                                  
, input     BMC_UART_5_TX         // bmc uart_5, BMC TX to cpld           (* chip_pin = "M1"  *)  
, output    BMC_UART_5_RX         // bmc uart_5, cpld to BMC RX           (* chip_pin = "M2"  *)  
                                                                                                  
                                                                                                  
, inout    PANTHER_COM_TX         // panther uart TX to cpld             (* chip_pin = "R3"  *)  
, output    PANTHER_COM_RX         // panther uart RX, cpld to panther RX (* chip_pin = "N5"  *)  
                                                                                                      
                                                                                                      
, input     FB_HDR_UART_RX         // facebook debug header               (* chip_pin = "N15"  *) 
, output    FB_HDR_UART_TX         // facebook debug header               (* chip_pin = "N14"  *) 
                                                                                                       
, input     REAR_DBG_UART_RX       // facebook debug header               (* chip_pin = "N16"  *) 
, output    REAR_DBG_UART_TX       // facebook debug header               (* chip_pin = "M13"  *) 
                                                                                                       
, input     RMON_RS485_RX          // rackmon connector                   (* chip_pin = "M15"  *) 
, output    RMON_RS485_TX          // rackmon connector                   (* chip_pin = "L14"  *) 
, output    RMON_RS485_RTS         // rackmon connector                   (* chip_pin = "L13"  *) 
 

//board ID signals    ro_0x00                              
, input	    BOARD_REV_ID0          // board revision ID        (* chip_pin = "K15"  *)
, input     BOARD_REV_ID1          // board revision ID        (* chip_pin = "K14"  *)
, input     BOARD_REV_ID2          // board revision ID        (* chip_pin = "L16"  *)
   	                              
  	                                                                                                	                          
//	system LED signals          
, output    SYS_LED1_GREEN         // system led 1, green     (* chip_pin = "J15"  *)
, output    SYS_LED1_BLUE          // system led 1, blue      (* chip_pin = "J14"  *)
, output    SYS_LED1_RED           // system led 1, red       (* chip_pin = "J16"  *)
                                                                                     
, output    SYS_LED2_GREEN         // system led 2, green     (* chip_pin = "J13"  *)
, output    SYS_LED2_BLUE          // system led 2, blue      (* chip_pin = "H16"  *)
, output    SYS_LED2_RED           // system led 2, red       (* chip_pin = "H13"  *)

//      rest of signals
, output    BMC_RST_N                   // BMC reset signal                                               (* chip_pin = "B7"  *)  
                                                                                                                                
, input	    BMC_HEARTBEAT_N             // BMC power good signal from BMC                                 (* chip_pin = "J2"  *)  ????????                                                                                                                                
, input	    BMC_PWR_BTN_OUT_N           // pwr btn out from bmc GPIOD1 pin D16                            (* chip_pin = "H3"  *)   this is driven by BMC, CPLD input
, input     BMC_PWR_BTN_IN_N            // pwr btn input, it is on board psh button out, cpld input       (* chip_pin = "G5"  *)   SW2, PUSHBUT1, this signal also go to BMC GPIOD0, pin A18 this signal connect to BMC and CPLD at the same time
, input	    BMC_READY_N                 // BMC ready signal                                               (* chip_pin = "H2"  *)  BMCGPIOP7  
                                           
// QSFP selection LED                                                                                                                                 
, output    BOTTOM_QSFP_SEL_STATUS_LED  // bottom qsfp selection status                                   (* chip_pin = "B4"  *)  
, output    TOP_QSFP_SEL_STATUS_LED     // top qsfp selection status                                      (* chip_pin = "D6"  *)  
                                                                                                                                  
, output    BMC_CPLD_POWER_INT          // power interupt signal from BMC                                 (* chip_pin = "G16"  *)    used as interrupt to BMC, power status failure interrupt
                                           
, input	    PM_SM_ALERT_N               // sm bus alert from power manager                                (* chip_pin = "G13"  *) 
, input	    VCORE_SMB_ALERT             // VCORE supply sm bus alert                                      (* chip_pin = "G14"  *) 
, input	    V3_3V_SMB_ALERT             // V3_3V supply sm bus alert                                      (* chip_pin = "E16"  *) 
, input	    VANLG_SMB_ALERT             // VANLG supply sm bus alert                                      (* chip_pin = "F15"  *) 

, output    SMB_ALERT                   // logical OR of power supply sm bus alert to bmc                 (* chip_pin = "F16"  *) 

// , output    CPLD_IN3                    // spare interupt to power manager                                (* chip_pin = "G15"  *)    reserved for PWR1014A control input, set to 1, 0x2F control
                                                                                                                                 
, input	    CARD_PRNT_N                 // card present signal from rackmon connector                     (* chip_pin = "M16"  *) 
                                                                                                                                  
, input	    TEMP_SENSOR_ALERT           // temperature sensor alert signal                                (* chip_pin = "L11"  *) 
                                                                                                                                  
, output    BMC_CPLD_QSFP_INT           // interupt from cpld to BMC                                      (* chip_pin = "H14"  *) 
                                                                                                                                  
, input	    BMC_ISO_BUF_EN              // Request from BMC to enable isolation buffers                   (* chip_pin = "M4"  *)    used for power related filtering
, input	    BMC_MSERVE_ISOBUF_EN        // request from BMC to enable microserver isolation buffer        (* chip_pin = "P7"  *)  
, output    ISO_BUF_EN                  // isolation buffer enable                                        (* chip_pin = "L4"  *)  
, output    MSERVE_ISOBUF_EN            // Mserve isolation buffer enable                                 (* chip_pin = "M7"  *)    ???
, output    LS_BMC_COM_ISOBUF_EN            // EVTB COM-e test card isolation buffer enable                   (* chip_pin = "P6"  *) 
                                                                                                                                 
, input	    LS_BMC_WDTRST1              // BMC watch dog timer reset output                               (* chip_pin = "B5"  *)  
, input	    LS_BMC_WDTRST2              // BMC watch dog timer reset output                               (* chip_pin = "E6"  *)  

// debug control register 0x2f control
, input	    BMC_SPI_WP_N                // bmc request to enable  write protect of Secondary boot device  (* chip_pin = "K1"  *)  ?? control debug register
, output    CPLD_SPI_SEC_BOOT_WP_N      //  Secondary boot device write protect enable                   (* chip_pin = "J4"  *)  ?? control debug register
                                                                                                                                 
, input	    BMC_CPLD_RESET1             // spare reset signal from BMC                                    (* chip_pin = "J3"  *)  
, input	    BMC_CPLD_RESET2             // spare reset signal from BMC                                    (* chip_pin = "K2"  *)  
, input	    LS_BMC_CPLD_RESET3          // spare reset signal from BMC                                    (* chip_pin = "L3"  *)  
, input	    LS_BMC_CPLD_RESET4          // spare reset signal from BMC                                    (* chip_pin = "N1"  *)  
, input	    LS_BMC_CPLD_SPARE7          // spare signal from BMC                                          (* chip_pin = "G12" *) 

// push button signal input                                                                                                                                
, input	    PUSHBUTTON_RST_N            // front panel push btn reset                                    (* chip_pin = "K16" *) 
, input	    CPLD_PUSH_BTN_RST_IN_N      // on board debug reset btn, used to enable/disable usrv when BMC is not ready                         (* chip_pin = "L15" *) 
, input     DEBUG_RST_BTN_N             // Debug Reset button from FB header pressed, DEBUG_RST_BTN_N will become low, need pullup             (* chip_pin = "A15"  *) 
                                                                                                                                
, output    LS_DPLL_RST_N               // DPLL rst signal                                               (* chip_pin = "P14" *) 
// , output    DPLL_CLK_SEL                // DPLL clock selection                                          (* chip_pin = "P15" *) 

                                                                                                                                                                         
, input     DEBUG_PORT_UART_SEL_N       // Debug port select button in Front panel is pressed DEBUG_PORT_UART_SEL_N becomes low                 (* chip_pin = "C12"  *)    FB debug dongle
, input     DEBUG_UART_SEL_0            // debug port uart selection from BMC pin D15(GPIOE0)            (* chip_pin = "A13"  *) 

// DVTA new signals
//reg_0x14[4]
, input 	TPM_SPI_PIRQ_N	           //  (* chip_pin = "M9"	*)   Interupt from TPM based SPI module(Active Low)	CPLD_DEBUG4(testpoint)	Testpoint
// reg 0x28                                                                  
, output	TPM_LPC_RST_N	           //  (* chip_pin = "F4"	*)   Reset output for TPM based LPC module(Active Low)	CPLD_DEBUG7(testpoint)	Testpoint
, output	LS_TPM_SPI_RST_N	       //  (* chip_pin = "F2"	*)   Reset output for TPM based SPI module(Active Low)	CPLD_DEBUG8(testpoint)	Testpoint
, output	LS_CPLD_COM_PHY_RST_N	   //  (* chip_pin = "K4"	*)   COMe reset output(Active Low)	NC	NC 
, output	LS_LPC_RST_N	           //  (* chip_pin = "C7"	*)   BMC LPC reset output(Active Low)	NC	NC
                                                               
, output	LS_COM_NIC_ISOBUF_EN	   //  (* chip_pin = "N3"	*)   COMe SMBUS isolation buffer enable(Active Low)	CP2112_CPLD_GPIO2	GPIO to CP2112
, output	LS_COM_PANTHER_ISOBUF_EN   //  (* chip_pin = "P2"	*)   COMe I2C isolation buffer enable(Active Low)	CP2112_CPLD_GPIO3	GPIO to CP2112
, output	LS_COM_PWROK	           //  (* chip_pin = "K13"	*)   Power ok signal to COMe Module	                CPLD_DEBUG6(testpoint)	Testpoint
// reg_0x18                                                                                                                                
, input	    LS_B_COM_TYPE0	           //  (* chip_pin = "R1"	*)   Type signal from COMe	         CP2112_CPLD_GPIO4	GPIO to CP2112
, input	    LS_B_COM_TYPE1	           //  (* chip_pin = "P4"	*)   Type signal from COMe	         CP2112_CPLD_GPIO5	GPIO to CP2112
, input	    LS_B_COM_TYPE2	           //  (* chip_pin = "T2"	*)   Type signal from COMe	         CP2112_CPLD_GPIO6	GPIO to CP2112
, input 	LS_COM_GBE0_LINK1000_N	   //  (* chip_pin = "P13"	*)   Gigabit ethernet link input from COMe(Active Low)	CPLD_DEBUG5(testpoint)	Testpoint
                                                               
, input	    COM_SUS_STAT_N	           //  (* chip_pin = "N13"	*)   Sleep status signal from COMe	NC	NC
, input	    LS_COM_SUS_S3_N	           //  (* chip_pin = "P5"	*)   Sleep status signal from COMe	 CP2112_CPLD_GPIO7	GPIO to CP2112
, input	    COM_SUS_S4_N	           //  (* chip_pin = "J5"	*)   Sleep status signal from COMe	NC	NC
, input	    COM_SUS_S5_N	           //  (* chip_pin = "A4"	*)   Sleep status signal from COMe	NC	NC
// reg_0x29                                                                   
, output	LS_BMC_PHY_WP	           //  (* chip_pin = "J12"	*)  "BMC PHY write protect signal  1:Disable,  0:Enable"	NC	NC                             
, output	LS_FP_PHY_WP	           //  (* chip_pin = "H12"	*)  "Front panel  PHY write protect signal 1:Disable,  0:Enable"	NC	NC                               
, output	CPLD_BMC_SPIBOOT_WP_N	   //  (* chip_pin = "G15"	*)  "BMC Spi boot write protect signal, 1:Disable, 0:Enable"	CPLD_IN3	Spare interupt  input to Powermanager  
                                                                   


, output [7:0] debug_out                                                                                                                                                                         
  
);

 

//============================  clock =====================================


 
wire  clk_10hz,clk_1hz;                                 
wire  pd_main_ok;
wire  usrv_uart_iso_en ;
reg   pd_main_reset_n_seq,pd_main_reset_n_2seq;   
 
//frequency generator    
//freq_divider    f100hz (.iCLK (clk    ),.iRESET (1'b1),.DIVIDER_CNT(27'd250000),.clk_by_divider(clk_100hz) ) ;
//freq_divider    f1hz   (.iCLK (clk    ),.iRESET (1'b1),.DIVIDER_CNT(27'd25000000),.clk_by_divider(clk_1hz) ) ;

// input clock is 50mhz
freq_divider    f10hz (.iCLK (clk),.iRESET (1'b1),.DIVIDER_CNT(27'd5000000),.clk_by_divider(clk_10hz) ) ;  // 50mhz/10hz = 5m
freq_divider    f1hz  (.iCLK (clk_10hz),.iRESET (1'b1),.DIVIDER_CNT(27'd10),.clk_by_divider(clk_1hz)  ) ;

wire  pd_main_rst_n_dly1 = pd_main_reset_n_seq ;
wire  pd_main_rst_n_dly2 = pd_main_reset_n_2seq;               

wire  pd_main_ok_delay  = pd_main_rst_n_dly2 & pd_main_ok ;
 

wire	[7:0]	ro_0x00;
wire    [7:0]   ro_0x01;  
wire    [7:0]   ro_0x02;  
wire    [7:0]   ro_0x03;  
wire    [7:0]   ro_0x04;  
wire    [7:0]   ro_0x05;  
wire    [7:0]   ro_0x06;  
wire    [7:0]   ro_0x07;  
wire    [7:0]   ro_0x08;  
wire    [7:0]   ro_0x09;  
wire    [7:0]   ro_0x0a;  
wire    [7:0]   ro_0x0b;  
wire    [7:0]   ro_0x0c;  
wire    [7:0]   ro_0x0d;  
wire    [7:0]   ro_0x0e;  
wire    [7:0]   ro_0x0f;  
 
wire    [7:0]   ro_0x10;  
wire    [7:0]   ro_0x11;  
wire    [7:0]   ro_0x12;  
wire    [7:0]   ro_0x13;  
wire    [7:0]   ro_0x14;  
wire    [7:0]   ro_0x15;  
wire    [7:0]   ro_0x16;  
wire    [7:0]   ro_0x17;  
wire    [7:0]   ro_0x18;  
wire    [7:0]   ro_0x19;  
wire    [7:0]   ro_0x1a;  
wire    [7:0]   ro_0x1b;  
wire    [7:0]   ro_0x1c;  
wire    [7:0]   ro_0x1d;  
wire    [7:0]   ro_0x1e;  
wire    [7:0]   ro_0x1f;   
 

wire	[7:0]	rw_0x20;
wire    [7:0]   rw_0x21;  
wire    [7:0]   rw_0x22;  
wire    [7:0]   rw_0x23;  
wire    [7:0]   rw_0x24;  
wire    [7:0]   rw_0x25;  
wire    [7:0]   rw_0x26;  
wire    [7:0]   rw_0x27;  
wire    [7:0]   rw_0x28;  
wire    [7:0]   rw_0x29;  
wire    [7:0]   rw_0x2a;  
wire    [7:0]   rw_0x2b;  
wire    [7:0]   rw_0x2c;  
wire    [7:0]   rw_0x2d;  
wire    [7:0]   rw_0x2e;  
wire    [7:0]   rw_0x2f;  
 
wire    [7:0]   rw_0x30;  
wire    [7:0]   rw_0x31;  
wire    [7:0]   rw_0x32;  
wire    [7:0]   rw_0x33;  
wire    [7:0]   rw_0x34;  
wire    [7:0]   rw_0x35;  
wire    [7:0]   rw_0x36;  
wire    [7:0]   rw_0x37;  
wire    [7:0]   rw_0x38;  
wire    [7:0]   rw_0x39;  
wire    [7:0]   rw_0x3a;  
wire    [7:0]   rw_0x3b;  
wire    [7:0]   rw_0x3c;  
wire    [7:0]   rw_0x3d;  
wire    [7:0]   rw_0x3e;  
wire    [7:0]   rw_0x3f;   
 
// newly added registers
wire    [7:0]   ro_0x40;  
wire    [7:0]   ro_0x42;  
wire    [7:0]   ro_0x43;  
wire    [7:0]   rw_0x41;  
wire    [7:0]   rw_0x44;  
wire    [7:0]   rw_0x45; 
wire    [7:0]   rw_0x46; 

reg       rst_self_n;
reg [5:0] self_rst_cnt;  
wire  rst_pwr_n = rst_self_n; 

wire  hot_reset_n  ;
wire  warm_reset_n ;
wire  cold_reset_n ;
wire  pd_usrv_delay =  rw_0x28[7];    // 1: delay, 0: no delay 
wire  wr_0x31_en_buf;
 
//--------------------------------------------------------------------------------------------------- 

//Reg_0x00 Board type & revision
wire    [3:0]   board_rev   = {1'b0,BOARD_REV_ID2,BOARD_REV_ID1,BOARD_REV_ID0};   //   external resister strappingBOARD_REV_ID0

wire    [1:0]   model_id    = 2'b00 ; // wedge100
// wire    [1:0]   model_id    = 2'b01 ; // 6-pack100 Line card
// wire    [1:0]   model_id    = 2'b10 ; // 6-pack100 fabric card
// wire    [1:0]   model_id    = 2'b11 ; // unused 
 

assign  ro_0x00 = {2'b00,model_id,board_rev} ;

//Reg_0x01 CPLD Code Revision
// parameter cpld_revision = 8'd1; // zyao: wedge100 initial revision
// parameter CPLD_REVISION = 8'd1; // zyao: wedge100 initial revision 

wire    release_bit =   1'b0 ;
wire    [5:0]   revision   = CPLD_REVISION[5:0];

assign  ro_0x01 = {1'd0,release_bit,revision} ;

// Reg_0x02 cpld sub-revision, keep track all changes made
assign  ro_0x02 = 8'd00;
//assign  ro_0x02 = 8'd01;   // initial revision
//assign  ro_0x02 = 8'd02;   // initial revision 
//assign  ro_0x02 = 8'd03;   // 
//assign  ro_0x02 = 8'd04;   //  edit code based on logi feedback
//assign  ro_0x02 = 8'd05;   //  temp release to Qwave for merge
//assign  ro_0x02 = 8'd06;   // micro-server power button control  
//assign  ro_0x02 = 8'd07;   // TH_PWRON from BMC is disabled in default
//assign  ro_0x02 = 8'd08;   // for VIDSEL to 100 in default until SW change it?? or HW change it(before tomahawk reset release
//assign  ro_0x02 = 8'd09;   // pwr_main_force force to 1
//assign  ro_0x02 = 8'd10;   // rov[3:0] set to 1000 if pd_main_rst_n is low, in default still use 1.0v as default
//assign  ro_0x02 = 8'd11;   // rw_0x2e[0] for debug control,  0: force vidsel to 100. 1: enable dynamic ROV VID. change it to 1, enable dynamic ROV VID control
//assign  ro_0x02 = 8'd12;   // bmc_rst_n AND with pd_stby_rst_n to allow BMC reset everytime if standby power reboot
//assign  ro_0x02 = 8'd13;   // change default tomahawk reset to be ON, reg 0x32 = 0000_1111
//assign  ro_0x02 = 8'd14;   // 5 output signals add weakpullup inside cpld, BMC_CPLD_POWER_INT, PWR_CYC_ALL_N, PWR_MAIN_EN, PWR_MAIN_FORCE, PWR_MSERVER_FORCE. change reset_ctrl state machine to pwr_rst_n                                                                                                  
//assign  ro_0x02 = 8'd15;     // disable dual boot mode   
//assign  ro_0x02 = 8'd16;     // change qsfp_reset_n default value to 1, release reset for easy debug; and release some chip out of reset   
//assign  ro_0x02 = 8'd17;     // change VIDSEL to 100, 1.0V 
//assign  ro_0x02 = 8'd18;     // change BMC_RST_N,    
//assign  ro_0x02 = 8'd19;     // add led debug function block   
//assign  ro_0x02 = 8'd20;     // led debug function improvement   
//assign  ro_0x02 = 8'd21;     // led debug function improvement , add walking test for both stream  
//assign  ro_0x02 = 8'd22;     // change uart mux register 0x26 default value to 0x00, alow BMC to automatically select uart port to userver 
//assign  ro_0x02 = 8'd23;     // enable dual boot for tian's debug  
//assign  ro_0x02 = 8'd24;     // change back to single boot, change two red system led to be ANDed with warm_reset_n     
//assign  ro_0x02 = 8'd25;     // add com-exp test card enable control, 0x33[1] comexp_test_en_n   
//assign  ro_0x02 = 8'd26;     // power button reset to enable BMC control and button control at the same time; enable front panel reset in default    
//assign  ro_0x02 = 8'd27;     // if disable main power, the BMC i2c bus will lockup, use hot_reset       
//assign  ro_0x02 = 8'd28;     // add status read-only register 0x1c and 0x1d, fix reset_ctrl pwr_rst_n missing issue       
//assign  ro_0x02 = 8'd29;     // change reset_ctrl defalt reset signals state to 0: assert reset during power cycling  
//assign  ro_0x02 = 8'd30;     // add rov test logic to debug rov
//assign  ro_0x02 = 8'd31;     // fix micro-server power on and off issue      
//assign  ro_0x02 = 8'd32;     // micro-server push button function issue??? add fan_tray heart beat module
//assign  ro_0x02 = 8'd33;     // heart attack module debug
//assign  ro_0x02 = 8'd34;     // add self power button pulse for micro-server self booting
//assign  ro_0x02 = 8'd35;     //add pride mode test
//assign  ro_0x02 = 8'd36;     //add pride blink shift function
//assign  ro_0x02 = 8'd37;     // change default state to blinking shift pride mode
//assign  ro_0x02 = 8'd38;     // change led walking test led number sequence to count down sequence, add msrver_buf_en protection control, disable mserver_buf_en when usrv reset                                                                                                                                                                                                                
//assign  ro_0x02 = 8'd39;     // disable auto-power button reset. add test signal for micro-server button debug
//assign  ro_0x02 = 8'd40;     // disable panther_com isolation buffer in default reg_0x33[2] = 0, SW can change this bit to 1 to enable panther_uart console
//assign  ro_0x02 = 8'd41;     // enable panther_com isolation buffer in default reg_0x33[2] = 1,  to compare with rev 40
//assign  ro_0x02 = 8'd42;     // drive COM_RX to 0 when userver is in reset, or power down mode, add weakup for BMC power button control signals
//assign  ro_0x02 = 8'd43;     // enable ROV, if pd_main_rst_n is active low, then default value is 1.0V, if pd_main_rst_n is high, then the voltage is ROV decided
//assign  ro_0x02 = 8'd44;     // enable rov, disable asic power, waiting SW to enable, change heart-attack expire time to 120 seconds
// assign  ro_0x02 = 8'd45;    // change OOB switch, PHY reset to be controlled by cold_reset only
// assign  ro_0x02 = 8'd46;    // fix reg 0x03 slot ID issue, wedge100 value need to be 0x10, use d10 instead. change to 0x10
// assign  ro_0x02 = 8'd47;    // change COM-E buffer control polarity
//assign  ro_0x02 = 8'd48;     // donot change polarity, instead, change default value of reg_0x33 and bit definition
//assign  ro_0x02 = 8'd49;     // add uart workaround, use P+ PCIE_RST_N to drive uart TX/RX 0 to panther+
//assign  ro_0x02 = 8'd50;     // remove cold_reset_n from micro-server buffer control, only rw_0x33[2] control iso buffer now, correct comexp_test_en_n inpmied signal issue
//assign  ro_0x02 = 8'd51;     // change com-e test mode to be disabled in default
//assign  ro_0x02 = 8'd52;     // change default mode to be dual boot for tian to test
//assign  ro_0x02 = 8'd53;     // PCIE_RST_N to register 0x13 bit7
//assign  ro_0x02 = 8'd54;     // if micro-server power is turn off, then disable COM-E test buffer enable. it will workaround power leakage issue to PCA9534 on COM-E adpat card
//assign  ro_0x02 = 8'd55;     // com-e logic added
//assign  ro_0x02 = 8'd56;     // adjust COM-E powerup and reset sequence, gated PWR_OK, Mserver_RST_N and MICROSRV_PWR_BTN_N signals with pd_main_reset_n delayed signals
//assign  ro_0x02 = 8'd57;     // add main_rst_n to Gate some reset signals for COM-E related logics
//assign  ro_0x02 = 8'd58;     // change default value of reg_0x28 from 0000_1111 to 0100_1111, PWR_OK to be enabled
//assign  ro_0x02 = 8'd59;     // add 4 seconds delay for pd_usrv_reset_n
//assign  ro_0x02 = 8'd60;       // add cb_reset_n signal to gate phy_reset and other com-e reset signals
 
 // Reg_0x03: slot information(reserved for 6-pack100)                                                      
/*                                                                                                      
wire [7:0]  ro_0x03 = 8'd00; // line card slot-1
wire [7:0]  ro_0x03 = 8'd01; // line card slot-2
wire [7:0]  ro_0x03 = 8'd02; // line card slot-3
wire [7:0]  ro_0x03 = 8'd03; // line card slot-4
wire [7:0]  ro_0x03 = 8'd04; // line card slot-5
wire [7:0]  ro_0x03 = 8'd05; // line card slot-6
wire [7:0]  ro_0x03 = 8'd06; // line card slot-7
wire [7:0]  ro_0x03 = 8'd07; // line card slot-8
wire [7:0]  ro_0x03 = 8'd08; // fabric card slot-1, Block-0
wire [7:0]  ro_0x03 = 8'd09; // fabric card slot-1, Block-1
wire [7:0]  ro_0x03 = 8'd0a; // fabric card slot-2, Block-0
wire [7:0]  ro_0x03 = 8'd0b; // fabric card slot-2, Block-1
*/

assign  ro_0x03 = 8'h10; // reserved for TOR
 
// reg 0x08, present status register

assign    ro_0x08[7]  = 1'b1 ; 
assign    ro_0x08[6]  = 1'b1 ; 
assign    ro_0x08[5]  = 1'b1 ; 
assign    ro_0x08[4]  = 1'b1 ; 
assign    ro_0x08[3]  = MICROSRV_PRSNT_N; 
assign    ro_0x08[2]  = CARD_PRNT_N; 
assign    ro_0x08[1]  = PSU2_PRSNT_N; 
assign    ro_0x08[0]  = PSU1_PRSNT_N; 

//=====================================================================================
// gpio to USB-I2C bridge CP2112  rw_0x1f, rw_0x2c, rw_0x2d
assign	  CP2112_GPIO7  = (rw_0x2c[7]) ? rw_0x2d[7] : 1'bz ;   // GPIO7  from CP2112      
assign	  CP2112_GPIO6  = (rw_0x2c[6]) ? rw_0x2d[6] : 1'bz ;   // GPIO6  from CP2112
assign	  CP2112_GPIO5  = (rw_0x2c[5]) ? rw_0x2d[5] : 1'bz ;   // GPIO5  from CP2112
assign	  CP2112_GPIO4  = (rw_0x2c[4]) ? rw_0x2d[4] : 1'bz ;   // GPIO4  from CP2112
assign	  CP2112_GPIO3  = (rw_0x2c[3]) ? rw_0x2d[3] : 1'bz ;   // GPIO3  from CP2112
assign	  CP2112_GPIO2  = (rw_0x2c[2]) ? rw_0x2d[2] : 1'bz ;   // GPIO2  from CP2112
assign    LS_CP2112_CPLD_GPIO1  = (rw_0x2c[1]) ? rw_0x2d[1] : 1'bz ;   // GPIO1  from CP2112
assign    LS_CP2112_CPLD_GPIO0  = (rw_0x2c[0]) ? rw_0x2d[0] : 1'bz ;   // GPIO0  from CP2112


assign    ro_0x1f[7]  = CP2112_GPIO7; 
assign    ro_0x1f[6]  = CP2112_GPIO6;
assign    ro_0x1f[5]  = CP2112_GPIO5;
assign    ro_0x1f[4]  = CP2112_GPIO4;
assign    ro_0x1f[3]  = CP2112_GPIO3;
assign    ro_0x1f[2]  = CP2112_GPIO2;
assign    ro_0x1f[1]  = LS_CP2112_CPLD_GPIO1;
assign    ro_0x1f[0]  = LS_CP2112_CPLD_GPIO0;

//======================================================================================

// Xpliant PLL Locks PLL_CLOCK_LOCK[2:0] status register 
assign ro_0x43[2] = ISO_XP_CORE_PLL_LOCK; // Core clock PLL lock indication 0-not locked,1- locked
assign ro_0x43[1] = ISO_XP_MAC_PLL_LOCK;  // Mac clock PLL lock indication 0-not locked,1- locked
assign ro_0x43[0] = ISO_XP_PEX_PLL_LOCK;  // PEX clock PLL lock indication 0-not locked,1- locked


// Xpliant GPIO Interface for future use
assign   ISO_XP_GPIO_0 = (rw_0x45[0])? rw_0x45[4] : 1'bz ;         // Xpliant GPIO signal
assign   ISO_XP_GPIO_1 = (rw_0x45[1])? rw_0x45[5] : 1'bz ;         // Xpliant GPIO signal
assign   ISO_XP_GPIO_2 = (rw_0x45[2])? rw_0x45[6] : 1'bz ;         // Xpliant GPIO signal
assign   ISO_XP_GPIO_3 = (rw_0x45[3])? rw_0x45[7] : 1'bz ;         // Xpliant GPIO signal

assign ro_0x42[0] = ISO_XP_GPIO_0 ;
assign ro_0x42[1] = ISO_XP_GPIO_1 ;
assign ro_0x42[2] = ISO_XP_GPIO_2 ;
assign ro_0x42[3] = ISO_XP_GPIO_3 ;

//------------------- 0x2f-----------------------------------

// debug control register 0x2f control
// reg 0x2F default value is 1111_0011        => dal_boot enable, and second SPI can be write
assign   DUAL_BOOT_EN =  rw_0x2f[0];  // in default dual boot enabled

wire     enable_2nd_write_protect = rw_0x2f[1];
wire     force_2nd_write          = rw_0x2f[2];  // set this bit to 1 to force 2nd flash writable

// 	    BMC_SPI_WP_N                //bmc request to enable  write protect of Secondary boot device  (* chip_pin = "K1"  *)  ?? control debug register
//  Secondary boot device write protect enable                   (* chip_pin = "J4"  *)  ?? control debug register
assign   CPLD_SPI_SEC_BOOT_WP_N  = force_2nd_write          ? 1'b1 : 
                                   enable_2nd_write_protect ? 1'b0 : BMC_SPI_WP_N ;

wire     usrv_pwr_btn_bypass    = rw_0x2f[3];                                    
                                   
// dual boot support. 0: NO dual boot, 1: dual boot   
//assign   DUAL_BOOT_EN = 1'b1;

wire     iso_force_usrv     = rw_0x2f[4]; 
wire     iso_force_buffer   = rw_0x2f[5];
wire     iso_force_mode     = rw_0x2f[6]; 

// assign   CPLD_IN3           = rw_0x2f[7];  // reserved for PWR1014A control

//  Isolation Buffer    
//  input	  BMC_ISO_BUF_EN              // Request from BMC to enable isolation buffers                  (* chip_pin = "M4"  *)    used for power related filtering
//  input	  BMC_MSERVE_ISOBUF_EN        // request from BMC to enable microserver isolation buffer       (* chip_pin = "P7"  *)  
//  output    ISO_BUF_EN                  // isolation buffer enable                                       (* chip_pin = "L4"  *)  
//  output    MSERVE_ISOBUF_EN            // Mserve isolation buffer enable                                (* chip_pin = "M7"  *)    ???

// buffer enable is active low
wire     iso_buf_en_out         = iso_force_mode ? iso_force_buffer : BMC_ISO_BUF_EN ;
wire     mserve_isobuf_en_out   = iso_force_mode ? iso_force_usrv   : BMC_MSERVE_ISOBUF_EN ;

// assign   ISO_BUF_EN         =  pd_main_ok ? !iso_buf_en_out       : 1'b1 ;   // active low
// assign   MSERVE_ISOBUF_EN   =  pd_main_ok ? !mserve_isobuf_en_out : 1'b1 ;

wire  pwr_all_ok = PD_STBY_RESET_N & PD_MAIN_RESET_N ; // rely on pwr014A reset as power good indication

wire   iso_buf_en_buf        =  pwr_all_ok ? !iso_buf_en_out       : 1'b1 ;  
wire   mserve_isobuf_en_buf  =  pwr_all_ok ? !mserve_isobuf_en_out : 1'b1 ;  

assign   ISO_BUF_EN          =  iso_buf_en_buf       ;  

//assign   MSERVE_ISOBUF_EN    = (usrv_uart_iso_en         == 1'b0 ) ? 1'b1:
//                               (mserve_isobuf_en_protect == 1'b1 ) ? mserve_isobuf_en_buf : 1'b1 ;    // micro-server power buttun reset or other reset, micro-server UART buffer need to be disable
                               
// 07/31/2015 workaround, always enable micro-server buffer       
assign   MSERVE_ISOBUF_EN     = !usrv_uart_iso_en ; // usrv_uart_iso_en is rw_0x33[2], default is 1, enable micro-server isolation buffer                        
                               

//wire    mserve_isobuf_en_protect =  microsrv_pwr_btn_n_buf & MICROSRV_RST_N & MICROSRV_PCIE_RST_N;

//======================  power signals  ==============================================
// IR power status, 0x22   
//wire  pd_main_ok  = VCORE_VRDY1 & VANLG_VRDY1 & V3V3_VRDY1 ; 
assign  pd_main_ok  = PD_STBY_RESET_N & PD_MAIN_RESET_N ; // rely on pwr014A reset as power good indication, IR5384 VRDY output has issue
   

wire  ir_pwr_hot  = VCORE_HOT & VANLG_HOT & V3V3_HOT ;                                                                     
//     VCORE_VRDY1             // Vcore voltage ready status               (* chip_pin = "M6"  *)
//     VCORE_HOT               // over temperature or over current alarm   (* chip_pin = "T5"  *)
//     VANLG_VRDY1             //                                          (* chip_pin = "R6"  *)
//     VANLG_HOT               // over temperature or over current alarm   (* chip_pin = "N7"  *)
//     V3V3_VRDY1              //                                          (* chip_pin = "R7"  *)
//     V3V3_HOT                // over temperature or over current alarm   (* chip_pin = "P8"  *)
                                                                                                      

assign   PWR_STBY_OK = P1V2_STBY_OK ; // standby power is 1.2V power good because 1.2V is the last DCDC in power sequence  

 
always @ (posedge clk_10hz )
    begin
       
       pd_main_reset_n_seq  <= PD_MAIN_RESET_N ;   // input signal is in capital
       pd_main_reset_n_2seq <= pd_main_reset_n_seq ;      
    end
 

// micro-server power button 
//  BMC_PWR_BTN_OUT_N           // pwr btn out from bmc GPIOD1 pin D16                            (* chip_pin = "H3"  *)   this is driven by BMC, CPLD input
//  BMC_PWR_BTN_IN_N            // pwr btn input, it is on board psh button out, cpld input       (* chip_pin = "G5"  *)   SW2, PUSHBUT1, this signal also go to BMC GPIOD0, pin A18 this signal connect to BMC and CPLD at the same time
// on board push button for micro-server pwr control
// BMC_READY_N is from BMCGPIOP7
// BMC_READY_N = 0: then button input is from BMC output (BMC_PWR_BTN_OUT_N)
// BMC_READY_N = 1: then button input is from real push button (BMC_PWR_BTN_OUT_N)
wire  pwr_usrv_button_in = BMC_READY_N ? BMC_PWR_BTN_OUT_N : BMC_PWR_BTN_IN_N;


//======================================================================================= 
//  power button self reset pulse after pd_main_reset_n become high
//=======================================================================================
reg       pwr_btn_self_n;
reg [3:0] pwr_btn_cnt; 
 
always @ (posedge clk_10hz )
    begin
       if       ( pd_main_ok_delay == 1'b0 )
                  pwr_btn_cnt <= 4'd0;
       else if (( pwr_btn_cnt < 4'd15 ) && ( pd_main_ok_delay == 1'b1 ))
                  pwr_btn_cnt <= pwr_btn_cnt + 1;
       else if (  pwr_btn_cnt == 15 )
                  pwr_btn_cnt <= 15;
    
     // self reset for poweron reset, 1 to 14 are reset active low pulse
       if   (( pwr_btn_cnt >= 4'd1 ) && ( pwr_btn_cnt <  4'd14 ))
             pwr_btn_self_n <= 1'b0;
	   else  pwr_btn_self_n <= 1'b1;
             
    end
	
wire  microsrv_rst_n_out; 
wire  mserve_workaround_act_n = microsrv_rst_n_out & MICROSRV_PCIE_RST_N;  //MICROSRV_RST_N = cold_reset_n & reset_usrv_n_int & pd_main_reset_n & rw_0x32[0] ; // micro-server reset output 


wire  pwr_usrv_en ;              // rw_0x30[2] : micro-server power enable bit
wire  pwr_mserver_force_int;     // force micro-server power, debug only, should not change by SW
wire  microsrv_pwr_btn_n_out; 


// button bypass directly
// microsrv_pwr_btn_n_out is 200ms delayed version of pwr_usrv_button_in to filer out noise
//assign  MICROSRV_PWR_BTN_N = usrv_pwr_btn_bypass ? BMC_PWR_BTN_IN_N: microsrv_pwr_btn_n_out;
// BMC_PWR_BTN_IN_N : external power button input
// microsrv_pwr_btn_n_out: reg_0x30[3], and BMC button signal input
//wire   microsrv_pwr_btn_n_buf = usrv_pwr_btn_bypass ? BMC_PWR_BTN_IN_N: (BMC_PWR_BTN_IN_N && microsrv_pwr_btn_n_out && pwr_btn_self_n) ;

// 0x2f[3] usrv_pwr_btn_bypass
wire   microsrv_pwr_btn_n_buf = usrv_pwr_btn_bypass ? BMC_PWR_BTN_IN_N: (BMC_PWR_BTN_IN_N && microsrv_pwr_btn_n_out ) ;   // no self boot pulse

// assign  MICROSRV_PWR_BTN_N    = microsrv_pwr_btn_n_buf ;

// panther uart work-around, use pcie_rst_n from micro-server to drive uart signal low to workaround the leakage issue 
wire   panther_com_tx_in  = PANTHER_COM_TX;  

assign PANTHER_COM_TX  = mserve_workaround_act_n ? 1'bz : 1'b0 ; // implement workaround to driver PANTHER_COM_TX 0 when micro-server RST_N and PCIE_RST_N is active low.

  
wire   panther_com_rx_out ;    

//wire   panther_com_oe = !MICROSRV_PCIE_RST_N ;   
// assign  PANTHER_COM_RX  = panther_com_oe  ?  1'b0: panther_com_rx_out ; 
// assign  PANTHER_COM_TX  = panther_com_oe  ?  1'b0: 1'bZ ; 

//assign  PANTHER_COM_RX  = mserve_isobuf_en_protect ? panther_com_rx_out : 1'b0 ;    // when us reset, COM_RX will drive 0

assign  PANTHER_COM_RX  = mserve_workaround_act_n ? panther_com_rx_out : 1'b0 ;


// panther+ uart workaround enable, always drive PANTHER_COM_RX and PANTHER_COM_TX to 0

assign PWR_MSERVER_FORCE  = pwr_mserver_force_int & pwr_usrv_en ;
	
wire       read_from_bmc;
wire       write_from_bmc;
wire [7:0] writedata_from_bmc;
wire [7:0] address_from_bmc;
wire       read_from_usrv;
wire       write_from_usrv;
wire [7:0] writedata_from_usrv;
wire [7:0] address_from_usrv;
wire       bcm5387_rst_n_out ;    
wire       fp_phy_rst_n_out  ;    
wire       bcm54616_phy_rst_n_out;
wire       bmc_rst_n_out ;
wire [7:0] readdata_to_bmc_usrv ; 
wire [7:0] readdata_nodelay ;
wire       pwr_main_en_out;
  
assign  BCM5387_RST_N      = bcm5387_rst_n_out      ? 1'bZ : 1'b0  ;       // OOB switch BCM5387 reset output , low will drive 0, high will tri-state, rely on external pullup 
assign  FP_PHY_RST_N       = fp_phy_rst_n_out       ? 1'bZ : 1'b0  ;       // front port PHY reset output , low will drive 0, high will tri-state, rely on external pullup 
assign  BCM54616_PHY_RST_N = bcm54616_phy_rst_n_out ? 1'bZ : 1'b0  ;       // on-board PHY BCM54616 reset output, low will drive 0, high will tri-state, rely on external pullup  
assign  BMC_RST_N          = bmc_rst_n_out          ? 1'bZ : 1'b0  ;

//assign  LS_BMC_COM_ISOBUF_EN   = !comexp_test_en_n ; // change polarity, comexp_test_en = 0: disabl ecomexp test card. 1: enable comexp test card
wire [31:0] qsfp_reset_n;
wire    comexp_test_en_n;
//assign  LS_BMC_COM_ISOBUF_EN   =  comexp_test_en_n ; // donot change polarity, change bit definition and default value of reg 0x33
assign  LS_BMC_COM_ISOBUF_EN   =  pwr_usrv_en ? comexp_test_en_n: 1'b1; // if micro-sever power is disabled, then disable com-e test buffer
 
system_boot 
 #
(
 .PULSE_WIDTH_HOT    ( PULSE_WIDTH_HOT    ),
 .PULSE_WIDTH_WARM   ( PULSE_WIDTH_WARM   ),
 .PULSE_WIDTH_COLD   ( PULSE_WIDTH_COLD   ),
 .PULSE_WID_BMC_MAIN ( PULSE_WID_BMC_MAIN ),
 .PULSE_WID_PUSH_BTN ( PULSE_WID_PUSH_BTN ),
 .SW_DEB_LEN         ( SW_DEB_LEN         )

)

system_boot_u 
(
	.clk	                   (clk	                   ),     // clock
	.clk_1s				       (clk_1hz				   ),     // clock 1second for watchdog timer
	.clk_100ms                 (clk_10hz               ),     // 100ms cycle
	.reg_rst_ctrl_wr           (wr_0x31_en_buf         ),
     
	.rw_0x30                   (rw_0x30                ),     // reg 0x30
	.rw_0x31                   (rw_0x31                ),     // reg 0x31
	.rw_0x32                   (rw_0x32                ),     // reg 0x32
	.rw_0x33                   (rw_0x33                ),     // reg 0x33
	.rw_0x34                   (rw_0x34                ),     // reg 0x34
	.rw_0x35                   (rw_0x35                ),     // reg 0x35
	.rw_0x36                   (rw_0x36                ),     // reg 0x36
	.rw_0x37                   (rw_0x37                ),     // reg 0x37
	.rw_0x38                   (rw_0x38                ),     // reg 0x38
	.rw_0x39                   (rw_0x39                ),     // reg 0x39
	.rw_0x3a                   (rw_0x3a                ),     // reg 0x3a 
	.rw_0x3b                   (rw_0x3b                ),     // reg 0x3b
	    
	.ro_0x0c                   (ro_0x0c                ),     // status out to register file read bus
	.ro_0x0d                   (ro_0x0d                ),     // status out to register file read bus
	.ro_0x0e                   (ro_0x0e                ),     // status out to register file read bus
	.ro_0x0f                   (ro_0x0f                ),     // status out to register file read bus
	
	.pd_stby_reset_n 	       (PD_STBY_RESET_N 	   ),     // async standby power on reset, active low, from power1014a, already delayed
	.pd_main_reset_n           (pd_main_rst_n_dly2     ),     // power domain main reset, 200ms delay , from pwr1014a
	.rst_pwr_n                 (rst_pwr_n              ),     // self poweron reset                                                 
	 
	.xp_powerup                (XP_POWERUP             ),
	.userver_powerup           (MSERV_POWERUP          ),     //   micro-server power up enable      (* chip_pin = "D7"  *) => this is BMC driven signal,  
	             
	.MICROSRV_PCIE_RST_N       (MICROSRV_PCIE_RST_N    ),      // micro-server reset output               (* chip_pin = "E7"  *)  : Microserver request to reset PCIe devices                                                                                                   
	.LS_BMC_WDTRST1            (LS_BMC_WDTRST1         ),      // BMC watch dog timer reset output,       (* chip_pin = "B5"  *)   falling edge pulse 
	.LS_BMC_WDTRST2            (LS_BMC_WDTRST2         ),      // BMC watch dog timer reset output,       (* chip_pin = "E6"  *)   falling edge pulse 
	 
	.BMC_MAIN_RESET_N          (BMC_MAIN_RESET_N       ),      // BMC request to reset the system         (* chip_pin = "F5"  *)  :                                                                                                                                                                                                                  
	.BMC_CPLD_RESET1           (BMC_CPLD_RESET1        ),      // spare reset signal from BMC,            (* chip_pin = "J3"  *)    falling edge pulse, reset BMC only 
	.BMC_CPLD_RESET2           (BMC_CPLD_RESET2        ),      // spare reset signal from BMC,            (* chip_pin = "K2"  *)    falling edge pulse, reset uServer  
	.LS_BMC_CPLD_RESET3        (LS_BMC_CPLD_RESET3     ),      // spare reset signal from BMC             (* chip_pin = "L3"  *)
	.LS_BMC_CPLD_RESET4        (LS_BMC_CPLD_RESET4     ),      // spare reset signal from BMC             (* chip_pin = "N1"  *)
	                                             
	.PUSHBUTTON_RST_N          (PUSHBUTTON_RST_N       ),      // front panel push btn reset              (* chip_pin = "K16" *) 
	.CPLD_PUSH_BTN_RST_IN_N    (CPLD_PUSH_BTN_RST_IN_N ),      // on board debug reset btn                (* chip_pin = "L15" *) 
	.DEBUG_RST_BTN_N           (DEBUG_RST_BTN_N        ),      // Debug Reset button in Front panel is pressed, DEBUG_RST_BTN_N will become low (* chip_pin = "A15"  *)  
    .pwr_usrv_button_in        (pwr_usrv_button_in     ),      // micro-server button input
	                                                      
//output signals                                      
// power control register 0x30                        
	.pwr_cyc_all_n      	   (PWR_CYC_ALL_N          ),      // power cycle output to pwr1014a, power cycle all power
	.pwr_main_en               (pwr_main_en_out        ),      // enable main power, active high, to pwr1014a
	.pwr_usrv_en               (pwr_usrv_en            ),      // enable micro-server power, active high, to pwr1014a
	.pwr_usrv_btn_n            (microsrv_pwr_btn_n_out ),      // micro-server power button 
	                                                   
	.pwr_main_force            (PWR_MAIN_FORCE         ),      // force main power, debug only, should not change by SW
	.pwr_mserver_force         (pwr_mserver_force_int  ),      // force micro-server power, debug only, should not change by SW
                                                       
// reset control reset register 0x32         	       
	.microsrv_rst_n            (microsrv_rst_n_out     ),      // micro-server reset output 
	.iso_xpliant_rst_n         (ISO_XPLIANT_RST_N      ),      // tomahawk reset output 
	
	// misc control 0x33
    // .dpll_clk_sel              (DPLL_CLK_SEL           ),     // dpll clock select
    .comexp_test_en_n          (comexp_test_en_n       ),     // comexp test card enable 
    .usrv_uart_iso_en          (usrv_uart_iso_en       ),    // micro-server uart isolation buffer 0: disable, 1: enable, under BMC control 
                                                      
// BMC reset                                            
	.bmc_rst_n                 (bmc_rst_n_out          ),      // bmc reset output 
                                                        
// qsfp reset output , reg 0x34 to 0x37                                                                                                       
	.qsfp_reset_n              (qsfp_reset_n           ),
                                                       
// reset control register 0x32 for small ICs, such as   oob switch, phy, and fan-ctrl card    
	.fancard_rst_n             (FANCARD_RST_N          ),        // fan_ctrl card reset output                               
	.usb_brdg_rst_n      	   (USB_BRDG_RST_N         ),        // usb bridge reset output 
	.usb_hub_rst_n             (USB_HUB_RST_N          ),        // usb hub reset output 
	.bcm5387_rst_n             (bcm5387_rst_n_out      ),        // OOB switch BCM5387 reset output  
	.fp_phy_rst_n              (fp_phy_rst_n_out       ),        // front port PHY reset output 
	.bcm54616_phy_rst_n        (bcm54616_phy_rst_n_out ),        // on-board PHY BCM54616 reset output 
	.usb_spi_brg_rst_n         (LS_USB_SPI_BRIDGE_RST_N), // reserved usb to spi bridge reset output
    .dpll_rst_n                (LS_DPLL_RST_N          ),   // reserved for dppl reset                                                       
// reset control register 0x33   for i2c mux reset                                   
	.i2c_mux_rst0_n   	       (I2C_MUX_RST0_N         ),        // i2c mux 0 reset output
	.i2c_mux_rst1_n            (I2C_MUX_RST1_N         ),        // i2c mux 1 reset output
	.i2c_mux_rst2_n            (I2C_MUX_RST2_N         ),        // i2c mux 2 reset output
	.i2c_mux_rst3_n            (I2C_MUX_RST3_N         ),        // i2c mux 3 reset output
	.i2c_mux_psu_rst_n         (I2C_MUX_PSU_RST_N      ),        // i2c mux for psu reset output 
	.i2c_mux_exp_rst_n         (I2C_MUX_EXP_RST_N      ),        // i2c mux for qsfp LLI signals reset output  	 

	.hot_reset_n               (hot_reset_n 	       ),        // cold reset output, reset all devices on board, both standby and main power domain
	.warm_reset_n              (warm_reset_n           ),        // warm reset output, reset standby power domain                               
	.cold_reset_n              (cold_reset_n           )         // hot reset output, reset BMC only, will not affect datapath                  
	                                                                                                                                                

) ;


// reset output signals
assign   P0_QRESET_N           = qsfp_reset_n[0]; 
assign   P1_QRESET_N           = qsfp_reset_n[1]; 
assign   P2_QRESET_N           = qsfp_reset_n[2]; 
assign   P3_QRESET_N           = qsfp_reset_n[3]; 
assign   P4_QRESET_N           = qsfp_reset_n[4]; 
assign   P5_QRESET_N           = qsfp_reset_n[5]; 
assign   P6_QRESET_N           = qsfp_reset_n[6]; 
assign   P7_QRESET_N           = qsfp_reset_n[7]; 
assign   P8_QRESET_N           = qsfp_reset_n[8]; 
assign   P9_QRESET_N           = qsfp_reset_n[9]; 
assign   P10_QRESET_N          = qsfp_reset_n[10]; 
assign   P11_QRESET_N          = qsfp_reset_n[11]; 
assign   P12_QRESET_N          = qsfp_reset_n[12]; 
assign   P13_QRESET_N          = qsfp_reset_n[13]; 
assign   P14_QRESET_N          = qsfp_reset_n[14]; 
assign   P15_QRESET_N          = qsfp_reset_n[15]; 
assign   P16_QRESET_N          = qsfp_reset_n[16]; 
assign   P17_QRESET_N          = qsfp_reset_n[17]; 
assign   P18_QRESET_N          = qsfp_reset_n[18]; 
assign   P19_QRESET_N          = qsfp_reset_n[19]; 
assign   P20_QRESET_N          = qsfp_reset_n[20]; 
assign   P21_QRESET_N          = qsfp_reset_n[21]; 
assign   P22_QRESET_N          = qsfp_reset_n[22]; 
assign   P23_QRESET_N          = qsfp_reset_n[23]; 
assign   P24_QRESET_N          = qsfp_reset_n[24]; 
assign   P25_QRESET_N          = qsfp_reset_n[25]; 
assign   P26_QRESET_N          = qsfp_reset_n[26]; 
assign   P27_QRESET_N          = qsfp_reset_n[27]; 
assign   P28_QRESET_N          = qsfp_reset_n[28]; 
assign   P29_QRESET_N          = qsfp_reset_n[29]; 
assign   P30_QRESET_N          = qsfp_reset_n[30]; 
assign   P31_QRESET_N          = qsfp_reset_n[31]; 
                           
// assign   USB_BRDG_RST_N        = usb_brdg_rst_n 
// assign   USB_HUB_RST_N         = usb_hub_rst_n                               
// assign   FANCARD_RST_N         = fancard_rst_n                             
//                                                        
// assign   MICROSRV_RST_N        = microsrv_rst_n                                      
// assign   ISO_XPLIANT_RST_N     = iso_xpliant_rst_n ;                                 
// assign   TOMAHAWK_PCIE_RST_N   = tomahawk_pcie_rst_n 
//                                 
// assign   BCM5387_RST_N         = bcm5387_rst_n      
// assign   FP_PHY_RST_N          = fp_phy_rst_n       
// assign   BCM54616_PHY_RST_N    = bcm54616_phy_rst_n 
//                       
// assign   I2C_MUX_RST0_N        = i2c_mux_rst0_n   ;
// assign   I2C_MUX_RST1_N        = i2c_mux_rst1_n   ;
// assign   I2C_MUX_RST2_N        = i2c_mux_rst2_n   ;
// assign   I2C_MUX_RST3_N        = i2c_mux_rst3_n   ;
// assign   I2C_MUX_PSU_RST_N     = i2c_mux_psu_rst_n;
// assign   I2C_MUX_EXP_RST_N     = i2c_mux_exp_rst_n;



//======================================================================================= 

 
always @ (posedge clk )
    begin
       if (  self_rst_cnt < 6'd63 )
             self_rst_cnt <= self_rst_cnt + 6'd1;
       else
             self_rst_cnt <= 6'd63;
    
     // self reset for poweron reset
       if   ( self_rst_cnt == 6'd63 )  rst_self_n <= 1'b1;
	   else  rst_self_n <= 1'b0;
             
    end
 

// DUAL_BOOT_DEFAULT

reg_file #
( 
 //.DUAL_BOOT_DEFAULT         ( 1'b1         )  //dual boot enable
 .DUAL_BOOT_DEFAULT         ( 1'b0         ) // dual boot disable
)
reg_file_inst
(
 
    .clk                    (clk                   ),
    .rst_pwr_n              (rst_pwr_n             ),
                           
    .hot_reset_n            (hot_reset_n           ),
    .warm_reset_n           (warm_reset_n          ),
    .cold_reset_n           (cold_reset_n          ),
                          
    .wr_0x31_en_buf         (wr_0x31_en_buf        ),
                                             
    .read_from_bmc          (read_from_bmc         ),               
    .write_from_bmc         (write_from_bmc        ),               
    .address_from_bmc       (address_from_bmc      ),               
    .writedata_from_bmc     (writedata_from_bmc    ),               
                  
    .readdata_to_bmc_usrv   (readdata_to_bmc_usrv  ),               
    .readdata_nodelay       (readdata_nodelay      ),                                               
              
    .read_from_usrv         (read_from_usrv        ),               
    .write_from_usrv        (write_from_usrv       ),               
    .address_from_usrv      (address_from_usrv     ),               
    .writedata_from_usrv    (writedata_from_usrv   ),               
       
    .ro_0x00                (ro_0x00               ),          
    .ro_0x01                (ro_0x01               ),          
    .ro_0x02                (ro_0x02               ),          
    .ro_0x03                (ro_0x03               ),          
    .ro_0x04                (ro_0x04               ),          
    .ro_0x05                (ro_0x05               ),          
    .ro_0x06                (ro_0x06               ),          
    .ro_0x07                (ro_0x07               ),          
    .ro_0x08                (ro_0x08               ),          
    .ro_0x09                (ro_0x09               ),          
    .ro_0x0a                (ro_0x0a               ),          
    .ro_0x0b                (ro_0x0b               ),          
    .ro_0x0c                (ro_0x0c               ),          
    .ro_0x0d                (ro_0x0d               ),          
    .ro_0x0e                (ro_0x0e               ),          
    .ro_0x0f                (ro_0x0f               ),          
                                     
    .ro_0x10                (ro_0x10               ),          
    .ro_0x11                (ro_0x11               ),          
    .ro_0x12                (ro_0x12               ),          
    .ro_0x13                (ro_0x13               ),          
    .ro_0x14                (ro_0x14               ),          
    .ro_0x15                (ro_0x15               ),          
    .ro_0x16                (ro_0x16               ),          
    .ro_0x17                (ro_0x17               ),          
    .ro_0x18                (ro_0x18               ),          
    .ro_0x19                (ro_0x19               ),          
    .ro_0x1a                (ro_0x1a               ),          
    .ro_0x1b                (ro_0x1b               ),          
    .ro_0x1c                (ro_0x1c               ),          
    .ro_0x1d                (ro_0x1d               ),          
    .ro_0x1e                (ro_0x1e               ),          
    .ro_0x1f                (ro_0x1f               ),          
                                     
    .rw_0x20                (rw_0x20               ),
    .rw_0x21                (rw_0x21               ),
    .rw_0x22                (rw_0x22               ),
    .rw_0x23                (rw_0x23               ),
    .rw_0x24                (rw_0x24               ),
    .rw_0x25                (rw_0x25               ),          
    .rw_0x26                (rw_0x26               ),          
    .rw_0x27                (rw_0x27               ),          
    .rw_0x28                (rw_0x28               ),          
    .rw_0x29                (rw_0x29               ),          
    .rw_0x2a                (rw_0x2a               ),          
    .rw_0x2b                (rw_0x2b               ),          
    .rw_0x2c                (rw_0x2c               ),          
    .rw_0x2d                (rw_0x2d               ),          
    .rw_0x2e                (rw_0x2e               ),          
    .rw_0x2f                (rw_0x2f               ),          
                                     
    .rw_0x30                (rw_0x30               ),          
    .rw_0x31                (rw_0x31               ),          
    .rw_0x32                (rw_0x32               ),          
    .rw_0x33                (rw_0x33               ),          
    .rw_0x34                (rw_0x34               ),          
    .rw_0x35                (rw_0x35               ),          
    .rw_0x36                (rw_0x36               ),          
    .rw_0x37                (rw_0x37               ),          
    .rw_0x38                (rw_0x38               ),          
    .rw_0x39                (rw_0x39               ),          
    .rw_0x3a                (rw_0x3a               ),          
    .rw_0x3b                (rw_0x3b               ),          
    .rw_0x3c                (rw_0x3c               ),          
    .rw_0x3d                (rw_0x3d               ),          
    .rw_0x3e                (rw_0x3e               ),          
    .rw_0x3f                (rw_0x3f               ),
    
	.ro_0x40                (ro_0x40               ),
    .rw_0x41                (rw_0x41               ),
    .ro_0x42                (ro_0x42               ),
    .ro_0x43                (ro_0x43               ),
    .rw_0x44                (rw_0x44               ),
    .rw_0x45                (rw_0x45               ),	
    .rw_0x46                (rw_0x46               )
	) ;    

   
    
 //-----------------------------------------------------------------
 // Calling the I2C Slave inst of BMC
 //-----------------------------------------------------------------

 wire       sda_0_oe_n;
 wire       sda_0_i  = BMC_CPLD_SDA;
 wire       scl_0_i  = BMC_CPLD_SCL; 
//    assign iCPU_I2C_SDA = (!sda_oe_n) ? 1'b0 : 1'bz; // This port is the Open-Drain mode.
assign BMC_CPLD_SDA =  (!sda_0_oe_n)      ? 1'b0 : 1'bz; 

/*                        
    wire      scl_i_rising = (scl_i_seq == 2'b01) ? 1'b1 : 1'b0;                        
    reg [1:0] scl_i_seq,scl_i_rising_seq;
    always @ (posedge clk    )
     begin
        scl_i_seq        <= {scl_i_seq[0],scl_i} ;
        scl_i_rising_seq <= scl_i_rising;
     end

    
// wire  mode_no_drive_scl = rw_0x49[2];
//0: drive scl high for 1 cycle in order to speedup rising edge
//1: disable drive scl high 
wire  scl_i_rising_wide = scl_i_rising | scl_i_rising_seq; 
wire  drive_scl  =  !mode_no_drive_scl & scl_i_rising_wide;
// drive scl to 1 for 20ns to increase the rising edge speed   
assign I2C0_SCL =  (drive_scl)? 1'b1:1'bz ;  

*/

                        
    i2c_csr  
    #(  
        .I2C_DevADDR            ( 7'h31                ) 
     )
       I2C_0_SLAVE                                        
        
    (
        .clk                    ( clk                  ),                         
        .reset_n                ( hot_reset_n          ),                         
        .scl_i                  ( scl_0_i              ),                        
        .sda_i                  ( sda_0_i              ),                        
        .sda_oe_n               ( sda_0_oe_n           ),                         
        .readdata               ( readdata_to_bmc_usrv ),
        .writedata              ( writedata_from_bmc   ),
        .address                ( address_from_bmc     ),
        .read                   ( read_from_bmc        ),
        .write                  ( write_from_bmc       )
    );

//-----------------------------------------------------------------
// Calling the i2c Slave inst for microserver i2c bus
//-----------------------------------------------------------------
 

 wire       sda_1_oe_n;
 wire       sda_1_i  = MAIN_I2C_SDA;
 wire       scl_1_i  = MAIN_I2C_SCL; 
//    assign iCPU_I2C_SDA = (!sda_oe_n) ? 1'b0 : 1'bz; // This port is the Open-Drain mode.
assign MAIN_I2C_SDA  =  (!sda_1_oe_n)      ? 1'b0 : 1'bz; 

     
   i2c_csr 
   #(  
        .I2C_DevADDR            ( 7'h32                ) 
    )
      I2C_1_SLAVE                                                 
   
    (
        .clk                    ( clk                  ),
        .reset_n                ( hot_reset_n          ), 
        .scl_i                  ( scl_1_i              ),
        .sda_i                  ( sda_1_i              ),
        .sda_oe_n               ( sda_1_oe_n           ),
        .readdata               ( readdata_to_bmc_usrv ),
        .writedata              ( writedata_from_usrv  ),
        .address                ( address_from_usrv    ),
        .read                   ( read_from_usrv       ),
        .write                  ( write_from_usrv      )
    );



   
//==================================================================================

  
wire  clk_tick  = clk_10hz;
 
irq_ctrl irq_ctrl_inst 
(
 
	.clk	              (clk			   ),  // clock 50mhz
	.clk_tick             (clk_tick        ), 
	.rst_n                (warm_reset_n    ), 
	                      
	.rw_0x20              (rw_0x20         ),  // interrupt control
	.rw_0x21              (rw_0x21         ),  // interrupt control
	.rw_0x22              (rw_0x22         ),  // interrupt control
	.rw_0x23              (rw_0x23         ), 
	.rw_0x24              (rw_0x24         ), 
	.rw_0x25              (rw_0x25         ),
// output registers       (                ), 
	.ro_0x10              (ro_0x10         ), 
	.ro_0x11              (ro_0x11         ), 
	.ro_0x12              (ro_0x12         ), 
	.ro_0x13              (ro_0x13         ), 
	.ro_0x14              (ro_0x14         ), 
	.ro_0x15              (ro_0x15         ), 
	.ro_0x16              (ro_0x16         ), 
	.ro_0x17              (ro_0x17         ), 
	.ro_0x40              (ro_0x40         ), 
	.rw_0x41              (rw_0x41         ), 
 

// psu signals      0x10
	.PSU1_PRSNT_N         (PSU1_PRSNT_N      ),      // psu-1 present, active low
	.PSU1_PWR_OK          (PSU1_PWR_OK       ),      // psu-1 power ok
	.PSU1_INPUT_OK        (PSU1_INPUT_OK     ),      // psu-1 input power ok
	.PSU1_SMB_ALERT_N     (PSU1_SMB_ALERT_N  ),      // psu-1 sm bus alert, active low
                                             
	.PSU2_PRSNT_N         (PSU2_PRSNT_N      ),      // psu-2 present, active low
	.PSU2_PWR_OK          (PSU2_PWR_OK       ),      // psu-2 power ok
	.PSU2_INPUT_OK        (PSU2_INPUT_OK     ),      // psu-2 input power ok
	.PSU2_SMB_ALERT_N     (PSU2_SMB_ALERT_N  ),      // psu-2 sm bus alert, active low
                                              
                                              
//   power status input       0x11           ),
//	.P5V_STBY_OK 	      (P5V_STBY_OK       ),      // 5V standby power OK
//	.P1V2_STBY_OK	      (P1V2_STBY_OK      ),      // 1.2V standby power OK	                           
	.PWR_STBY_OK 	      (PWR_STBY_OK       ),      //  
                                             
//   IR power status, 0x12                   
	.VCORE_VRDY1          (VCORE_VRDY1       ),      // Vcore voltage ready status
	.VCORE_HOT            (VCORE_HOT         ),      // over temperature or over current alarm
	.VANLG_VRDY1          (VANLG_VRDY1       ),      // 
	.VANLG_HOT            (VANLG_HOT         ),      // over temperature or over current alarm
	.V3V3_VRDY1           (V3V3_VRDY1        ),      // 
	.V3V3_HOT             (V3V3_HOT          ),      // over temperature or over current alarm
                                           
//   interrupt signals, 0x13               
	.I2C_IO_0_INT_N	      (I2C_IO_0_INT_N    ),      // I2C IO device PCA9535 Interrupt
	.I2C_IO_1_INT_N	      (I2C_IO_1_INT_N    ),      // I2C IO device PCA9535 Interrupt
	.I2C_IO_2_INT_N	      (I2C_IO_2_INT_N    ),      // I2C IO device PCA9535 Interrupt
	.I2C_IO_3_INT_N	      (I2C_IO_3_INT_N    ),      // I2C IO device PCA9535 Interrupt
	.I2C_IO_4_INT_N	      (I2C_IO_4_INT_N    ),      // I2C IO device PCA9535 Interrupt
	.I2C_IO_5_INT_N	      (I2C_IO_5_INT_N    ),      // I2C IO device PCA9535 Interrupt
	                                         
	.PM_SM_ALERT_N       (PM_SM_ALERT_N     ), 
	.VCORE_SMB_ALERT     (VCORE_SMB_ALERT   ), 
	.V3_3V_SMB_ALERT     (V3_3V_SMB_ALERT   ), 
	.VANLG_SMB_ALERT     (VANLG_SMB_ALERT   ),
	.TEMP_SENSOR_ALERT   (TEMP_SENSOR_ALERT ),
	.TPM_SPI_PIRQ_N      (TPM_SPI_PIRQ_N    ), 
                          
    .ISO_XP_INT_N	     (ISO_XP_INT_N	     ),  // ISO_XP_INT_N XPLIANT INTERRUPT SIGNAL
    .ISO_XP_OVERT_N	     (ISO_XP_OVERT_N	 ),  //	ISO_XP_OVERT_N XLIPANT TEMP SENSOR OUTPUT
    .ISO_XP_TEMP_ALRT_N	 (ISO_XP_TEMP_ALRT_N ),  //	ISO_XP_TEMP_ALRT_N XLIPANT TEMP SENSOR OUTPUT			  
    .ISO_XP_REI_INIT_DONE(ISO_XP_REI_INIT_DONE ),  //	ISO_XP_REI_INIT_DONE XLIPANT TEMP SENSOR OUTPUT			  
						  
    .SMB_ALERT           (SMB_ALERT          ), 
    .BMC_CPLD_POWER_INT  (BMC_CPLD_POWER_INT ),  
    .BMC_CPLD_QSFP_INT   (BMC_CPLD_QSFP_INT  ) 
                                                                                        
// interrupt output                         
//	.irq_psu_n          (irq_psu_n        ),      // psu interrupt active low
//	.irq_power_n        (irq_power_n      ),        // main board power interrupt active low   
//	.irq_ir_pwr_n       (irq_ir_pwr_n     ),         // IR power interrupt active low
//	.irq_pca9535_n      (irq_pca9535_n    )          // psu interrupt active low
 
) ;
 
//=================  UART MUX   =======================================

uart_mux uart_mux_u
(
	.uart_ctrl          (rw_0x26               ),     // uart mux control, rw_0x26
	.uart_select_bmc    (DEBUG_UART_SEL_0      ),     // DEBUG UART 0 Select line from BMC GPIOE0                
	.uart_select_dbg    (DEBUG_PORT_UART_SEL_N ),     // DEBUG UART 0 Select line from fcebook debug header           
	                                                 
	.BMC_UART_1_TX      (BMC_UART_1_TX         ),     // bmc uart_1, BMC TX to cpld
	.BMC_UART_1_RX      (BMC_UART_1_RX         ),     // bmc uart_1, cpld to BMC RX
	.BMC_UART_1_RTS     (BMC_UART_1_RTS        ),     // bmc uart_1, BMC RTS to cpld
                                                     
	.BMC_UART_4_TX      (BMC_UART_4_TX         ),     // bmc uart_4, BMC TX to cpld
	.BMC_UART_4_RX      (BMC_UART_4_RX         ),     // bmc uart_4, cpld to BMC RX
	.BMC_UART_4_RTS     (BMC_UART_4_RTS        ),     // bmc uart_1, BMC RTS to cpld
	                                                 
	.BMC_UART_5_TX      (BMC_UART_5_TX         ),     // bmc uart_5, BMC TX to cpld
	.BMC_UART_5_RX      (BMC_UART_5_RX         ),     // bmc uart_5, cpld to BMC RX
	                                                 
	.PANTHER_COM_TX     (panther_com_tx_in     ),     // panther uart TX to cpld
	.PANTHER_COM_RX     (panther_com_rx_out    ),     // panther uart RX, cpld to panther RX

//, input   PANEL_UART_RX         // front panel uart transceiver
//, output  PANEL_UART_TX         // front panel uart transceiver

	.FB_HDR_UART_RX     (FB_HDR_UART_RX        ),     // facebook debug header
	.FB_HDR_UART_TX     (FB_HDR_UART_TX        ),     // facebook debug header
	                                           
	.REAR_DBG_UART_RX   (REAR_DBG_UART_RX      ),     // facebook debug header
	.REAR_DBG_UART_TX   (REAR_DBG_UART_TX      ),     // facebook debug header
                                               
	.RMON_RS485_RX      (RMON_RS485_RX         ),     //  
	.RMON_RS485_TX      (RMON_RS485_TX         ),     //  
	.RMON_RS485_RTS     (RMON_RS485_RTS        )      //  

);


//-=================================  Tomahawk ROV   ===================================
// rw_0x2e for debug control
// rw_0x2e[0]: force vidsel to 100. 1: enable dynamic ROV VID
// wire     vid_en     = rw_0x2e[0]; 
wire [5:0]  reg_vid_ctrl  = rw_0x2e[5:0] ; 

//==================================  LED   =============================================
// rw_0x3c,rw_0x3d,rw_0x3e,rw_0x3f
// this is push button to rotate status, need more design here
//wire  port_led_sel =  CPLD_QSFP_LED_POSITION ;


led_if led_if_u
(
	
	
	.hot_reset_n 	             (hot_reset_n 	             ), 
	.warm_reset_n                (warm_reset_n               ), 
	.cold_reset_n                (cold_reset_n               ), 
	.pd_stby_reset_n             (PD_STBY_RESET_N            ),  // must use upper case
	.pd_main_reset_n             (pd_main_rst_n_dly2         ), 
	
	
	.clk                         (clk                        ),  // 50mhz clock input
	.clk_10hz                    (clk_10hz                   ),  // blinking clock input, 500ms??
	.clk_blink                   (clk_1hz                    ),  // blinking clock input, 500ms??
	.pd_main_ok                  (pd_main_ok                 ),  // power domain main is OK

	.ISO_XP_LED_CLK              (ISO_XP_LED_CLK             ),  // LED Stream Interface Clock input
	.ISO_XP_LED_DAT              (ISO_XP_LED_DAT             ),  // LED Data, synchronized to LED_CLK input 
	.ISO_XP_LED_STB              (ISO_XP_LED_STB             ),  // LED Strobe, synchronized to LED_CLK input
    .CPLD_QSFP_LED_POSITION      (CPLD_QSFP_LED_POSITION     ), // Top/Bottom LED stream selection (* chip_pin = "H15"  *)	 
	
	.rw_0x3c                     (rw_0x3c                    ),  // Tomahawk LED control 1
	.rw_0x3d                     (rw_0x3d                    ),  // Tomahawk LED control 2
	.rw_0x3e                     (rw_0x3e                    ),  // stream LED control 1
	.rw_0x3f                     (rw_0x3f                    ),  // stream LED control 2
 	.rw_0x46                     (rw_0x46                    ),  // stream LED control 2
                                                             	                 
	.LED_CLK0_BUF_EN             (LED_CLK0_BUF_EN            ),  // led stream 0 ISO buffer enable, active low
	.LED_CLEAR0                  (LED_CLEAR0                 ),  // led stream 0 clear
	.LED_CLK0                    (LED_CLK0                   ),  // led stream 0 clock output
	.LED_DATA0                   (LED_DATA0                  ),  // led stream 0 data output
	                                                                                                                      
//	system LED signals                                         
	.SYS_LED1_GREEN              (SYS_LED1_GREEN             ),  // system led 1, green
	.SYS_LED1_BLUE               (SYS_LED1_BLUE              ),  // system led 1, blue
	.SYS_LED1_RED                (SYS_LED1_RED               ),  // system led 1, red
	                                                             
	.SYS_LED2_GREEN              (SYS_LED2_GREEN             ),  // system led 1, green
	.SYS_LED2_BLUE               (SYS_LED2_BLUE              ),  // system led 1, blue
	.SYS_LED2_RED                (SYS_LED2_RED               ),  // system led 1, red
	 
	.top_led_active_n            (TOP_QSFP_SEL_STATUS_LED    ),  //top qsfp selection status         (* chip_pin = "D6"  *) 
	.bot_led_active_n            (BOTTOM_QSFP_SEL_STATUS_LED ),  //bottom qsfp selection status      (* chip_pin = "B4"  *) 
	                 
	.ro_0x1b                     (ro_0x1b                    )
	
) ;


//=======================================
wire   heart_attack_en   =  rw_0x2e[7] ; 
wire   fancard_heart     =  CARD_PRNT_N ;
wire   fan_fatal_out;
wire   fan_fatal = heart_attack_en? fan_fatal_out : 1'b0;


assign PWR_MAIN_EN   = fan_fatal ? 1'b0: pwr_main_en_out ; // if fan fatal(in 30 seconds duration), then main power is shutdown, standby power is still on

heart_attack
 #
(
    //10hz clock, 1hz heartbeat
    //.PULSE_WIDTH_HEART_BEAT     (300     ) // 30 seconds
    .PULSE_WIDTH_HEART_BEAT     (1200     ) // 120 seconds
)
heart_attack_inst
(
    .clk                (clk            ),      // 50mhz clock
    .clk_10hz           (clk_10hz       ),      // 10hz clock
    .fancard_heart      (fancard_heart  ),      // fancard heart beat
 
 	.fan_fatal          (fan_fatal_out  )       // fan fatal status                          
                   
) ;


//===========================================================
//  for debug purpose 
 
                                                                                                                                
assign  ro_0x1c[0]  =  PUSHBUTTON_RST_N       ;    // front panel push btn reset                                    (* chip_pin = "K16" *) 
assign  ro_0x1c[1]  =  CPLD_PUSH_BTN_RST_IN_N ;    // on board debug reset btn, used to enable/disable usrv when BMC is not ready                         (* chip_pin = "L15" *) 
assign  ro_0x1c[2]  =  DEBUG_RST_BTN_N        ;    // Debug Reset button from FB header pressed, DEBUG_RST_BTN_N will become low, need pullup             (* chip_pin = "A15"  *) 
assign  ro_0x1c[3]  =  CPLD_QSFP_LED_POSITION ;    // push button led position selection  (* chip_pin = "H15"  *)                                                                                                                                                                        
assign  ro_0x1c[4]  =  DEBUG_PORT_UART_SEL_N  ;    // Debug port select button in Front panel is pressed DEBUG_PORT_UART_SEL_N becomes low                 (* chip_pin = "C12"  *)    FB debug dongle
assign  ro_0x1c[5]  =  DEBUG_UART_SEL_0       ;    // debug port uart selection from BMC pin D15(GPIOE0)            (* chip_pin = "A13"  *) 
assign  ro_0x1c[6]  =  1'b0 ;
assign  ro_0x1c[7]  =  MICROSRV_PCIE_RST_N ;
 


assign  ro_0x1d[0]  =  BMC_CPLD_RESET1 ;            // spare reset signal from BMC                                    (* chip_pin = "J3"  *)  
assign  ro_0x1d[1]  =  BMC_CPLD_RESET2 ;            // spare reset signal from BMC                                    (* chip_pin = "K2"  *)  
assign  ro_0x1d[2]  =  LS_BMC_CPLD_RESET3 ;            // spare reset signal from BMC                                    (* chip_pin = "L3"  *)  
assign  ro_0x1d[3]  =  LS_BMC_CPLD_RESET4 ;            // spare reset signal from BMC                                    (* chip_pin = "N1"  *)  
assign  ro_0x1d[4]  =  LS_BMC_CPLD_SPARE7 ;            // spare signal from BMC                                          (* chip_pin = "G12" *) 
assign  ro_0x1d[5]  =  1'b0 ;               
assign  ro_0x1d[6]  =  microsrv_pwr_btn_n_buf ; 
assign  ro_0x1d[7]  =  usrv_uart_iso_en ;

//========================================================================================================

assign  debug_out[0]  =  BMC_ISO_BUF_EN      ;            // in EVTB, ONBRD_GREEN         // on board debug led, green
assign  debug_out[1]  =  BMC_MSERVE_ISOBUF_EN;            // in EVTB, ONBRD_BLUE          // on board debug led, blue 
assign  debug_out[2]  =  ISO_BUF_EN       ;               // in EVTB, ONBRD_RED           // on board debug led, red  


assign  debug_out[3]  =  MSERVE_ISOBUF_EN ;  

assign  debug_out[4]  =  hot_reset_n  ;
assign  debug_out[5]  =  warm_reset_n ;
assign  debug_out[6]  =  cold_reset_n ;
assign  debug_out[7]  =  1'b0 ;
  
//============================================= COM-E status register ro_0x18 ===========================================================  

assign  ro_0x18[0]   = LS_B_COM_TYPE0 ;	       //  (* chip_pin = "R1"	*)   Type signal from COMe	         CP2112_CPLD_GPIO4	GPIO to CP2112
assign  ro_0x18[1]   = LS_B_COM_TYPE1 ;	       //  (* chip_pin = "P4"	*)   Type signal from COMe	         CP2112_CPLD_GPIO5	GPIO to CP2112
assign  ro_0x18[2]   = LS_B_COM_TYPE2 ;	       //  (* chip_pin = "T2"	*)   Type signal from COMe	         CP2112_CPLD_GPIO6	GPIO to CP2112
assign  ro_0x18[3]   = LS_COM_GBE0_LINK1000_N; //  (* chip_pin = "P13"	*)   Gigabit ethernet link input from COMe(Active Low)	CPLD_DEBUG5(testpoint)	Testpoint
                                                  
assign  ro_0x18[4]   = COM_SUS_STAT_N ; //  (* chip_pin = "N13"	*)   Sleep status signal from COMe	NC	NC
assign  ro_0x18[5]   = LS_COM_SUS_S3_N; //  (* chip_pin = "P5"	*)   Sleep status signal from COMe	 CP2112_CPLD_GPIO7	GPIO to CP2112
assign  ro_0x18[6]   = COM_SUS_S4_N	  ; //  (* chip_pin = "J5"	*)   Sleep status signal from COMe	NC	NC
assign  ro_0x18[7]   = COM_SUS_S5_N	  ; //  (* chip_pin = "A4"	*)   Sleep status signal from COMe	NC	NC

// CB_RESET_N = MICROSRV_PCIE_RST_N
wire  cb_reset_n = MICROSRV_PCIE_RST_N;
// pd_main_rst_n_dly2 indicates that main power, inclduing COM-E power is OK
reg  pd_usrv_rst_n_seq ; 
reg  pd_usrv_rst_n_2seq;
reg  pd_usrv_rst_n_3seq;
reg  pd_usrv_rst_n_4seq;

//delay 4 seconds 
always @ (posedge clk_1hz )
    begin
       
       pd_usrv_rst_n_seq  <= pd_main_rst_n_dly2 ;   // input signal is in capital
       pd_usrv_rst_n_2seq <= pd_usrv_rst_n_seq ;  
       pd_usrv_rst_n_3seq <= pd_usrv_rst_n_2seq ;
       pd_usrv_rst_n_4seq <= pd_usrv_rst_n_3seq ;    
    end
    
wire   pd_usrv_rst_n = pd_usrv_delay? pd_usrv_rst_n_4seq : pd_main_rst_n_dly2;   // main reset for com-E ANDed

//reg_0x14[4]
//	TPM_SPI_PIRQ_N	           //  (* chip_pin = "M9"	*)   Interupt from TPM based SPI module(Active Low)	CPLD_DEBUG4(testpoint)	Testpoint

// reg 0x28                                                                 
assign  TPM_LPC_RST_N	      =  cb_reset_n & pd_usrv_rst_n & rw_0x28[0];       //  (* chip_pin = "F4"	*)   Reset output for TPM based LPC module(Active Low)	CPLD_DEBUG7(testpoint)	Testpoint
assign  LS_TPM_SPI_RST_N	  =  cb_reset_n & pd_usrv_rst_n & rw_0x28[1];       //  (* chip_pin = "F2"	*)   Reset output for TPM based SPI module(Active Low)	CPLD_DEBUG8(testpoint)	Testpoint
assign  LS_CPLD_COM_PHY_RST_N =  cb_reset_n & pd_usrv_rst_n & rw_0x28[2];       //  (* chip_pin = "C10"*)   COMe reset output(Active Low)	NC	NC 
assign  LS_LPC_RST_N	      =  cb_reset_n & pd_usrv_rst_n & rw_0x28[3];       //  (* chip_pin = "C7"	*)   BMC LPC reset output(Active Low)	NC	NC
                                                     
assign  LS_COM_NIC_ISOBUF_EN	  =  !(cb_reset_n & rw_0x28[4] ) ;    //  (* chip_pin = "N3"	*)   COMe SMBUS isolation buffer enable(Active Low)	CP2112_CPLD_GPIO2	GPIO to CP2112
assign  LS_COM_PANTHER_ISOBUF_EN  =  !(cb_reset_n & rw_0x28[5] ) ;    //  (* chip_pin = "P2"	*)   COMe I2C isolation buffer enable(Active Low)	CP2112_CPLD_GPIO3	GPIO to CP2112
//assign  LS_COM_PWROK	          =  rw_0x28[6];                      //  (* chip_pin = "K13"	*)   Power ok signal to COMe Module	                CPLD_DEBUG6(testpoint)	Testpoint



assign  LS_COM_PWROK          = pd_usrv_rst_n & rw_0x28[6]; 
assign  MICROSRV_PWR_BTN_N    = pd_usrv_rst_n & microsrv_pwr_btn_n_buf ;


assign  MICROSRV_RST_N        = microsrv_rst_n_out ? 1'bZ : 1'b0 ;   // use tri-state to avoid potential conflict
 
// reg_0x29                                                                   
assign LS_BMC_PHY_WP 	      = rw_0x29[0];  //  (* chip_pin = "J12"	*)  "BMC PHY write protect signal  1:Disable,  0:Enable"	NC	NC                             
assign LS_FP_PHY_WP	          = rw_0x29[1];  //  (* chip_pin = "H12"	*)  "Front panel  PHY write protect signal 1:Disable,  0:Enable"	NC	NC                               
assign CPLD_BMC_SPIBOOT_WP_N  = !rw_0x29[2]; //  (* chip_pin = "G15"	*)  "BMC Spi boot write protect signal, 1:Disable, 0:Enable"	CPLD_IN3	Spare interupt  input to Powermanager  

// reg 0x42 to implement CLK_PLL_RESET[2:0] register
assign ISO_XP_CORE_CLK_PLL_RST_N = rw_0x44[0]; // Core Clock PLL reset. When low core clock pll is reset 
assign ISO_XP_MAC_CLK_PLL_RST_N  = rw_0x44[1]; // Mac Clock PLL reset. When low mac clock pll is reset
assign ISO_XP_PEX_CLK_PLL_RST_N  = rw_0x44[2]; // PEX Clock PLL reset. When low pex clock pll is reset


endmodule
