/*
facebook wedge100
Model:
Revision: V0.1,
History :
2015/02/26 - Draft


    Pin Number  Pin Name    Type    Wedge100 DVT- cpld signals  New Function    Wedge100 EVTB cpld signals  Function
1   M9  DIFFIO_B13n/DEV_CLRn    Input   TPM_SPI_PIRQ_N  Interupt from TPM based SPI module(Active Low)  CPLD_DEBUG4(testpoint)  Testpoint
2   F4  DIFFIO_L6p  Output  TPM_LPC_RST_N   Reset output for TPM based LPC module(Active Low)   CPLD_DEBUG7(testpoint)  Testpoint
3   F2  DIFFIO_L6n  Output  LS_TPM_SPI_RST_N    Reset output for TPM based SPI module(Active Low)   CPLD_DEBUG8(testpoint)  Testpoint
4   P13 DIFFIO_B22n Input   LS_COM_GBE0_LINK1000_N  Gigabit ethernet link input from COMe(Active Low)   CPLD_DEBUG5(testpoint)  Testpoint
5   K13 DIFFIO_R14n Output  LS_COM_PWROK    Power ok signal to COMe Module  CPLD_DEBUG6(testpoint)  Testpoint
6   N13 IO_N13  Input   COM_SUS_STAT_N  Sleep status signal from COMe   NC  NC
7   C10 IO_C10  Output  LS_CPLD_COM_PHY_RST_N   COMe reset output(Active Low)   NC  NC
8   C7  IO_C7   Output  LS_LPC_RST_N    BMC LPC reset output(Active Low)    NC  NC
9   A4  IO_A4   Input   COM_SUS_S5_N    Sleep status signal from COMe   NC  NC
10  R1  DIFFIO_B1p  Input   LS_B_COM_TYPE0  Type signal from COMe   CP2112_CPLD_GPIO4   GPIO to CP2112
11  P4  DIFFIO_B1n  Input   LS_B_COM_TYPE1  Type signal from COMe   CP2112_CPLD_GPIO5   GPIO to CP2112
12  T2  DIFFIO_B2p  Input   LS_B_COM_TYPE2  Type signal from COMe   CP2112_CPLD_GPIO6   GPIO to CP2112
13  P5  DIFFIO_B2n  Input   LS_COM_SUS_S3_N Sleep status signal from COMe   CP2112_CPLD_GPIO7   GPIO to CP2112
14  J5  CLK1    Input   COM_SUS_S4_N    Sleep status signal from COMe   NC  NC
15  J12 CLK2    Output  LS_BMC_PHY_WP   "BMC PHY write protect signal
                                     1:Disable
                                     0:Enable"  NC  NC
16  H12 CLK3    Output  LS_FP_PHY_WP    "Front panel  PHY write protect signal
                                     1:Disable
                                     0:Enable"  NC  NC
17  G15 DIFFIO_R8n  Output  CPLD_BMC_SPIBOOT_WP_N   "BMC Spi boot write protect signal
                                                     1:Disable
                                                     0:Enable"  CPLD_IN3    Spare interupt  input to Powermanager
18  N3  DIFFIO_L21p Output  LS_COM_NIC_ISOBUF_EN    COMe SMBUS isolation buffer enable(Active Low)  CP2112_CPLD_GPIO2   GPIO to CP2112
19  P2  DIFFIO_L21n Output  LS_COM_PANTHER_ISOBUF_EN    COMe I2C isolation buffer enable(Active Low)    CP2112_CPLD_GPIO3   GPIO to CP2112
*/

//-----------------------------------------------------------------------------
// Title       : Wedge100 CPLD Design top module
// Design      : Wedge100 CPLD Design
// File        : wedge100_syscpld_top.v
//-----------------------------------------------------------------------------
// Version     : Ver 2.0
// Generated   : 03/12/2015
// Changes     : 1. Added the 22 additional signals
//             : 2. Removed the unused signals mentioned in excel sheet
//             : 3. Changed the name of signals that are level shifted and
//                  those mentioned in excel sheet
//-----------------------------------------------------------------------------
// Version     : Ver 2.1
// Generated   : 02/02/2016
// Changes     : 1. Added the LED shift register implementation signals
//-----------------------------------------------------------------------------
// Description:- Wedge100 CPLD Design top module
//-----------------------------------------------------------------------------

`include "wedge100_syscpld_def.v"

module wedge100_syscpld #
(
    parameter [27:00]   PULSE_WIDTH_HOT    = 5000000 , // 100ms - clock= 50MHz
    parameter [27:00]   PULSE_WIDTH_WARM   = 10000000, // 200ms - clock= 50MHz
    parameter [27:00]   PULSE_WIDTH_COLD   = 19000000, // 380ms - clock= 50MHz
    parameter [27:00]   PULSE_WID_BMC_MAIN = 1000000 , // 20ms  - clock= 50MHz
    parameter [27:00]   PULSE_WID_PUSH_BTN = 1000000 , // 20ms  - clock= 50MHz
    parameter           SW_DEB_LEN         = 32      , // Switch Debounce time - 32:=> 640ns if clk = 50Hz
    parameter  [6:0]    MAIN_I2C_DevADDR   = 7'h32   , // Main I2C Slave Address
    parameter  [6:0]    BMC_I2C_DevADDR    = 7'h31   , // BMC I2C Slave Address
    parameter  [7:0]    MAIN_End_Of_ADDR   = 8'hFF   , // Main I2C Slave End Address
    parameter  [7:0]    BMC_End_Of_ADDR    = 8'hFF   , // BMC I2C Slave End Address
    //parameter           CPLD_REVISION      = 8'd1    // zyao: wedge100 initial revision
    //parameter           CPLD_REVISION      = 8'd2    // zyao: wedge100 2nd version
    //parameter           CPLD_REVISION      = 8'd3    // zyao: wedge100 3nd version
    parameter           CPLD_REVISION      = 8'd4      // zyao: wedge100 4th version

)
(
   (* chip_pin = "J12"   *) input   clk                    // 50mhz clock input

// led stream signals
,  (* chip_pin = "F2"   *) input   ISO_XP_LED_CLK          // LED Stream Interface Clock input
,  (* chip_pin = "F1"   *) input   ISO_XP_LED_DAT          // LED Data, synchronized to LED_CLK input
,  (* chip_pin = "F6"   *) input   ISO_XP_LED_STB          // LED Strobe, synchronized to LED_CLK input
,  (* chip_pin = "H15"  *) input   CPLD_QSFP_LED_POSITION  // push button led position selection

,  (* chip_pin = "L4"   *) output  ISO_XPLIANT_RST_N       // tomahawk ISO_XPLIANT_RST_N
,  (* chip_pin = "G2"   *) inout   ISO_XP_GPIO_0           // Xpliant GPIO signal
,  (* chip_pin = "G3"   *) inout   ISO_XP_GPIO_1           // Xpliant GPIO signal
,  (* chip_pin = "G1"   *) inout   ISO_XP_GPIO_2           // Xpliant GPIO signal
,  (* chip_pin = "G4"   *) inout   ISO_XP_GPIO_3           // Xpliant GPIO signal

,  (* chip_pin = "M10"  *) output  LED_CLK0_BUF_EN         // led stream 0 ISO buffer enable
,  (* chip_pin = "P10"  *) output  LED_CLEAR0              // led stream 0 clear
,  (* chip_pin = "N10"  *) output  LED_CLK0                // led stream 0 clock output
,  (* chip_pin = "T11"  *) output  LED_DATA0               // led stream 0 data output

// main i2c bus
,  (* chip_pin = "T9"   *) inout   MAIN_I2C_SDA            // I2C Bus controlled by micro-server
,  (* chip_pin = "T8"   *) inout   MAIN_I2C_SCL            // I2C Bus controlled by micro-server
// BMC cpld i2c bus
,  (* chip_pin = "R8"   *) inout   BMC_CPLD_SDA            // I2C Bus to BMC
,  (* chip_pin = "N8"   *) inout   BMC_CPLD_SCL            // I2C Bus to BMC

,  (* chip_pin = "D3"   *) output  ISO_XP_CORE_CLK_PLL_RST_N  // Core Clock PLL reset.When low core clock pll is reset
,  (* chip_pin = "C2"   *) output  ISO_XP_MAC_CLK_PLL_RST_N   // Mac Clock PLL reset.When low mac clock pll is reset
,  (* chip_pin = "C3"   *) output  ISO_XP_PEX_CLK_PLL_RST_N   // PEX Clock PLL reset.When low pex clock pll is reset
,  (* chip_pin = "E3"   *) input   ISO_XP_CORE_PLL_LOCK       // Core clock PLL lock indication 0-not locked,1- locked
,  (* chip_pin = "D2"  *)  input   ISO_XP_MAC_PLL_LOCK        // Mac clock PLL lock indication 0-not locked,1- locked
,  (* chip_pin = "E4"  *)  input   ISO_XP_PEX_PLL_LOCK        // PEX clock PLL lock indication 0-not locked,1- locked

,  (* chip_pin = "L2"   *) inout   LS_CP2112_CPLD_GPIO1       // GPIO1
,  (* chip_pin = "L1"   *) inout   LS_CP2112_CPLD_GPIO0       // GPIO0

// --------------------------------------------------------
// psu signals
,  (* chip_pin = "D10"  *) input   PSU1_PRSNT_N         // psu-1 present, active low
,  (* chip_pin = "B10"  *) input   PSU1_PWR_OK          // psu-1 power ok
,  (* chip_pin = "E8"   *) input   PSU1_INPUT_OK        // psu-1 input power ok
,  (* chip_pin = "A6"   *) input   PSU1_SMB_ALERT_N     // psu-1 sm bus alert, active low

,  (* chip_pin = "C6"   *) input   PSU2_PRSNT_N         // psu-2 present, active low
,  (* chip_pin = "B3"   *) input   PSU2_PWR_OK          // psu-2 power ok
,  (* chip_pin = "D5"   *) input   PSU2_INPUT_OK        // psu-2 input power ok
,  (* chip_pin = "A2"   *) input   PSU2_SMB_ALERT_N     // psu-2 sm bus alert, active low

// power status input    0x21
,  (* chip_pin = "M6"   *) input   P1V2_STBY_OK         // 1.2V standby power OK
,  (* chip_pin = "T5"   *) output  PWR_STBY_OK          //  standby power OK

// IR power status, 0x22
,  (* chip_pin = "P7"   *) input   VCORE_VRDY1          // Vcore voltage ready status
,  (* chip_pin = "R6"   *) input   VCORE_HOT            // over temperature or over current alarm
,  (* chip_pin = "N7"   *) input   VANLG_VRDY1          //
,  (* chip_pin = "M7"   *) input   VANLG_HOT            // over temperature or over current alarm
,  (* chip_pin = "R7"   *) input   V3V3_VRDY1           //
,  (* chip_pin = "P8"   *) input   V3V3_HOT             // over temperature or over current alarm

// interrupt signals, 0x22
,  (* chip_pin = "R13"  *) input   I2C_IO_0_INT_N       // I2C IO device PCA9535 Interrupt
,  (* chip_pin = "N12"  *) input   I2C_IO_1_INT_N       // I2C IO device PCA9535 Interrupt
,  (* chip_pin = "R14"  *) input   I2C_IO_2_INT_N       // I2C IO device PCA9535 Interrupt
,  (* chip_pin = "P12"  *) input   I2C_IO_3_INT_N       // I2C IO device PCA9535 Interrupt
,  (* chip_pin = "T15"  *) input   I2C_IO_4_INT_N       // I2C IO device PCA9535 Interrupt
,  (* chip_pin = "R16"  *) input   I2C_IO_5_INT_N       // I2C IO device PCA9535 Interrupt

//------------------------------------------------------------------------
// misc control signals  rw_0x3d
,  (* chip_pin = "T7"   *) output  DUAL_BOOT_EN         //  enable dual boot

// micro-server signals
,  (* chip_pin = "C8"   *) input   MICROSRV_PRSNT_N     // micro-server reset output
,  (* chip_pin = "E7"   *) input   MICROSRV_PCIE_RST_N  // micro-server reset output com-E CB_RESET_N
,  (* chip_pin = "B6"   *) output  MICROSRV_PWR_BTN_N   // micro-server reset output
,  (* chip_pin = "D7"   *) input   MSERV_POWERUP        // micro-server power up enable driven from BMC

//  Reset control
,  (* chip_pin = "L12"  *) input   PD_STBY_RESET_N      // standby reset input from pwr1014a
,  (* chip_pin = "T4"   *) input   PD_MAIN_RESET_N      // main power reset input from pwr1014a
,  (* chip_pin = "N13"  *) input   BMC_MAIN_RESET_N     // BMC request to reset the system

,  (* chip_pin = "F13"  *) output  P0_QRESET_N          // Reset output to QSFP port 0
,  (* chip_pin = "E15"  *) output  P1_QRESET_N          // Reset output to QSFP port 1
,  (* chip_pin = "F14"  *) output  P2_QRESET_N          // Reset output to QSFP port 2
,  (* chip_pin = "D16"  *) output  P3_QRESET_N          // Reset output to QSFP port 3
,  (* chip_pin = "E12"  *) output  P4_QRESET_N          // Reset output to QSFP port 4
,  (* chip_pin = "D15"  *) output  P5_QRESET_N          // Reset output to QSFP port 5
,  (* chip_pin = "C15"  *) output  P6_QRESET_N          // Reset output to QSFP port 6
,  (* chip_pin = "E13"  *) output  P7_QRESET_N          // Reset output to QSFP port 7
,  (* chip_pin = "E14"  *) output  P8_QRESET_N          // Reset output to QSFP port 8
,  (* chip_pin = "C14"  *) output  P9_QRESET_N          // Reset output to QSFP port 9
,  (* chip_pin = "C13"  *) output  P10_QRESET_N         // Reset output to QSFP port 10
,  (* chip_pin = "B16"  *) output  P11_QRESET_N         // Reset output to QSFP port 11
,  (* chip_pin = "D12"  *) output  P12_QRESET_N         // Reset output to QSFP port 12
,  (* chip_pin = "B14"  *) output  P13_QRESET_N         // Reset output to QSFP port 13
,  (* chip_pin = "C11"  *) output  P14_QRESET_N         // Reset output to QSFP port 14
,  (* chip_pin = "B13"  *) output  P15_QRESET_N         // Reset output to QSFP port 15
,  (* chip_pin = "E11"  *) output  P16_QRESET_N         // Reset output to QSFP port 16
,  (* chip_pin = "B12"  *) output  P17_QRESET_N         // Reset output to QSFP port 17
,  (* chip_pin = "B11"  *) output  P18_QRESET_N         // Reset output to QSFP port 18
,  (* chip_pin = "A12"  *) output  P19_QRESET_N         // Reset output to QSFP port 19
,  (* chip_pin = "E10"  *) output  P20_QRESET_N         // Reset output to QSFP port 20
,  (* chip_pin = "A11"  *) output  P21_QRESET_N         // Reset output to QSFP port 21
,  (* chip_pin = "A10"  *) output  P22_QRESET_N         // Reset output to QSFP port 22
,  (* chip_pin = "C9"   *) output  P23_QRESET_N         // Reset output to QSFP port 23
,  (* chip_pin = "B9"   *) output  P24_QRESET_N         // Reset output to QSFP port 24
,  (* chip_pin = "D9"   *) output  P25_QRESET_N         // Reset output to QSFP port 25
,  (* chip_pin = "A9"   *) output  P26_QRESET_N         // Reset output to QSFP port 26
,  (* chip_pin = "E9"   *) output  P27_QRESET_N         // Reset output to QSFP port 27
,  (* chip_pin = "B8"   *) output  P28_QRESET_N         // Reset output to QSFP port 28
,  (* chip_pin = "A8"   *) output  P29_QRESET_N         // Reset output to QSFP port 29
,  (* chip_pin = "D8"   *) output  P30_QRESET_N         // Reset output to QSFP port 30
,  (* chip_pin = "A7"   *) output  P31_QRESET_N         // Reset output to QSFP port 31

,  (* chip_pin = "M14"  *) output  USB_BRDG_RST_N       // usb bridge reset output
,  (* chip_pin = "K12"  *) output  USB_HUB_RST_N        // usb hub reset output
,  (* chip_pin = "M11"  *) output  FANCARD_RST_N        // fan_ctrl card reset output

,  (* chip_pin = "R5"  *)  output  BMC_RST_N            // BMC reset signal

,  (* chip_pin = "C10"  *) output  MICROSRV_RST_N       // micro-server reset output
,  (* chip_pin = "N9"   *) output  BCM5387_RST_N        // OOB switch BCM5387 reset output
,  (* chip_pin = "F11"  *) output  FP_PHY_RST_N         // front port PHY reset output
,  (* chip_pin = "T10"  *) output  BCM54616_PHY_RST_N   // on-board PHY BCM54616 reset output

,  (* chip_pin = "D4"   *) output  I2C_MUX_RST0_N       // i2c mux 0 reset output
,  (* chip_pin = "B1"   *) output  I2C_MUX_RST1_N       // i2c mux 1 reset output
,  (* chip_pin = "C5"   *) output  I2C_MUX_RST2_N       // i2c mux 2 reset output
,  (* chip_pin = "C4"   *) output  I2C_MUX_RST3_N       // i2c mux 3 reset output
,  (* chip_pin = "D13"  *) output  I2C_MUX_PSU_RST_N    // i2c mux for psu reset output
,  (* chip_pin = "M12"  *) output  I2C_MUX_EXP_RST_N    // i2c mux for qsfp LLI signals reset output

// power control signals
,  (* chip_pin = "D11" *)  output  PWR_CYC_ALL_N        // power cycle output to pwr1014a, power cycle all power
,  (* chip_pin = "D14" *)  output  PWR_MAIN_EN          // enable main power, active high
,  (* chip_pin = "C7"  *)  output  PWR_MAIN_FORCE       // force main power, debug only, should not change by SW
,  (* chip_pin = "F12" *)  output  PWR_MSERVER_FORCE    // force micro-server power, debug only, should not change by SW
,  (* chip_pin = "A5"  *)  input   XP_POWERUP           // tomahawk power up from BMC

// uart mux signals

,  (* chip_pin = "R1"  *)  input   BMC_UART_1_TX        // bmc uart_1, BMC TX to cpld
,  (* chip_pin = "P4"  *)  output  BMC_UART_1_RX        // bmc uart_1, cpld to BMC RX
,  (* chip_pin = "P9"  *)  input   BMC_UART_1_RTS       // bmc uart_1, BMC RTS to cpld

,  (* chip_pin = "T2"  *)  input   BMC_UART_4_TX        // bmc uart_4, BMC TX to cpld
,  (* chip_pin = "P5"  *)  output  BMC_UART_4_RX        // bmc uart_4, cpld to BMC RX
,  (* chip_pin = "R9"  *)  input   BMC_UART_4_RTS       // bmc uart_1, BMC RTS to cpld

,  (* chip_pin = "R3"  *)  input   BMC_UART_5_TX        // bmc uart_5, BMC TX to cpld
,  (* chip_pin = "N5"  *)  output  BMC_UART_5_RX        // bmc uart_5, cpld to BMC RX

,  (* chip_pin = "P6"  *)  inout   PANTHER_COM_TX       // panther uart TX to cpld
,  (* chip_pin = "N6"  *)  output  PANTHER_COM_RX       // panther uart RX, cpld to panther RX

,  (* chip_pin = "N15" *) input   FB_HDR_UART_RX        // facebook debug header
,  (* chip_pin = "N14" *) output  FB_HDR_UART_TX        // facebook debug header

,  (* chip_pin = "N16" *) input   REAR_DBG_UART_RX      // facebook debug header
,  (* chip_pin = "M13" *) output  REAR_DBG_UART_TX      // facebook debug header

,  (* chip_pin = "M15" *) input   RMON_RS485_RX         //  rackmon connector
,  (* chip_pin = "L14" *) output  RMON_RS485_TX         //  rackmon connector
,  (* chip_pin = "L13" *) output  RMON_RS485_RTS        // rackmon connector

//board ID signals
,  (* chip_pin = "K15"  *) input   BOARD_REV_ID0        //board revision ID
,  (* chip_pin = "K14"  *) input   BOARD_REV_ID1        //board revision ID
,  (* chip_pin = "L16"  *) input   BOARD_REV_ID2        //board revision ID


//  system LED signals
,  (* chip_pin = "J15"  *) output  SYS_LED1_GREEN       // system led 1, green
,  (* chip_pin = "J14"  *) output  SYS_LED1_BLUE        // system led 1, blue
,  (* chip_pin = "J16"  *) output  SYS_LED1_RED         // system led 1, red

,  (* chip_pin = "J13"  *) output  SYS_LED2_GREEN       // system led 2, green
,  (* chip_pin = "H16"  *) output  SYS_LED2_BLUE        // system led 2, blue
,  (* chip_pin = "H13"  *) output  SYS_LED2_RED         // system led 2, red

,  (* chip_pin = "B4"  *)  output  BOTTOM_QSFP_SEL_STATUS_LED //bottom qsfp selection status
,  (* chip_pin = "D6"  *)  output  TOP_QSFP_SEL_STATUS_LED    //top qsfp selection status

//      rest of signals
,  (* chip_pin = "B5"  *)  input   BMC_HEARTBEAT_N            // BMCpower good signal from BMC
,  (* chip_pin = "K13" *)  input   BMC_READY_N                // BMC ready signal

,  (* chip_pin = "M8"  *)  input   BMC_PWR_BTN_OUT_N          // pwr btn out from bmc
,  (* chip_pin = "M9"  *)  input   BMC_PWR_BTN_IN_N           // pwr btn input from on-board button

// interrupts
,  (* chip_pin = "G13"  *) input   PM_SM_ALERT_N              // sm bus alert from power manager
,  (* chip_pin = "G14"  *) input   VCORE_SMB_ALERT            // VCORE supply sm bus alert
,  (* chip_pin = "E16"  *) input   V3_3V_SMB_ALERT            // V3_3V supply sm bus alert
,  (* chip_pin = "F15"  *) input   VANLG_SMB_ALERT            // VANLG supply sm bus alert
,  (* chip_pin = "L11"  *) input   TEMP_SENSOR_ALERT          // temperature sensor alert signal

,  (* chip_pin = "F16"  *) output  SMB_ALERT                  //  logical OR of power supply sm bus alert to bmc
,  (* chip_pin = "G16"  *) output  BMC_CPLD_POWER_INT         // power interupt signal from BMC
,  (* chip_pin = "H14"  *) output  BMC_CPLD_QSFP_INT          // interupt from cpld to BMC

,  (* chip_pin = "M16"  *) input   CARD_PRNT_N                // card present signal from rackmon connector


,  (* chip_pin = "R4"  *)  input   BMC_ISO_BUF_EN             // Request from BMC to enable isolation buffers
,  (* chip_pin = "P14" *)  input   BMC_MSERVE_ISOBUF_EN       // request from BMC to enable microserver isolation buffer

,  (* chip_pin = "P13"  *) output  ISO_BUF_EN                 // isolation buffer enable
,  (* chip_pin = "P15"  *) output  MSERVE_ISOBUF_EN           // Mserver isolation buffer enable
,  (* chip_pin = "H1"   *) output  LS_BMC_COM_ISOBUF_EN       // EVTB COM-e test card isolation buffer enable

// BMC to enable second protection, will disable in MP
,  (* chip_pin = "E6"  *)  input   BMC_SPI_WP_N               // bmc request to enable  write protect of Secondary boot device
,  (* chip_pin = "B7"  *)  output  CPLD_SPI_SEC_BOOT_WP_N     // Secondary boot device write protect enable

//reset signal inputs
,  (* chip_pin = "E2"  *)  input   LS_BMC_WDTRST1             // BMC watch dog timer reset output
,  (* chip_pin = "F5"  *)  input   LS_BMC_WDTRST2             // BMC watch dog timer reset output

,  (* chip_pin = "A4"  *)  input   BMC_CPLD_RESET1            // spare reset signal from BMC
,  (* chip_pin = "G12" *)  input   BMC_CPLD_RESET2            // spare reset signal from BMC
,  (* chip_pin = "J3"  *)  input   LS_BMC_CPLD_RESET3         // spare reset signal from BMC
,  (* chip_pin = "K2"  *)  input   LS_BMC_CPLD_RESET4         // spare reset signal from BMC
,  (* chip_pin = "K5"  *)  input   LS_BMC_CPLD_SPARE7         // spare signal from BMC

,  (* chip_pin = "K16" *) input   PUSHBUTTON_RST_N            // front panel push btn reset
,  (* chip_pin = "L15" *) input   CPLD_PUSH_BTN_RST_IN_N      // on board debug reset btn

,  (* chip_pin = "E5"  *) output  LS_DPLL_RST_N               // DPLL rst signal
,  (* chip_pin = "D1"  *) output  LS_USB_SPI_BRIDGE_RST_N     // usb to spi bridge reset signal

,  (* chip_pin = "C12" *) input   DEBUG_PORT_UART_SEL_N       // Debug port select button in Front panel is pressed DEBUG_PORT_UART_SEL_N becomes low
,  (* chip_pin = "A13" *) input   DEBUG_UART_SEL_0            // debug port uart selection from BMC
,  (* chip_pin = "A15" *) input   DEBUG_RST_BTN_N             // Debug Reset button in Front panel is pressed, DEBUG_RST_BTN_N will become low


//  debug probe signals, test point on PCB
,  (* chip_pin = "M3"  *) output  CPLD_DEBUG1                 // in EVTB, ONBRD_GREEN         // on board debug led, green
,  (* chip_pin = "N3"  *) output  CPLD_DEBUG2                 // in EVTB, ONBRD_BLUE          // on board debug led, blue
,  (* chip_pin = "P2"  *) output  CPLD_DEBUG3                 // in EVTB, ONBRD_RED           // on board debug led, red

// DVTA new signals
,  (* chip_pin = "M4" *) input   LS_COM_GBE0_LINK1000_N       // Gigabit ethernet link input from COMe(Active Low)  CPLD_DEBUG5(testpoint)  Testpoint
,  (* chip_pin = "R11"*) input   TPM_SPI_PIRQ_N               // Interupt from TPM based SPI module(Active Low) CPLD_DEBUG4(testpoint)  Testpoint

,  (* chip_pin = "L3" *) output TPM_LPC_RST_N                 // Reset output for TPM based LPC module(Active Low)  CPLD_DEBUG7(testpoint)  Testpoint
,  (* chip_pin = "N1" *) output LS_TPM_SPI_RST_N              // Reset output for TPM based SPI module(Active Low)  CPLD_DEBUG8(testpoint)  Testpoint
,  (* chip_pin = "K4" *) output LS_CPLD_COM_PHY_RST_N         // COMe reset output(Active Low)  NC  NC
,  (* chip_pin = "L5" *) output LS_LPC_RST_N                  // BMC LPC reset output(Active Low)   NC  NC

,  (* chip_pin = "N2" *) output LS_COM_PWROK                  // Power ok signal to COMe Module                 CPLD_DEBUG6(testpoint)  Testpoint

,  (* chip_pin = "H2" *) input  LS_B_COM_TYPE0                // Type signal from COMe           CP2112_CPLD_GPIO4  GPIO to CP2112
,  (* chip_pin = "G5" *) input  LS_B_COM_TYPE1                // Type signal from COMe           CP2112_CPLD_GPIO5  GPIO to CP2112
,  (* chip_pin = "H3" *) input  LS_B_COM_TYPE2                // Type signal from COMe           CP2112_CPLD_GPIO6  GPIO to CP2112

,  (* chip_pin = "N11"*) input  COM_SUS_STAT_N                // Sleep status signal from COMe  NC  NC
,  (* chip_pin = "J1" *) input  LS_COM_SUS_S3_N               // Sleep status signal from COMe   CP2112_CPLD_GPIO7  GPIO to CP2112
,  (* chip_pin = "H12"*) input  COM_SUS_S4_N                  // Sleep status signal from COMe  NC  NC
,  (* chip_pin = "T12"*) input  COM_SUS_S5_N                  // Sleep status signal from COMe  NC  NC

,  (* chip_pin = "H5" *) output LS_BMC_PHY_WP                 // "BMC PHY write protect signal  1:Disable,  0:Enable"   NC  NC
,  (* chip_pin = "J5" *) output LS_FP_PHY_WP                  // "Front panel  PHY write protect signal 1:Disable,  0:Enable"   NC  NC
,  (* chip_pin = "G15"*) output CPLD_BMC_SPIBOOT_WP_N         // "BMC Spi boot write protect signal, 1:Disable, 0:Enable"   CPLD_IN3    Spare interupt  input to Powermanager

,  (* chip_pin = "K3" *) output LS_COM_NIC_ISOBUF_EN          // COMe SMBUS isolation buffer enable(Active Low) CP2112_CPLD_GPIO2   GPIO to CP2112
,  (* chip_pin = "M1" *) output LS_COM_PANTHER_ISOBUF_EN      // COMe I2C isolation buffer enable(Active Low)   CP2112_CPLD_GPIO3   GPIO to CP2112

// ,  (* chip_pin = "K1"    *) output   ISO_XP_SL_SCL         //  XPLIANT SLAVE SCL
// ,  (* chip_pin = "J4"    *) output   ISO_XP_SL_SDA         //  XPLIANT SLAVE SDA
// ,  (* chip_pin = "E3"    *) output   ISO_XP_SL_MDC         //  XPLIANT SLAVE MDC
// ,  (* chip_pin = "H4"    *) output   ISO_XP_SL_MDIO        //  XPLIANT SLAVE MDIO

,  (* chip_pin = "M2"   *) input    ISO_XP_REI_INIT_DONE      // REI INIT DONE OUTPUT
,  (* chip_pin = "F4"   *) input    ISO_XP_INT_N              // XPLIANT INTERRUPT SIGNAL
,  (* chip_pin = "E1"   *) input    ISO_XP_OVERT_N            // XLIPANT TEMP SENSOR OUTPUT
,  (* chip_pin = "F3"   *) input    ISO_XP_TEMP_ALRT_N        // XLIPANT TEMP SENSOR OUTPUT

);
wire  [7:0]  debug_out;


wedge100_syscpld_top  #
(
//  parameters
  .PULSE_WIDTH_HOT     ( PULSE_WIDTH_HOT     ),
  .PULSE_WIDTH_WARM    ( PULSE_WIDTH_WARM    ),
  .PULSE_WIDTH_COLD    ( PULSE_WIDTH_COLD    ),
  .PULSE_WID_BMC_MAIN  ( PULSE_WID_BMC_MAIN  ),
  .PULSE_WID_PUSH_BTN  ( PULSE_WID_PUSH_BTN  ),
  .SW_DEB_LEN          ( SW_DEB_LEN          ),
  .MAIN_I2C_DevADDR    ( MAIN_I2C_DevADDR    ),
  .BMC_I2C_DevADDR     ( BMC_I2C_DevADDR     ),
  .MAIN_End_Of_ADDR    ( MAIN_End_Of_ADDR    ),
  .BMC_End_Of_ADDR     ( BMC_End_Of_ADDR     ),
  .CPLD_REVISION       ( CPLD_REVISION       )

)

wedge100_syscpld_top_inst
(

    .clk                             (clk                       ), // 50mhz clock input

    // led stream signals
    .LED_CLK0_BUF_EN                 (LED_CLK0_BUF_EN           ), // led stream 0 ISO buffer enable      (* chip_pin = "M10"  *)
    .LED_CLEAR0                      (LED_CLEAR0                ), // led stream 0 clear                  (* chip_pin = "P10"  *)
    .LED_CLK0                        (LED_CLK0                  ), // led stream 0 clock output           (* chip_pin = "N10"  *)
    .LED_DATA0                       (LED_DATA0                 ), // led stream 0 data output            (* chip_pin = "T11"  *)

// main i2c bus
    .ISO_XP_LED_CLK                  (ISO_XP_LED_CLK            ), // LED Stream Interface Clock input  (* chip_pin = "T9"  *)
    .ISO_XP_LED_DAT                  (ISO_XP_LED_DAT            ), // LED Data, synchronized to LED_CLK input   (* chip_pin = "T8"  *)
    .ISO_XP_LED_STB                  (ISO_XP_LED_STB            ), // LED Strobe, synchronized to LED_CLK input
    .CPLD_QSFP_LED_POSITION          (CPLD_QSFP_LED_POSITION    ), // Top/Bottom LED stream selection (* chip_pin = "H15"  *)

// --------------------------------------------------------
// psu signals
    .PSU1_PRSNT_N                    (PSU1_PRSNT_N              ),  // psu-1 present, active low        (* chip_pin = "D10" *)
    .PSU1_PWR_OK                     (PSU1_PWR_OK               ),  // psu-1 power ok                   (* chip_pin = "B10" *)
    .PSU1_INPUT_OK                   (PSU1_INPUT_OK             ),  // psu-1 input power ok             (* chip_pin = "E8"  *)
    .PSU1_SMB_ALERT_N                (PSU1_SMB_ALERT_N          ),  // psu-1 sm bus alert, active low   (* chip_pin = "A6"  *)

    .PSU2_PRSNT_N                    (PSU2_PRSNT_N              ),  // psu-2 present, active low        (* chip_pin = "C6"  *)
    .PSU2_PWR_OK                     (PSU2_PWR_OK               ),  // psu-2 power ok                   (* chip_pin = "B3"  *)
    .PSU2_INPUT_OK                   (PSU2_INPUT_OK             ),  // psu-2 input power ok             (* chip_pin = "D5"  *)
    .PSU2_SMB_ALERT_N                (PSU2_SMB_ALERT_N          ),  // psu-2 sm bus alert, active low   (* chip_pin = "A2"  *)

    .MAIN_I2C_SDA                    (MAIN_I2C_SDA              ),  // I2C Bus controlled by micro-server (* chip_pin = "T9"  *)
    .MAIN_I2C_SCL                    (MAIN_I2C_SCL              ),  // I2C Bus controlled by micro-server (* chip_pin = "T8"  *)
    .BMC_CPLD_SDA                    (BMC_CPLD_SDA              ),  // I2C Bus to BMC                     (* chip_pin = "R8"  *)
    .BMC_CPLD_SCL                    (BMC_CPLD_SCL              ),  // I2C Bus to BMC                     (* chip_pin = "N8"  *)
    .LS_CP2112_CPLD_GPIO1            (LS_CP2112_CPLD_GPIO1      ),  // GPIO1                              (* chip_pin = "L2"  *)
    .LS_CP2112_CPLD_GPIO0            (LS_CP2112_CPLD_GPIO0      ),  // GPIO0                              (* chip_pin = "L1"  *)

// power status input    0x21

    .P1V2_STBY_OK                    (P1V2_STBY_OK               ), // 1.2V standby power OK      (* chip_pin = "M6"  *)
    .PWR_STBY_OK                     (PWR_STBY_OK                ), //  standby power OK           (* chip_pin = "T5"  *)

// IR power status, 0x22
    .VCORE_VRDY1                     (VCORE_VRDY1                ), // Vcore voltage ready status               (* chip_pin = "P7"  *)
    .VCORE_HOT                       (VCORE_HOT                  ), // over temperature or over current alarm   (* chip_pin = "R6"  *)
    .VANLG_VRDY1                     (VANLG_VRDY1                ), //                                          (* chip_pin = "N7"  *)
    .VANLG_HOT                       (VANLG_HOT                  ), // over temperature or over current alarm   (* chip_pin = "M7"  *)
    .V3V3_VRDY1                      (V3V3_VRDY1                 ), //                                          (* chip_pin = "R7"  *)
    .V3V3_HOT                        (V3V3_HOT                   ), // over temperature or over current alarm   (* chip_pin = "P8"  *)

// interrupt signals, 0x22
    .I2C_IO_0_INT_N                  (I2C_IO_0_INT_N             ), // I2C IO device PCA9535 Interrupt  (* chip_pin = "R13"  *)
    .I2C_IO_1_INT_N                  (I2C_IO_1_INT_N             ), // I2C IO device PCA9535 Interrupt  (* chip_pin = "N12"  *)
    .I2C_IO_2_INT_N                  (I2C_IO_2_INT_N             ), // I2C IO device PCA9535 Interrupt  (* chip_pin = "R14"  *)
    .I2C_IO_3_INT_N                  (I2C_IO_3_INT_N             ), // I2C IO device PCA9535 Interrupt  (* chip_pin = "P12"  *)
    .I2C_IO_4_INT_N                  (I2C_IO_4_INT_N             ), // I2C IO device PCA9535 Interrupt  (* chip_pin = "T15"  *)
    .I2C_IO_5_INT_N                  (I2C_IO_5_INT_N             ), // I2C IO device PCA9535 Interrupt  (* chip_pin = "R16"  *)

//------------------------------------------------------------------------

// misc control signals  rw_0x3d
    .DUAL_BOOT_EN                    (DUAL_BOOT_EN               ),  //  enable dual boot      (* chip_pin = "T7"  *)



// micro-server signals
    . MICROSRV_PRSNT_N               (MICROSRV_PRSNT_N           ),  // micro-server reset output        (* chip_pin = "C8"  *)
    . MICROSRV_PCIE_RST_N            (MICROSRV_PCIE_RST_N        ),  // micro-server reset output     (* chip_pin = "E7"  *)
    . MICROSRV_PWR_BTN_N             (MICROSRV_PWR_BTN_N         ),  // micro-server reset output    (* chip_pin = "B6"  *)
    . MSERV_POWERUP                  (MSERV_POWERUP              ),  // micro-server power up enable      (* chip_pin = "D7"  *)


//  Reset control
    .PD_STBY_RESET_N                 (PD_STBY_RESET_N            ),  // standby reset input from pwr1014a      (* chip_pin = "L12"  *)
    .PD_MAIN_RESET_N                 (PD_MAIN_RESET_N            ),  // main power reset input from pwr1014a    (* chip_pin = "T4"  *)
    .BMC_MAIN_RESET_N                (BMC_MAIN_RESET_N           ),  // BMC request to reset the system          (* chip_pin = "N13"  *)

    .P0_QRESET_N                     (P0_QRESET_N                ),  // Reset output to QSFP port 0     (* chip_pin = "F13"  *)
    .P1_QRESET_N                     (P1_QRESET_N                ),  // Reset output to QSFP port 1     (* chip_pin = "E15" *)
    .P2_QRESET_N                     (P2_QRESET_N                ),  // Reset output to QSFP port 2     (* chip_pin = "F14"  *)
    .P3_QRESET_N                     (P3_QRESET_N                ),  // Reset output to QSFP port 3     (* chip_pin = "D16" *)
    .P4_QRESET_N                     (P4_QRESET_N                ),  // Reset output to QSFP port 4    (* chip_pin = "E12"  *)
    .P5_QRESET_N                     (P5_QRESET_N                ),  // Reset output to QSFP port 5    (* chip_pin = "D15"  *)
    .P6_QRESET_N                     (P6_QRESET_N                ),  // Reset output to QSFP port 6    (* chip_pin = "C15"  *)
    .P7_QRESET_N                     (P7_QRESET_N                ),  // Reset output to QSFP port 7    (* chip_pin = "E13"  *)
    .P8_QRESET_N                     (P8_QRESET_N                ),  // Reset output to QSFP port 8    (* chip_pin = "E14"  *)
    .P9_QRESET_N                     (P9_QRESET_N                ),  // Reset output to QSFP port 9    (* chip_pin = "C14"  *)
    .P10_QRESET_N                    (P10_QRESET_N               ),  // Reset output to QSFP port 10   (* chip_pin = "C13"  *)
    .P11_QRESET_N                    (P11_QRESET_N               ),  // Reset output to QSFP port 11   (* chip_pin = "B16"  *)
    .P12_QRESET_N                    (P12_QRESET_N               ),  // Reset output to QSFP port 12   (* chip_pin = "D12"  *)
    .P13_QRESET_N                    (P13_QRESET_N               ),  // Reset output to QSFP port 13   (* chip_pin = "B14"  *)
    .P14_QRESET_N                    (P14_QRESET_N               ),  // Reset output to QSFP port 14   (* chip_pin = "C11"  *)
    .P15_QRESET_N                    (P15_QRESET_N               ),  // Reset output to QSFP port 15   (* chip_pin = "B13"  *)
    .P16_QRESET_N                    (P16_QRESET_N               ),  // Reset output to QSFP port 16   (* chip_pin = "E11"  *)
    .P17_QRESET_N                    (P17_QRESET_N               ),  // Reset output to QSFP port 17   (* chip_pin = "B12"  *)
    .P18_QRESET_N                    (P18_QRESET_N               ),  // Reset output to QSFP port 18   (* chip_pin = "B11"  *)
    .P19_QRESET_N                    (P19_QRESET_N               ),  // Reset output to QSFP port 19   (* chip_pin = "A12"  *)
    .P20_QRESET_N                    (P20_QRESET_N               ),  // Reset output to QSFP port 20   (* chip_pin = "E10"  *)
    .P21_QRESET_N                    (P21_QRESET_N               ),  // Reset output to QSFP port 21   (* chip_pin = "A11"  *)
    .P22_QRESET_N                    (P22_QRESET_N               ),  // Reset output to QSFP port 22   (* chip_pin = "A10"  *)
    .P23_QRESET_N                    (P23_QRESET_N               ),  // Reset output to QSFP port 23   (* chip_pin = "C9"  *)
    .P24_QRESET_N                    (P24_QRESET_N               ),  // Reset output to QSFP port 24   (* chip_pin = "B9"  *)
    .P25_QRESET_N                    (P25_QRESET_N               ),  // Reset output to QSFP port 25   (* chip_pin = "D9"  *)
    .P26_QRESET_N                    (P26_QRESET_N               ),  // Reset output to QSFP port 26   (* chip_pin = "A9"  *)
    .P27_QRESET_N                    (P27_QRESET_N               ),  // Reset output to QSFP port 27    (* chip_pin = "E9"  *)
    .P28_QRESET_N                    (P28_QRESET_N               ),  // Reset output to QSFP port 28    (* chip_pin = "B8"  *)
    .P29_QRESET_N                    (P29_QRESET_N               ),  // Reset output to QSFP port 29    (* chip_pin = "A8"  *)
    .P30_QRESET_N                    (P30_QRESET_N               ),  // Reset output to QSFP port 30    (* chip_pin = "D8"  *)
    .P31_QRESET_N                    (P31_QRESET_N               ),  // Reset output to QSFP port 31    (* chip_pin = "A7"  *)

    .USB_BRDG_RST_N                  (USB_BRDG_RST_N             ),  // usb bridge reset output        (* chip_pin = "M14"  *)
    .USB_HUB_RST_N                   (USB_HUB_RST_N              ),  // usb hub reset output           (* chip_pin = "K12"  *)
    .FANCARD_RST_N                   (FANCARD_RST_N              ),  // fan_ctrl card reset output     (* chip_pin = "M11"  *)

    .MICROSRV_RST_N                  (MICROSRV_RST_N             ),  // micro-server reset output                   (* chip_pin = "K4"  *)
    .BCM5387_RST_N                   (BCM5387_RST_N              ),  // OOB switch BCM5387 reset output             (* chip_pin = "N9"  *)
    .FP_PHY_RST_N                    (FP_PHY_RST_N               ),  // front port PHY reset output                (* chip_pin = "F11"  *)
    .BCM54616_PHY_RST_N              (BCM54616_PHY_RST_N         ),  // on-board PHY BCM54616 reset output         (* chip_pin = "T10"  *)
    .LS_USB_SPI_BRIDGE_RST_N         (LS_USB_SPI_BRIDGE_RST_N    ),  // usb to spi bridge reset signal                                (* chip_pin = "D1"  *)

    .I2C_MUX_RST0_N                  (I2C_MUX_RST0_N             ),  // i2c mux 0 reset output                      (* chip_pin = "D4"  *)
    .I2C_MUX_RST1_N                  (I2C_MUX_RST1_N             ),  // i2c mux 1 reset output                      (* chip_pin = "B1"  *)
    .I2C_MUX_RST2_N                  (I2C_MUX_RST2_N             ),  // i2c mux 2 reset output                      (* chip_pin = "C5"  *)
    .I2C_MUX_RST3_N                  (I2C_MUX_RST3_N             ),  // i2c mux 3 reset output                      (* chip_pin = "C4"  *)
    .I2C_MUX_PSU_RST_N               (I2C_MUX_PSU_RST_N          ),  // i2c mux for psu reset output               (* chip_pin = "D13"  *)
    .I2C_MUX_EXP_RST_N               (I2C_MUX_EXP_RST_N          ),  // i2c mux for qsfp LLI signals reset output  (* chip_pin = "M12"  *)

// power control signals
    .PWR_CYC_ALL_N                   (PWR_CYC_ALL_N              ),  // power cycle output to pwr1014a, power cycle all power            (* chip_pin = "D11"  *)
    .PWR_MAIN_EN                     (PWR_MAIN_EN                ),  // enable main power, active high                                   (* chip_pin = "D14"  *)
    .PWR_MAIN_FORCE                  (PWR_MAIN_FORCE             ),  // force main power, debug only, should not change by SW            (* chip_pin = "C7"  *)
    .PWR_MSERVER_FORCE               (PWR_MSERVER_FORCE          ),  // force micro-server power, debug only, should not change by SW    (* chip_pin = "F12"  *)
    .XP_POWERUP                      (XP_POWERUP                 ),  // tomahawk power up                                                (* chip_pin = "A5"  *)

    .BMC_UART_1_TX                   (BMC_UART_1_TX              ),  // bmc uart_1, BMC TX to cpld                 (* chip_pin = "R1"  *)
    .BMC_UART_1_RX                   (BMC_UART_1_RX              ),  // bmc uart_1, cpld to BMC RX                 (* chip_pin = "P4"  *)
    .BMC_UART_1_RTS                  (BMC_UART_1_RTS             ),  // bmc uart_1, BMC RTS to cpld                (* chip_pin = "P9"  *)

    .BMC_UART_4_TX                   (BMC_UART_4_TX              ),  // bmc uart_4, BMC TX to cpld                 (* chip_pin = "T2"  *)
    .BMC_UART_4_RX                   (BMC_UART_4_RX              ),  // bmc uart_4, cpld to BMC RX                 (* chip_pin = "P5"  *)
    .BMC_UART_4_RTS                  (BMC_UART_4_RTS             ),  // bmc uart_1, BMC RTS to cpld                (* chip_pin = "R9"  *)

    .BMC_UART_5_TX                   (BMC_UART_5_TX              ),  // bmc uart_5, BMC TX to cpld                 (* chip_pin = "R3"  *)
    .BMC_UART_5_RX                   (BMC_UART_5_RX              ),  // bmc uart_5, cpld to BMC RX                 (* chip_pin = "N5"  *)

    .PANTHER_COM_TX                  (PANTHER_COM_TX             ),  // panther uart TX to cpld                   (* chip_pin = "P6"  *)
    .PANTHER_COM_RX                  (PANTHER_COM_RX             ),  // panther uart RX, cpld to panther RX       (* chip_pin = "N6"  *)

    .FB_HDR_UART_RX                  (FB_HDR_UART_RX             ),  // facebook debug header                    (* chip_pin = "N15"  *)
    .FB_HDR_UART_TX                  (FB_HDR_UART_TX             ),  // facebook debug header                    (* chip_pin = "N14"  *)

    .REAR_DBG_UART_RX                (REAR_DBG_UART_RX           ),  // facebook debug header                  (* chip_pin = "N16"  *)
    .REAR_DBG_UART_TX                (REAR_DBG_UART_TX           ),  // facebook debug header                  (* chip_pin = "M13"  *)

    .RMON_RS485_RX                   (RMON_RS485_RX              ),  //  rackmon connector                        (* chip_pin = "M15"  *)
    .RMON_RS485_TX                   (RMON_RS485_TX              ),  //  rackmon connector                        (* chip_pin = "L14"  *)
    .RMON_RS485_RTS                  (RMON_RS485_RTS             ),  // rackmon connector                        (* chip_pin = "L13"  *)

//  board ID signals    ro_0x00
    .BOARD_REV_ID0                   (BOARD_REV_ID0              ),  //board revision ID        (* chip_pin = "K15"  *)
    .BOARD_REV_ID1                   (BOARD_REV_ID1              ),  //board revision ID        (* chip_pin = "K14"  *)
    .BOARD_REV_ID2                   (BOARD_REV_ID2              ),  //board revision ID        (* chip_pin = "L16"  *)


//  system LED signals
    .SYS_LED1_GREEN                  (SYS_LED1_GREEN             ),  // system led 1, green     (* chip_pin = "J15"  *)
    .SYS_LED1_BLUE                   (SYS_LED1_BLUE              ),  // system led 1, blue      (* chip_pin = "J14"  *)
    .SYS_LED1_RED                    (SYS_LED1_RED               ),  // system led 1, red       (* chip_pin = "J16"  *)

    .SYS_LED2_GREEN                  (SYS_LED2_GREEN             ),  // system led 2, green     (* chip_pin = "J13"  *)
    .SYS_LED2_BLUE                   (SYS_LED2_BLUE              ),  // system led 2, blue      (* chip_pin = "H16"  *)
    .SYS_LED2_RED                    (SYS_LED2_RED               ),  // system led 2, red       (* chip_pin = "H13"  *)

//  rest of signals
    .BMC_RST_N                       (BMC_RST_N                  ),  // BMC reset signal                                              (* chip_pin = "R5"  *)

    .BMC_HEARTBEAT_N                 (BMC_HEARTBEAT_N            ),  //BMCpower good signal from BMC                                  (* chip_pin = "B5"  *)

    .BMC_PWR_BTN_OUT_N               (BMC_PWR_BTN_OUT_N          ),  //pwr btn out from bmc                                           (* chip_pin = "M8"  *)
    .BMC_PWR_BTN_IN_N                (BMC_PWR_BTN_IN_N           ),  //pwr btn input to bmc                                           (* chip_pin = "M9"  *)
    .BMC_READY_N                     (BMC_READY_N                ),  //BMC ready signal                                               (* chip_pin = "K13"  *)

    .BOTTOM_QSFP_SEL_STATUS_LED      (BOTTOM_QSFP_SEL_STATUS_LED ),  //bottom qsfp selection status                                   (* chip_pin = "B4"  *)
    .TOP_QSFP_SEL_STATUS_LED         (TOP_QSFP_SEL_STATUS_LED    ),  //top qsfp selection status                                      (* chip_pin = "D6"  *)

    .BMC_CPLD_POWER_INT              (BMC_CPLD_POWER_INT         ),  //power interupt signal from BMC                                 (* chip_pin = "G16"  *)
    .PM_SM_ALERT_N                   (PM_SM_ALERT_N              ),  //sm bus alert from power manager                                (* chip_pin = "G13"  *)
    .VCORE_SMB_ALERT                 (VCORE_SMB_ALERT            ),  //VCORE supply sm bus alert                                      (* chip_pin = "G14"  *)
    .V3_3V_SMB_ALERT                 (V3_3V_SMB_ALERT            ),  //V3_3V supply sm bus alert                                      (* chip_pin = "E16"  *)
    .VANLG_SMB_ALERT                 (VANLG_SMB_ALERT            ),  //VANLG supply sm bus alert                                      (* chip_pin = "F15"  *)
    .SMB_ALERT                       (SMB_ALERT                  ),  // logical OR of power supply sm bus alert to bmc                (* chip_pin = "F16"  *)

    .CARD_PRNT_N                     (CARD_PRNT_N                ),  //card present signal from rackmon connector                     (* chip_pin = "M16"  *)

    .TEMP_SENSOR_ALERT               (TEMP_SENSOR_ALERT          ),  //temperature sensor alert signal                                (* chip_pin = "L11"  *)

    .BMC_CPLD_QSFP_INT               (BMC_CPLD_QSFP_INT          ),  //interupt from cpld to BMC                                      (* chip_pin = "H14"  *)

    .BMC_ISO_BUF_EN                  (BMC_ISO_BUF_EN             ),  //Request from BMC to enable isolation buffers                   (* chip_pin = "R4"  *)
    .BMC_MSERVE_ISOBUF_EN            (BMC_MSERVE_ISOBUF_EN       ),  //request from BMC to enable microserver isolation buffer        (* chip_pin = "P14"  *)
    .ISO_BUF_EN                      (ISO_BUF_EN                 ),  // isolation buffer enable                                       (* chip_pin = "P13"  *)
    .MSERVE_ISOBUF_EN                (MSERVE_ISOBUF_EN           ),  // Mserve isolation buffer enable                                (* chip_pin = "P15"  *)
    .LS_BMC_COM_ISOBUF_EN            (LS_BMC_COM_ISOBUF_EN       ),  // EVTB COM-e test card isolation buffer enable                   (* chip_pin = "H1"  *)

    .LS_BMC_WDTRST1                  (LS_BMC_WDTRST1             ),  //BMC watch dog timer reset output                               (* chip_pin = "E2"  *)
    .LS_BMC_WDTRST2                  (LS_BMC_WDTRST2             ),  //BMC watch dog timer reset output                               (* chip_pin = "F5"  *)
    .BMC_SPI_WP_N                    (BMC_SPI_WP_N               ),  //bmc request to enable  write protect of Secondary boot device  (* chip_pin = "E6"  *)
    .CPLD_SPI_SEC_BOOT_WP_N          (CPLD_SPI_SEC_BOOT_WP_N     ),  //  Secondary boot device write protect enable                   (* chip_pin = "B7"  *)

    .BMC_CPLD_RESET1                 (BMC_CPLD_RESET1            ),  //spare reset signal from BMC                                    (* chip_pin = "A4"  *)
    .BMC_CPLD_RESET2                 (BMC_CPLD_RESET2            ),  //spare reset signal from BMC                                    (* chip_pin = "G12"  *)
    .LS_BMC_CPLD_RESET3              (LS_BMC_CPLD_RESET3         ),  //spare reset signal from BMC                                    (* chip_pin = "J3"  *)
    .LS_BMC_CPLD_RESET4              (LS_BMC_CPLD_RESET4         ),  //spare reset signal from BMC                                    (* chip_pin = "K2"  *)
    .LS_BMC_CPLD_SPARE7              (LS_BMC_CPLD_SPARE7         ),  //spare signal from BMC                                          (* chip_pin = "K5"  *)

    .PUSHBUTTON_RST_N                (PUSHBUTTON_RST_N           ),  //front panel push btn reset                                     (* chip_pin = "K16"  *)
    .CPLD_PUSH_BTN_RST_IN_N          (CPLD_PUSH_BTN_RST_IN_N     ),  //on board debug reset btn                                       (* chip_pin = "L15"  *)

    .LS_DPLL_RST_N                   (LS_DPLL_RST_N              ),  // DPLL rst signal                                               (* chip_pin = "E5"  *)


    .DEBUG_PORT_UART_SEL_N           (DEBUG_PORT_UART_SEL_N      ),  // Debug port select button in Front panel is pressed DEBUG_PORT_UART_SEL_N becomes low                 (* chip_pin = "C12"  *)
    .DEBUG_UART_SEL_0                (DEBUG_UART_SEL_0           ),  //debug port uart selection from BMC                                                                    (* chip_pin = "A13"  *)
    .DEBUG_RST_BTN_N                 (DEBUG_RST_BTN_N            ),  // Debug Reset button in Front panel is pressed, DEBUG_RST_BTN_N will become low                        (* chip_pin = "A15"  *)

    // new DVTA signals
    .LS_COM_GBE0_LINK1000_N          (LS_COM_GBE0_LINK1000_N     ),  //(* chip_pin = "M4"   *) input   Gigabit ethernet link input from COMe(Active Low)    CPLD_DEBUG5(testpoint)  Testpoint
    .TPM_SPI_PIRQ_N                  (TPM_SPI_PIRQ_N             ),  //(* chip_pin = "R11"  *)     input    Interupt from TPM based SPI module(Active Low)  CPLD_DEBUG4(testpoint)  Testpoint

    .TPM_LPC_RST_N                   (TPM_LPC_RST_N              ),  //(* chip_pin = "L3"   *)     output   Reset output for TPM based LPC module(Active Low)   CPLD_DEBUG7(testpoint)  Testpoint
    .LS_TPM_SPI_RST_N                (LS_TPM_SPI_RST_N           ),  //(* chip_pin = "N1"   *)     output   Reset output for TPM based SPI module(Active Low)   CPLD_DEBUG8(testpoint)  Testpoint
    .LS_CPLD_COM_PHY_RST_N           (LS_CPLD_COM_PHY_RST_N      ),  //(* chip_pin = "C10"*)     output  COMe reset output(Active Low)  NC  NC
    .LS_LPC_RST_N                    (LS_LPC_RST_N               ),  //(* chip_pin = "L5"   *)     output   BMC LPC reset output(Active Low)    NC  NC

    .LS_COM_PWROK                    (LS_COM_PWROK               ),  //(* chip_pin = "N2"   *) output  Power ok signal to COMe Module                   CPLD_DEBUG6(testpoint)  Testpoint

    .LS_B_COM_TYPE0                  (LS_B_COM_TYPE0             ),  //(* chip_pin = "H2"   *)     input    Type signal from COMe            CP2112_CPLD_GPIO4  GPIO to CP2112
    .LS_B_COM_TYPE1                  (LS_B_COM_TYPE1             ),  //(* chip_pin = "G5"   *)     input    Type signal from COMe            CP2112_CPLD_GPIO5  GPIO to CP2112
    .LS_B_COM_TYPE2                  (LS_B_COM_TYPE2             ),  //(* chip_pin = "H3"   *)     input    Type signal from COMe            CP2112_CPLD_GPIO6  GPIO to CP2112

    .COM_SUS_STAT_N                  (COM_SUS_STAT_N             ),  //(* chip_pin = "N11"*)     input   Sleep status signal from COMe  NC  NC
    .LS_COM_SUS_S3_N                 (LS_COM_SUS_S3_N            ),  //(* chip_pin = "J1"   *)     input    Sleep status signal from COMe    CP2112_CPLD_GPIO7  GPIO to CP2112
    .COM_SUS_S4_N                    (COM_SUS_S4_N               ),  //(* chip_pin = "H12"  *)     input    Sleep status signal from COMe   NC  NC
    .COM_SUS_S5_N                    (COM_SUS_S5_N               ),  //(* chip_pin = "A4"   *)     input    Sleep status signal from COMe   NC  NC

    .LS_BMC_PHY_WP                   (LS_BMC_PHY_WP              ),  //(* chip_pin = "J12"*)     output  "BMC PHY write protect signal  1:Disable,  0:Enable"   NC  NC
    .LS_FP_PHY_WP                    (LS_FP_PHY_WP               ),  //(* chip_pin = "H12"*)     output  "Front panel  PHY write protect signal 1:Disable,  0:Enable"   NC  NC
    .CPLD_BMC_SPIBOOT_WP_N           (CPLD_BMC_SPIBOOT_WP_N      ),  //(* chip_pin = "G15"*)     output  "BMC Spi boot write protect signal, 1:Disable, 0:Enable"   CPLD_IN3    Spare interupt  input to Powermanager

    .LS_COM_NIC_ISOBUF_EN            (LS_COM_NIC_ISOBUF_EN       ),  //(* chip_pin = "K3"   *)     output   COMe SMBUS isolation buffer enable(Active Low)  CP2112_CPLD_GPIO2   GPIO to CP2112
    .LS_COM_PANTHER_ISOBUF_EN        (LS_COM_PANTHER_ISOBUF_EN   ),  //(* chip_pin = "M1"   *)     output   COMe I2C isolation buffer enable(Active Low)    CP2112_CPLD_GPIO3   GPIO to CP2112

   //   Xpliant Clock PLL resets
    .ISO_XP_CORE_CLK_PLL_RST_N       (ISO_XP_CORE_CLK_PLL_RST_N  ),  //(* chip_pin = "D3"   *) input   ISO_XP_CORE_CLK_PLL_RST_N  // Core Clock PLL reset.When low core clock pll is reset
    .ISO_XP_MAC_CLK_PLL_RST_N        (ISO_XP_MAC_CLK_PLL_RST_N   ),  //(* chip_pin = "C2"   *) output   ISO_XP_MAC_CLK_PLL_RST_N  Mac Clock PLL reset.When low mac clock pll is reset
    .ISO_XP_PEX_CLK_PLL_RST_N        (ISO_XP_PEX_CLK_PLL_RST_N   ),  //(* chip_pin = "C3"   *) output   ISO_XP_PEX_CLK_PLL_RST_N  PEX Clock PLL reset.When low pex clock pll is reset

  //   Xpliant PLL Locks
    .ISO_XP_CORE_PLL_LOCK            (ISO_XP_CORE_PLL_LOCK       ),  //(* chip_pin = "E3"   *) input   ISO_XP_CORE_PLL_LOCK Core clock PLL lock indication 0-not locked,1- locked
    .ISO_XP_MAC_PLL_LOCK             (ISO_XP_MAC_PLL_LOCK        ),  //(* chip_pin = "D2"  *)  input   ISO_XP_MAC_PLL_LOCK Mac clock PLL lock indication 0-not locked,1- locked
    .ISO_XP_PEX_PLL_LOCK             (ISO_XP_PEX_PLL_LOCK        ),  //(* chip_pin = "E4"  *)  input  ISO_XP_PEX_PLL_LOCK PEX clock PLL lock indication 0-not locked,1- locked

   //   XpliantMisc Interfaces
    .ISO_XP_REI_INIT_DONE            (ISO_XP_REI_INIT_DONE       ),  //(* chip_pin = "M2"   *) output   ISO_XP_REI_INIT_DONE REI INIT DONE OUTPUT
    .ISO_XP_INT_N                    (ISO_XP_INT_N               ),  //(* chip_pin = "F4"   *) output   ISO_XP_INT_N XPLIANT INTERRUPT SIGNAL
    .ISO_XP_OVERT_N                  (ISO_XP_OVERT_N             ),  //(* chip_pin = "E1"   *) output   ISO_XP_OVERT_N XLIPANT TEMP SENSOR OUTPUT
    .ISO_XP_TEMP_ALRT_N              (ISO_XP_TEMP_ALRT_N         ),  //(* chip_pin = "F3"   *) output   ISO_XP_TEMP_ALRT_N XLIPANT TEMP SENSOR OUTPUT


    .ISO_XPLIANT_RST_N               (ISO_XPLIANT_RST_N          ),  //(* chip_pin = "L4"   *) input   ISO_XPLIANT_RST_N tomahawk ISO_XPLIANT_RST_N

    .ISO_XP_GPIO_0                   (ISO_XP_GPIO_0              ),  // (* chip_pin = "G2"   *) inout   ISO_XP_GPIO_0 Xpliant GPIO signal
    .ISO_XP_GPIO_1                   (ISO_XP_GPIO_1              ),  // (* chip_pin = "G3"   *) inout   ISO_XP_GPIO_1 Xpliant GPIO signal
    .ISO_XP_GPIO_2                   (ISO_XP_GPIO_2              ),  // (* chip_pin = "G1"   *) inout   ISO_XP_GPIO_2 Xpliant GPIO signal
    .ISO_XP_GPIO_3                   (ISO_XP_GPIO_3              ),  // (* chip_pin = "G4"   *) inout   ISO_XP_GPIO_3 Xpliant GPIO signal

       // debug signals from top module
    .debug_out                       (debug_out                  )   // debug output
);

assign       CPLD_DEBUG1 = debug_out[0];
assign       CPLD_DEBUG2 = debug_out[1];
assign       CPLD_DEBUG3 = debug_out[2];
endmodule
